#line 1 "ad_arm.cpp"
//
// Copyright (c) 2008, 2022, Oracle and/or its affiliates. All rights reserved.
// DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
//
// This code is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License version 2 only, as
// published by the Free Software Foundation.
//
// This code is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// version 2 for more details (a copy is included in the LICENSE file that
// accompanied this code).
//
// You should have received a copy of the GNU General Public License version
// 2 along with this work; if not, write to the Free Software Foundation,
// Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
//
// Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
// or visit www.oracle.com if you need additional information or have any
// questions.
//

// Machine Generated File.  Do Not Edit!

#include "precompiled.hpp"
#include "adfiles/adGlobals_arm.hpp"
#include "adfiles/ad_arm.hpp"
#include "memory/allocation.inline.hpp"
#include "code/codeCache.hpp"
#include "code/compiledIC.hpp"
#include "code/nativeInst.hpp"
#include "code/vmreg.inline.hpp"
#include "gc/shared/collectedHeap.inline.hpp"
#include "oops/compiledICHolder.hpp"
#include "oops/compressedOops.hpp"
#include "oops/markWord.hpp"
#include "oops/method.hpp"
#include "oops/oop.inline.hpp"
#include "opto/c2_MacroAssembler.hpp"
#include "opto/cfgnode.hpp"
#include "opto/intrinsicnode.hpp"
#include "opto/locknode.hpp"
#include "opto/opcodes.hpp"
#include "opto/regalloc.hpp"
#include "opto/regmask.hpp"
#include "opto/runtime.hpp"
#include "runtime/safepointMechanism.hpp"
#include "runtime/sharedRuntime.hpp"
#include "runtime/stubRoutines.hpp"
#include "utilities/growableArray.hpp"
#include "utilities/powerOfTwo.hpp"

//SourceForm

#line 398 "src/hotspot/cpu/arm/arm_32.ad"


// Given a register encoding, produce a Integer Register object
static Register reg_to_register_object(int register_encoding) {
  assert(R0->encoding() == R_R0_enc && R15->encoding() == R_R15_enc, "right coding");
  return as_Register(register_encoding);
}

// Given a register encoding, produce a single-precision Float Register object
static FloatRegister reg_to_FloatRegister_object(int register_encoding) {
  assert(S0->encoding() == R_S0_enc && S31->encoding() == R_S31_enc, "right coding");
  return as_FloatRegister(register_encoding);
}

void Compile::pd_compiler2_init() {
  // Umimplemented
}

// Location of compiled Java return values.  Same as C
OptoRegPair c2::return_value(int ideal_reg) {
  assert( ideal_reg >= Op_RegI && ideal_reg <= Op_RegL, "only return normal values" );
#ifndef __ABI_HARD__
  static int lo[Op_RegL+1] = { 0, 0, OptoReg::Bad, R_R0_num,     R_R0_num,     R_R0_num,     R_R0_num, R_R0_num };
  static int hi[Op_RegL+1] = { 0, 0, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, R_R1_num, R_R1_num };
#else
  static int lo[Op_RegL+1] = { 0, 0, OptoReg::Bad, R_R0_num,     R_R0_num,     R_hf_ret_lo_num,  R_hf_ret_lo_num, R_R0_num };
  static int hi[Op_RegL+1] = { 0, 0, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad, OptoReg::Bad,     R_hf_ret_hi_num, R_R1_num };
#endif
  return OptoRegPair( hi[ideal_reg], lo[ideal_reg]);
}

// !!!!! Special hack to get all type of calls to specify the byte offset
//       from the start of the call to the point where the return address
//       will point.

int MachCallStaticJavaNode::ret_addr_offset() {
  bool far = (_method == NULL) ? maybe_far_call(this) : !cache_reachable();
  return ((far ? 3 : 1) + (_method_handle_invoke ? 1 : 0)) *
    NativeInstruction::instruction_size;
}

int MachCallDynamicJavaNode::ret_addr_offset() {
  bool far = !cache_reachable();
  // mov_oop is always 2 words
  return (2 + (far ? 3 : 1)) * NativeInstruction::instruction_size;
}

int MachCallRuntimeNode::ret_addr_offset() {
  // bl or movw; movt; blx
  bool far = maybe_far_call(this);
  return (far ? 3 : 1) * NativeInstruction::instruction_size;
}

#line 111 "ad_arm.cpp"


//SourceForm

#line 133 "src/hotspot/cpu/arm/arm.ad"


// Assert that the given node is not a var shift.
bool assert_not_var_shift(const Node *n) {
  assert(!n->as_ShiftV()->is_var_shift(), "illegal var shift");
  return true;
}

#define __ _masm.

static FloatRegister reg_to_FloatRegister_object(int register_encoding);
static Register reg_to_register_object(int register_encoding);

void PhaseOutput::pd_perform_mach_node_analysis() {
}

int MachNode::pd_alignment_required() const {
  return 1;
}

int MachNode::compute_padding(int current_offset) const {
  return 0;
}

// ****************************************************************************

// REQUIRED FUNCTIONALITY

// emit an interrupt that is caught by the debugger (for debugging compiler)
void emit_break(CodeBuffer &cbuf) {
  C2_MacroAssembler _masm(&cbuf);
  __ breakpoint();
}

#ifndef PRODUCT
void MachBreakpointNode::format( PhaseRegAlloc *, outputStream *st ) const {
  st->print("TA");
}
#endif

void MachBreakpointNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  emit_break(cbuf);
}

uint MachBreakpointNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}


void emit_nop(CodeBuffer &cbuf) {
  C2_MacroAssembler _masm(&cbuf);
  __ nop();
}


void emit_call_reloc(CodeBuffer &cbuf, const MachCallNode *n, MachOper *m, RelocationHolder const& rspec) {
  int ret_addr_offset0 = n->as_MachCall()->ret_addr_offset();
  int call_site_offset = cbuf.insts()->mark_off();
  C2_MacroAssembler _masm(&cbuf);
  __ set_inst_mark(); // needed in emit_to_interp_stub() to locate the call
  address target = (address)m->method();
  assert(n->as_MachCall()->entry_point() == target, "sanity");
  assert(maybe_far_call(n) == !__ reachable_from_cache(target), "sanity");
  assert(cache_reachable() == __ cache_fully_reachable(), "sanity");

  assert(target != NULL, "need real address");

  int ret_addr_offset = -1;
  if (rspec.type() == relocInfo::runtime_call_type) {
    __ call(target, rspec);
    ret_addr_offset = __ offset();
  } else {
    // scratches Rtemp
    ret_addr_offset = __ patchable_call(target, rspec, true);
  }
  assert(ret_addr_offset - call_site_offset == ret_addr_offset0, "fix ret_addr_offset()");
}

//=============================================================================
// REQUIRED FUNCTIONALITY for encoding
void emit_lo(CodeBuffer &cbuf, int val) {  }
void emit_hi(CodeBuffer &cbuf, int val) {  }


//=============================================================================
const RegMask& MachConstantBaseNode::_out_RegMask = PTR_REG_mask();

int ConstantTable::calculate_table_base_offset() const {
  int offset = -(size() / 2);
  // flds, fldd: 8-bit  offset multiplied by 4: +/- 1024
  // ldr, ldrb : 12-bit offset:                 +/- 4096
  if (!Assembler::is_simm10(offset)) {
    offset = Assembler::min_simm10;
  }
  return offset;
}

bool MachConstantBaseNode::requires_postalloc_expand() const { return false; }
void MachConstantBaseNode::postalloc_expand(GrowableArray <Node *> *nodes, PhaseRegAlloc *ra_) {
  ShouldNotReachHere();
}

void MachConstantBaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  Compile* C = ra_->C;
  ConstantTable& constant_table = C->output()->constant_table();
  C2_MacroAssembler _masm(&cbuf);

  Register r = as_Register(ra_->get_encode(this));
  CodeSection* consts_section = __ code()->consts();
  CodeSection* insts_section = __ code()->insts();
  // constants section size is aligned according to the align_at_start settings of the next section
  int consts_size = insts_section->align_at_start(consts_section->size());
  assert(constant_table.size() == consts_size, "must be: %d == %d", constant_table.size(), consts_size);

  // Materialize the constant table base.
  address baseaddr = consts_section->start() + -(constant_table.table_base_offset());
  RelocationHolder rspec = internal_word_Relocation::spec(baseaddr);
  __ mov_address(r, baseaddr, rspec);
}

uint MachConstantBaseNode::size(PhaseRegAlloc*) const {
  return 8;
}

#ifndef PRODUCT
void MachConstantBaseNode::format(PhaseRegAlloc* ra_, outputStream* st) const {
  char reg[128];
  ra_->dump_register(this, reg, sizeof(reg));
  st->print("MOV_SLOW    &constanttable,%s\t! constant table base", reg);
}
#endif

#ifndef PRODUCT
void MachPrologNode::format( PhaseRegAlloc *ra_, outputStream *st ) const {
  Compile* C = ra_->C;

  for (int i = 0; i < OptoPrologueNops; i++) {
    st->print_cr("NOP"); st->print("\t");
  }

  size_t framesize = C->output()->frame_size_in_bytes();
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  int bangsize = C->output()->bang_size_in_bytes();
  // Remove two words for return addr and rbp,
  framesize -= 2*wordSize;
  bangsize -= 2*wordSize;

  // Calls to C2R adapters often do not accept exceptional returns.
  // We require that their callers must bang for them.  But be careful, because
  // some VM calls (such as call site linkage) can use several kilobytes of
  // stack.  But the stack safety zone should account for that.
  // See bugs 4446381, 4468289, 4497237.
  if (C->output()->need_stack_bang(bangsize)) {
    st->print_cr("! stack bang (%d bytes)", bangsize); st->print("\t");
  }
  st->print_cr("PUSH   R_FP|R_LR_LR"); st->print("\t");
  if (framesize != 0) {
    st->print   ("SUB    R_SP, R_SP, " SIZE_FORMAT,framesize);
  }

  if (C->stub_function() == NULL && BarrierSet::barrier_set()->barrier_set_nmethod() != NULL) {
    st->print("ldr t0, [guard]\n\t");
    st->print("ldr t1, [Rthread, #thread_disarmed_guard_value_offset]\n\t");
    st->print("cmp t0, t1\n\t");
    st->print("beq skip\n\t");
    st->print("blr #nmethod_entry_barrier_stub\n\t");
    st->print("b skip\n\t");
    st->print("guard: int\n\t");
    st->print("skip:\n\t");
  }
}
#endif

void MachPrologNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  Compile* C = ra_->C;
  C2_MacroAssembler _masm(&cbuf);

  for (int i = 0; i < OptoPrologueNops; i++) {
    __ nop();
  }

  size_t framesize = C->output()->frame_size_in_bytes();
  assert((framesize & (StackAlignmentInBytes-1)) == 0, "frame size not aligned");
  int bangsize = C->output()->bang_size_in_bytes();
  // Remove two words for return addr and fp,
  framesize -= 2*wordSize;
  bangsize -= 2*wordSize;

  // Calls to C2R adapters often do not accept exceptional returns.
  // We require that their callers must bang for them.  But be careful, because
  // some VM calls (such as call site linkage) can use several kilobytes of
  // stack.  But the stack safety zone should account for that.
  // See bugs 4446381, 4468289, 4497237.
  if (C->output()->need_stack_bang(bangsize)) {
    __ arm_stack_overflow_check(bangsize, Rtemp);
  }

  __ raw_push(FP, LR);
  if (framesize != 0) {
    __ sub_slow(SP, SP, framesize);
  }

  if (C->stub_function() == NULL) {
    BarrierSetAssembler* bs = BarrierSet::barrier_set()->barrier_set_assembler();
    bs->nmethod_entry_barrier(&_masm);
  }

  // offset from scratch buffer is not valid
  if (strcmp(cbuf.name(), "Compile::Fill_buffer") == 0) {
    C->output()->set_frame_complete( __ offset() );
  }

  if (C->has_mach_constant_base_node()) {
    // NOTE: We set the table base offset here because users might be
    // emitted before MachConstantBaseNode.
    ConstantTable& constant_table = C->output()->constant_table();
    constant_table.set_table_base_offset(constant_table.calculate_table_base_offset());
  }
}

uint MachPrologNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

int MachPrologNode::reloc() const {
  return 10; // a large enough number
}

//=============================================================================
#ifndef PRODUCT
void MachEpilogNode::format( PhaseRegAlloc *ra_, outputStream *st ) const {
  Compile* C = ra_->C;

  size_t framesize = C->output()->frame_size_in_bytes();
  framesize -= 2*wordSize;

  if (framesize != 0) {
    st->print("ADD    R_SP, R_SP, " SIZE_FORMAT "\n\t",framesize);
  }
  st->print("POP    R_FP|R_LR_LR");

  if (do_polling() && ra_->C->is_method_compilation()) {
    st->print("\n\t");
    st->print("MOV    Rtemp, #PollAddr\t! Load Polling address\n\t");
    st->print("LDR    Rtemp,[Rtemp]\t!Poll for Safepointing");
  }
}
#endif

void MachEpilogNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  Compile* C = ra_->C;

  size_t framesize = C->output()->frame_size_in_bytes();
  framesize -= 2*wordSize;
  if (framesize != 0) {
    __ add_slow(SP, SP, framesize);
  }
  __ raw_pop(FP, LR);

  // If this does safepoint polling, then do it here
  if (do_polling() && ra_->C->is_method_compilation()) {
    __ read_polling_page(Rtemp, relocInfo::poll_return_type);
  }
}

uint MachEpilogNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}

int MachEpilogNode::reloc() const {
  return 16; // a large enough number
}

const Pipeline * MachEpilogNode::pipeline() const {
  return MachNode::pipeline_class();
}

//=============================================================================

// Figure out which register class each belongs in: rc_int, rc_float, rc_stack
enum RC { rc_bad, rc_int, rc_float, rc_stack };
static enum RC rc_class( OptoReg::Name reg ) {
  if (!OptoReg::is_valid(reg)) return rc_bad;
  if (OptoReg::is_stack(reg)) return rc_stack;
  VMReg r = OptoReg::as_VMReg(reg);
  if (r->is_Register()) return rc_int;
  assert(r->is_FloatRegister(), "must be");
  return rc_float;
}

static inline bool is_iRegLd_memhd(OptoReg::Name src_first, OptoReg::Name src_second, int offset) {
  int rlo = Matcher::_regEncode[src_first];
  int rhi = Matcher::_regEncode[src_second];
  if (!((rlo&1)==0 && (rlo+1 == rhi))) {
    tty->print_cr("CAUGHT BAD LDRD/STRD");
  }
  return (rlo&1)==0 && (rlo+1 == rhi) && is_memoryHD(offset);
}

uint MachSpillCopyNode::implementation( CodeBuffer *cbuf,
                                        PhaseRegAlloc *ra_,
                                        bool do_size,
                                        outputStream* st ) const {
  // Get registers to move
  OptoReg::Name src_second = ra_->get_reg_second(in(1));
  OptoReg::Name src_first = ra_->get_reg_first(in(1));
  OptoReg::Name dst_second = ra_->get_reg_second(this );
  OptoReg::Name dst_first = ra_->get_reg_first(this );

  enum RC src_second_rc = rc_class(src_second);
  enum RC src_first_rc = rc_class(src_first);
  enum RC dst_second_rc = rc_class(dst_second);
  enum RC dst_first_rc = rc_class(dst_first);

  assert( OptoReg::is_valid(src_first) && OptoReg::is_valid(dst_first), "must move at least 1 register" );

  // Generate spill code!
  int size = 0;

  if (src_first == dst_first && src_second == dst_second)
    return size;            // Self copy, no move

#ifdef TODO
  if (bottom_type()->isa_vect() != NULL) {
  }
#endif

  // Shared code does not expect instruction set capability based bailouts here.
  // Handle offset unreachable bailout with minimal change in shared code.
  // Bailout only for real instruction emit.
  // This requires a single comment change in shared code. ( see output.cpp "Normal" instruction case )

  C2_MacroAssembler _masm(cbuf);

  // --------------------------------------
  // Check for mem-mem move.  Load into unused float registers and fall into
  // the float-store case.
  if (src_first_rc == rc_stack && dst_first_rc == rc_stack) {
    int offset = ra_->reg2offset(src_first);
    if (cbuf && !is_memoryfp(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      if (src_second_rc != rc_bad) {
        assert((src_first&1)==0 && src_first+1 == src_second, "pair of registers must be aligned/contiguous");
        src_first     = OptoReg::Name(R_mem_copy_lo_num);
        src_second    = OptoReg::Name(R_mem_copy_hi_num);
        src_first_rc  = rc_float;
        src_second_rc = rc_float;
        if (cbuf) {
          __ ldr_double(Rmemcopy, Address(SP, offset));
        } else if (!do_size) {
          st->print(LDR_DOUBLE "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_first),offset);
        }
      } else {
        src_first     = OptoReg::Name(R_mem_copy_lo_num);
        src_first_rc  = rc_float;
        if (cbuf) {
          __ ldr_float(Rmemcopy, Address(SP, offset));
        } else if (!do_size) {
          st->print(LDR_FLOAT "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_first),offset);
        }
      }
      size += 4;
    }
  }

  if (src_second_rc == rc_stack && dst_second_rc == rc_stack) {
    Unimplemented();
  }

  // --------------------------------------
  // Check for integer reg-reg copy
  if (src_first_rc == rc_int && dst_first_rc == rc_int) {
    // Else normal reg-reg copy
    assert( src_second != dst_first, "smashed second before evacuating it" );
    if (cbuf) {
      __ mov(reg_to_register_object(Matcher::_regEncode[dst_first]), reg_to_register_object(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
    } else if (!do_size) {
      st->print("MOV    R_%s, R_%s\t# spill",
                Matcher::regName[dst_first],
                Matcher::regName[src_first]);
#endif
    }
    size += 4;
  }

  // Check for integer store
  if (src_first_rc == rc_int && dst_first_rc == rc_stack) {
    int offset = ra_->reg2offset(dst_first);
    if (cbuf && !is_memoryI(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      if (src_second_rc != rc_bad && is_iRegLd_memhd(src_first, src_second, offset)) {
        assert((src_first&1)==0 && src_first+1 == src_second, "pair of registers must be aligned/contiguous");
        if (cbuf) {
          __ str_64(reg_to_register_object(Matcher::_regEncode[src_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(STR_64 "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_first), offset);
#endif
        }
        return size + 4;
      } else {
        if (cbuf) {
          __ str_32(reg_to_register_object(Matcher::_regEncode[src_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(STR_32 "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_first), offset);
#endif
        }
      }
    }
    size += 4;
  }

  // Check for integer load
  if (dst_first_rc == rc_int && src_first_rc == rc_stack) {
    int offset = ra_->reg2offset(src_first);
    if (cbuf && !is_memoryI(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      if (src_second_rc != rc_bad && is_iRegLd_memhd(dst_first, dst_second, offset)) {
        assert((src_first&1)==0 && src_first+1 == src_second, "pair of registers must be aligned/contiguous");
        if (cbuf) {
          __ ldr_64(reg_to_register_object(Matcher::_regEncode[dst_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(LDR_64 "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(dst_first), offset);
#endif
        }
        return size + 4;
      } else {
        if (cbuf) {
          __ ldr_32(reg_to_register_object(Matcher::_regEncode[dst_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(LDR_32 "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(dst_first), offset);
#endif
        }
      }
    }
    size += 4;
  }

  // Check for float reg-reg copy
  if (src_first_rc == rc_float && dst_first_rc == rc_float) {
    if (src_second_rc != rc_bad) {
      assert((src_first&1)==0 && src_first+1 == src_second && (dst_first&1)==0 && dst_first+1 == dst_second, "pairs of registers must be aligned/contiguous");
      if (cbuf) {
      __ mov_double(reg_to_FloatRegister_object(Matcher::_regEncode[dst_first]), reg_to_FloatRegister_object(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
      } else if (!do_size) {
        st->print(MOV_DOUBLE "    R_%s, R_%s\t# spill",
                  Matcher::regName[dst_first],
                  Matcher::regName[src_first]);
#endif
      }
      return 4;
    }
    if (cbuf) {
      __ mov_float(reg_to_FloatRegister_object(Matcher::_regEncode[dst_first]), reg_to_FloatRegister_object(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
    } else if (!do_size) {
      st->print(MOV_FLOAT "    R_%s, R_%s\t# spill",
                Matcher::regName[dst_first],
                Matcher::regName[src_first]);
#endif
    }
    size = 4;
  }

  // Check for float store
  if (src_first_rc == rc_float && dst_first_rc == rc_stack) {
    int offset = ra_->reg2offset(dst_first);
    if (cbuf && !is_memoryfp(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      // Further check for aligned-adjacent pair, so we can use a double store
      if (src_second_rc != rc_bad) {
        assert((src_first&1)==0 && src_first+1 == src_second && (dst_first&1)==0 && dst_first+1 == dst_second, "pairs of registers and stack slots must be aligned/contiguous");
        if (cbuf) {
          __ str_double(reg_to_FloatRegister_object(Matcher::_regEncode[src_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(STR_DOUBLE "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_first),offset);
#endif
        }
        return size + 4;
      } else {
        if (cbuf) {
          __ str_float(reg_to_FloatRegister_object(Matcher::_regEncode[src_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(STR_FLOAT "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_first),offset);
#endif
        }
      }
    }
    size += 4;
  }

  // Check for float load
  if (dst_first_rc == rc_float && src_first_rc == rc_stack) {
    int offset = ra_->reg2offset(src_first);
    if (cbuf && !is_memoryfp(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      // Further check for aligned-adjacent pair, so we can use a double store
      if (src_second_rc != rc_bad) {
        assert((src_first&1)==0 && src_first+1 == src_second && (dst_first&1)==0 && dst_first+1 == dst_second, "pairs of registers and stack slots must be aligned/contiguous");
        if (cbuf) {
          __ ldr_double(reg_to_FloatRegister_object(Matcher::_regEncode[dst_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(LDR_DOUBLE "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(dst_first),offset);
#endif
        }
        return size + 4;
      } else {
        if (cbuf) {
          __ ldr_float(reg_to_FloatRegister_object(Matcher::_regEncode[dst_first]), Address(SP, offset));
#ifndef PRODUCT
        } else if (!do_size) {
          if (size != 0) st->print("\n\t");
          st->print(LDR_FLOAT "   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(dst_first),offset);
#endif
        }
      }
    }
    size += 4;
  }

  // check for int reg -> float reg move
  if (src_first_rc == rc_int && dst_first_rc == rc_float) {
    // Further check for aligned-adjacent pair, so we can use a single instruction
    if (src_second_rc != rc_bad) {
      assert((dst_first&1)==0 && dst_first+1 == dst_second, "pairs of registers must be aligned/contiguous");
      assert((src_first&1)==0 && src_first+1 == src_second, "pairs of registers must be aligned/contiguous");
      assert(src_second_rc == rc_int && dst_second_rc == rc_float, "unsupported");
      if (cbuf) {
        __ fmdrr(reg_to_FloatRegister_object(Matcher::_regEncode[dst_first]), reg_to_register_object(Matcher::_regEncode[src_first]), reg_to_register_object(Matcher::_regEncode[src_second]));
#ifndef PRODUCT
      } else if (!do_size) {
        if (size != 0) st->print("\n\t");
        st->print("FMDRR   R_%s, R_%s, R_%s\t! spill",OptoReg::regname(dst_first), OptoReg::regname(src_first), OptoReg::regname(src_second));
#endif
      }
      return size + 4;
    } else {
      if (cbuf) {
        __ fmsr(reg_to_FloatRegister_object(Matcher::_regEncode[dst_first]), reg_to_register_object(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
      } else if (!do_size) {
        if (size != 0) st->print("\n\t");
        st->print(FMSR "   R_%s, R_%s\t! spill",OptoReg::regname(dst_first), OptoReg::regname(src_first));
#endif
      }
      size += 4;
    }
  }

  // check for float reg -> int reg move
  if (src_first_rc == rc_float && dst_first_rc == rc_int) {
    // Further check for aligned-adjacent pair, so we can use a single instruction
    if (src_second_rc != rc_bad) {
      assert((src_first&1)==0 && src_first+1 == src_second, "pairs of registers must be aligned/contiguous");
      assert((dst_first&1)==0 && dst_first+1 == dst_second, "pairs of registers must be aligned/contiguous");
      assert(src_second_rc == rc_float && dst_second_rc == rc_int, "unsupported");
      if (cbuf) {
        __ fmrrd(reg_to_register_object(Matcher::_regEncode[dst_first]), reg_to_register_object(Matcher::_regEncode[dst_second]), reg_to_FloatRegister_object(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
      } else if (!do_size) {
        if (size != 0) st->print("\n\t");
        st->print("FMRRD   R_%s, R_%s, R_%s\t! spill",OptoReg::regname(dst_first), OptoReg::regname(dst_second), OptoReg::regname(src_first));
#endif
      }
      return size + 4;
    } else {
      if (cbuf) {
        __ fmrs(reg_to_register_object(Matcher::_regEncode[dst_first]), reg_to_FloatRegister_object(Matcher::_regEncode[src_first]));
#ifndef PRODUCT
      } else if (!do_size) {
        if (size != 0) st->print("\n\t");
        st->print(FMRS "   R_%s, R_%s\t! spill",OptoReg::regname(dst_first), OptoReg::regname(src_first));
#endif
      }
      size += 4;
    }
  }

  // --------------------------------------------------------------------
  // Check for hi bits still needing moving.  Only happens for misaligned
  // arguments to native calls.
  if (src_second == dst_second)
    return size;               // Self copy; no move
  assert( src_second_rc != rc_bad && dst_second_rc != rc_bad, "src_second & dst_second cannot be Bad" );

  // Check for integer reg-reg copy.  Hi bits are stuck up in the top
  // 32-bits of a 64-bit register, but are needed in low bits of another
  // register (else it's a hi-bits-to-hi-bits copy which should have
  // happened already as part of a 64-bit move)
  if (src_second_rc == rc_int && dst_second_rc == rc_int) {
    if (cbuf) {
      __ mov(reg_to_register_object(Matcher::_regEncode[dst_second]), reg_to_register_object(Matcher::_regEncode[src_second]));
#ifndef PRODUCT
    } else if (!do_size) {
      if (size != 0) st->print("\n\t");
      st->print("MOV    R_%s, R_%s\t# spill high",
                Matcher::regName[dst_second],
                Matcher::regName[src_second]);
#endif
    }
    return size+4;
  }

  // Check for high word integer store
  if (src_second_rc == rc_int && dst_second_rc == rc_stack) {
    int offset = ra_->reg2offset(dst_second);

    if (cbuf && !is_memoryP(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      if (cbuf) {
        __ str(reg_to_register_object(Matcher::_regEncode[src_second]), Address(SP, offset));
#ifndef PRODUCT
      } else if (!do_size) {
        if (size != 0) st->print("\n\t");
        st->print("STR   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(src_second), offset);
#endif
      }
    }
    return size + 4;
  }

  // Check for high word integer load
  if (dst_second_rc == rc_int && src_second_rc == rc_stack) {
    int offset = ra_->reg2offset(src_second);
    if (cbuf && !is_memoryP(offset)) {
      ra_->C->record_method_not_compilable("unable to handle large constant offsets");
      return 0;
    } else {
      if (cbuf) {
        __ ldr(reg_to_register_object(Matcher::_regEncode[dst_second]), Address(SP, offset));
#ifndef PRODUCT
      } else if (!do_size) {
        if (size != 0) st->print("\n\t");
        st->print("LDR   R_%s,[R_SP + #%d]\t! spill",OptoReg::regname(dst_second), offset);
#endif
      }
    }
    return size + 4;
  }

  Unimplemented();
  return 0; // Mute compiler
}

#ifndef PRODUCT
void MachSpillCopyNode::format( PhaseRegAlloc *ra_, outputStream *st ) const {
  implementation( NULL, ra_, false, st );
}
#endif

void MachSpillCopyNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  implementation( &cbuf, ra_, false, NULL );
}

uint MachSpillCopyNode::size(PhaseRegAlloc *ra_) const {
  return implementation( NULL, ra_, true, NULL );
}

//=============================================================================
#ifndef PRODUCT
void MachNopNode::format( PhaseRegAlloc *, outputStream *st ) const {
  st->print("NOP \t# %d bytes pad for loops and calls", 4 * _count);
}
#endif

void MachNopNode::emit(CodeBuffer &cbuf, PhaseRegAlloc * ) const {
  C2_MacroAssembler _masm(&cbuf);
  for(int i = 0; i < _count; i += 1) {
    __ nop();
  }
}

uint MachNopNode::size(PhaseRegAlloc *ra_) const {
  return 4 * _count;
}


//=============================================================================
#ifndef PRODUCT
void BoxLockNode::format( PhaseRegAlloc *ra_, outputStream *st ) const {
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_reg_first(this);
  st->print("ADD    %s,R_SP+#%d",Matcher::regName[reg], offset);
}
#endif

void BoxLockNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  int offset = ra_->reg2offset(in_RegMask(0).find_first_elem());
  int reg = ra_->get_encode(this);
  Register dst = reg_to_register_object(reg);

  if (is_aimm(offset)) {
    __ add(dst, SP, offset);
  } else {
    __ mov_slow(dst, offset);
    __ add(dst, SP, dst);
  }
}

uint BoxLockNode::size(PhaseRegAlloc *ra_) const {
  // BoxLockNode is not a MachNode, so we can't just call MachNode::size(ra_)
  assert(ra_ == ra_->C->regalloc(), "sanity");
  return ra_->C->output()->scratch_emit_size(this);
}

//=============================================================================
#ifndef PRODUCT
#define R_RTEMP "R_R12"
void MachUEPNode::format( PhaseRegAlloc *ra_, outputStream *st ) const {
  st->print_cr("\nUEP:");
  if (UseCompressedClassPointers) {
    st->print_cr("\tLDR_w " R_RTEMP ",[R_R0 + oopDesc::klass_offset_in_bytes]\t! Inline cache check");
    st->print_cr("\tdecode_klass " R_RTEMP);
  } else {
    st->print_cr("\tLDR   " R_RTEMP ",[R_R0 + oopDesc::klass_offset_in_bytes]\t! Inline cache check");
  }
  st->print_cr("\tCMP   " R_RTEMP ",R_R8" );
  st->print   ("\tB.NE  SharedRuntime::handle_ic_miss_stub");
}
#endif

void MachUEPNode::emit(CodeBuffer &cbuf, PhaseRegAlloc *ra_) const {
  C2_MacroAssembler _masm(&cbuf);
  Register iCache  = reg_to_register_object(Matcher::inline_cache_reg_encode());
  assert(iCache == Ricklass, "should be");
  Register receiver = R0;

  __ load_klass(Rtemp, receiver);
  __ cmp(Rtemp, iCache);
  __ jump(SharedRuntime::get_ic_miss_stub(), relocInfo::runtime_call_type, noreg, ne);
}

uint MachUEPNode::size(PhaseRegAlloc *ra_) const {
  return MachNode::size(ra_);
}


//=============================================================================

// Emit exception handler code.
int HandlerImpl::emit_exception_handler(CodeBuffer& cbuf) {
  C2_MacroAssembler _masm(&cbuf);

  address base = __ start_a_stub(size_exception_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }

  int offset = __ offset();

  // OK to trash LR, because exception blob will kill it
  __ jump(OptoRuntime::exception_blob()->entry_point(), relocInfo::runtime_call_type, LR_tmp);

  assert(__ offset() - offset <= (int) size_exception_handler(), "overflow");

  __ end_a_stub();

  return offset;
}

int HandlerImpl::emit_deopt_handler(CodeBuffer& cbuf) {
  // Can't use any of the current frame's registers as we may have deopted
  // at a poll and everything can be live.
  C2_MacroAssembler _masm(&cbuf);

  address base = __ start_a_stub(size_deopt_handler());
  if (base == NULL) {
    ciEnv::current()->record_failure("CodeCache is full");
    return 0;  // CodeBuffer::expand failed
  }

  int offset = __ offset();
  address deopt_pc = __ pc();

  __ sub(SP, SP, wordSize); // make room for saved PC
  __ push(LR); // save LR that may be live when we get here
  __ mov_relative_address(LR, deopt_pc);
  __ str(LR, Address(SP, wordSize)); // save deopt PC
  __ pop(LR); // restore LR
  __ jump(SharedRuntime::deopt_blob()->unpack(), relocInfo::runtime_call_type, noreg);

  assert(__ offset() - offset <= (int) size_deopt_handler(), "overflow");

  __ end_a_stub();
  return offset;
}

const bool Matcher::match_rule_supported(int opcode) {
  if (!has_match_rule(opcode))
    return false;

  switch (opcode) {
  case Op_PopCountI:
  case Op_PopCountL:
    if (!UsePopCountInstruction)
      return false;
    break;
  case Op_LShiftCntV:
  case Op_RShiftCntV:
  case Op_AddVB:
  case Op_AddVS:
  case Op_AddVI:
  case Op_AddVL:
  case Op_SubVB:
  case Op_SubVS:
  case Op_SubVI:
  case Op_SubVL:
  case Op_MulVS:
  case Op_MulVI:
  case Op_LShiftVB:
  case Op_LShiftVS:
  case Op_LShiftVI:
  case Op_LShiftVL:
  case Op_RShiftVB:
  case Op_RShiftVS:
  case Op_RShiftVI:
  case Op_RShiftVL:
  case Op_URShiftVB:
  case Op_URShiftVS:
  case Op_URShiftVI:
  case Op_URShiftVL:
  case Op_AndV:
  case Op_OrV:
  case Op_XorV:
    return VM_Version::has_simd();
  case Op_LoadVector:
  case Op_StoreVector:
  case Op_AddVF:
  case Op_SubVF:
  case Op_MulVF:
    return VM_Version::has_vfp() || VM_Version::has_simd();
  case Op_AddVD:
  case Op_SubVD:
  case Op_MulVD:
  case Op_DivVF:
  case Op_DivVD:
    return VM_Version::has_vfp();
  }

  return true;  // Per default match rules are supported.
}

const bool Matcher::match_rule_supported_superword(int opcode, int vlen, BasicType bt) {
  return match_rule_supported_vector(opcode, vlen, bt);
}

const bool Matcher::match_rule_supported_vector(int opcode, int vlen, BasicType bt) {

  // TODO
  // identify extra cases that we might want to provide match rules for
  // e.g. Op_ vector nodes and other intrinsics while guarding with vlen
  bool ret_value = match_rule_supported(opcode) && vector_size_supported(bt, vlen);
  // Add rules here.

  return ret_value;  // Per default match rules are supported.
}

const bool Matcher::match_rule_supported_vector_masked(int opcode, int vlen, BasicType bt) {
  return false;
}

const bool Matcher::vector_needs_partial_operations(Node* node, const TypeVect* vt) {
  return false;
}

const RegMask* Matcher::predicate_reg_mask(void) {
  return NULL;
}

const TypeVectMask* Matcher::predicate_reg_type(const Type* elemTy, int length) {
  return NULL;
}

// Vector calling convention not yet implemented.
const bool Matcher::supports_vector_calling_convention(void) {
  return false;
}

OptoRegPair Matcher::vector_return_value(uint ideal_reg) {
  Unimplemented();
  return OptoRegPair(0, 0);
}

// Vector width in bytes
const int Matcher::vector_width_in_bytes(BasicType bt) {
  return MaxVectorSize;
}

const int Matcher::scalable_vector_reg_size(const BasicType bt) {
  return -1;
}

// Vector ideal reg corresponding to specified size in bytes
const uint Matcher::vector_ideal_reg(int size) {
  assert(MaxVectorSize >= size, "");
  switch(size) {
    case  8: return Op_VecD;
    case 16: return Op_VecX;
  }
  ShouldNotReachHere();
  return 0;
}

// Limits on vector size (number of elements) loaded into vector.
const int Matcher::max_vector_size(const BasicType bt) {
  assert(is_java_primitive(bt), "only primitive type vectors");
  return vector_width_in_bytes(bt)/type2aelembytes(bt);
}

const int Matcher::min_vector_size(const BasicType bt) {
  assert(is_java_primitive(bt), "only primitive type vectors");
  return 8/type2aelembytes(bt);
}

const int Matcher::superword_max_vector_size(const BasicType bt) {
  return Matcher::max_vector_size(bt);
}

// Is this branch offset short enough that a short branch can be used?
//
// NOTE: If the platform does not provide any short branch variants, then
//       this method should return false for offset 0.
bool Matcher::is_short_branch_offset(int rule, int br_size, int offset) {
  // The passed offset is relative to address of the branch.
  // On ARM a branch displacement is calculated relative to address
  // of the branch + 8.
  //
  // offset -= 8;
  // return (Assembler::is_simm24(offset));
  return false;
}

MachOper* Matcher::pd_specialize_generic_vector_operand(MachOper* original_opnd, uint ideal_reg, bool is_temp) {
  ShouldNotReachHere(); // generic vector operands not supported
  return NULL;
}

bool Matcher::is_reg2reg_move(MachNode* m) {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

bool Matcher::is_generic_vector(MachOper* opnd)  {
  ShouldNotReachHere();  // generic vector operands not supported
  return false;
}

// Should the matcher clone input 'm' of node 'n'?
bool Matcher::pd_clone_node(Node* n, Node* m, Matcher::MStack& mstack) {
  if (is_vshift_con_pattern(n, m)) { // ShiftV src (ShiftCntV con)
    mstack.push(m, Visit);           // m = ShiftCntV
    return true;
  }
  return false;
}

// Should the Matcher clone shifts on addressing modes, expecting them
// to be subsumed into complex addressing expressions or compute them
// into registers?
bool Matcher::pd_clone_address_expressions(AddPNode* m, Matcher::MStack& mstack, VectorSet& address_visited) {
  return clone_base_plus_offset_address(m, mstack, address_visited);
}

// Return whether or not this register is ever used as an argument.  This
// function is used on startup to build the trampoline stubs in generateOptoStub.
// Registers not mentioned will be killed by the VM call in the trampoline, and
// arguments in those registers not be available to the callee.
bool Matcher::can_be_java_arg( int reg ) {
  if (reg == R_R0_num ||
      reg == R_R1_num ||
      reg == R_R2_num ||
      reg == R_R3_num) return true;

  if (reg >= R_S0_num &&
      reg <= R_S13_num) return true;
  return false;
}

bool Matcher::is_spillable_arg( int reg ) {
  return can_be_java_arg(reg);
}

uint Matcher::int_pressure_limit()
{
  return (INTPRESSURE == -1) ? 12 : INTPRESSURE;
}

uint Matcher::float_pressure_limit()
{
  return (FLOATPRESSURE == -1) ? 30 : FLOATPRESSURE;
}

bool Matcher::use_asm_for_ldiv_by_con( jlong divisor ) {
  return false;
}

// Register for DIVI projection of divmodI
RegMask Matcher::divI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODI projection of divmodI
RegMask Matcher::modI_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for DIVL projection of divmodL
RegMask Matcher::divL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

// Register for MODL projection of divmodL
RegMask Matcher::modL_proj_mask() {
  ShouldNotReachHere();
  return RegMask();
}

const RegMask Matcher::method_handle_invoke_SP_save_mask() {
  return FP_REGP_mask();
}

bool maybe_far_call(const CallNode *n) {
  return !MacroAssembler::_reachable_from_cache(n->as_Call()->entry_point());
}

bool maybe_far_call(const MachCallNode *n) {
  return !MacroAssembler::_reachable_from_cache(n->as_MachCall()->entry_point());
}


#line 1180 "ad_arm.cpp"


#ifndef PRODUCT
void Compile::adlc_verification() {

  // Following assertions generated from definition section
  assert( DEFAULT_COST == 100, "Expect (100) to equal 100");
  assert( HUGE_COST == 1000000, "Expect (1000000) to equal 1000000");
  assert( MEMORY_REF_COST == 200, "Expect (DEFAULT_COST * 2) to equal 200");
  assert( BRANCH_COST == 300, "Expect (DEFAULT_COST * 3) to equal 300");
  assert( CALL_COST == 300, "Expect (DEFAULT_COST * 3) to equal 300");
}
#endif

// Map from machine-independent register number to register_save_policy
const        char register_save_policy[] = {
  'C', // R_R4
  'C', // R_R5
  'C', // R_R6
  'C', // R_R7
  'C', // R_R8
  'C', // R_R9
  'N', // R_R11
  'C', // R_R12
  'N', // R_R10
  'N', // R_R13
  'C', // R_R14
  'N', // R_R15
  'C', // R_R0
  'C', // R_R1
  'C', // R_R2
  'C', // R_R3
  'C', // R_S16
  'C', // R_S17
  'C', // R_S18
  'C', // R_S19
  'C', // R_S20
  'C', // R_S21
  'C', // R_S22
  'C', // R_S23
  'C', // R_S24
  'C', // R_S25
  'C', // R_S26
  'C', // R_S27
  'C', // R_S28
  'C', // R_S29
  'C', // R_S30
  'C', // R_S31
  'C', // R_S0
  'C', // R_S1
  'C', // R_S2
  'C', // R_S3
  'C', // R_S4
  'C', // R_S5
  'C', // R_S6
  'C', // R_S7
  'C', // R_S8
  'C', // R_S9
  'C', // R_S10
  'C', // R_S11
  'C', // R_S12
  'C', // R_S13
  'C', // R_S14
  'C', // R_S15
  'C', // R_D16
  'C', // R_D16x
  'C', // R_D17
  'C', // R_D17x
  'C', // R_D18
  'C', // R_D18x
  'C', // R_D19
  'C', // R_D19x
  'C', // R_D20
  'C', // R_D20x
  'C', // R_D21
  'C', // R_D21x
  'C', // R_D22
  'C', // R_D22x
  'C', // R_D23
  'C', // R_D23x
  'C', // R_D24
  'C', // R_D24x
  'C', // R_D25
  'C', // R_D25x
  'C', // R_D26
  'C', // R_D26x
  'C', // R_D27
  'C', // R_D27x
  'C', // R_D28
  'C', // R_D28x
  'C', // R_D29
  'C', // R_D29x
  'C', // R_D30
  'C', // R_D30x
  'C', // R_D31
  'C', // R_D31x
  'C', // APSR
  'C' // no trailing comma // FPSCR
};

// Map from machine-independent register number to c_reg_save_policy
const        char c_reg_save_policy[] = {
  'E', // R_R4
  'E', // R_R5
  'E', // R_R6
  'E', // R_R7
  'E', // R_R8
  'E', // R_R9
  'E', // R_R11
  'C', // R_R12
  'E', // R_R10
  'N', // R_R13
  'C', // R_R14
  'N', // R_R15
  'C', // R_R0
  'C', // R_R1
  'C', // R_R2
  'C', // R_R3
  'E', // R_S16
  'E', // R_S17
  'E', // R_S18
  'E', // R_S19
  'E', // R_S20
  'E', // R_S21
  'E', // R_S22
  'E', // R_S23
  'E', // R_S24
  'E', // R_S25
  'E', // R_S26
  'E', // R_S27
  'E', // R_S28
  'E', // R_S29
  'E', // R_S30
  'E', // R_S31
  'C', // R_S0
  'C', // R_S1
  'C', // R_S2
  'C', // R_S3
  'C', // R_S4
  'C', // R_S5
  'C', // R_S6
  'C', // R_S7
  'C', // R_S8
  'C', // R_S9
  'C', // R_S10
  'C', // R_S11
  'C', // R_S12
  'C', // R_S13
  'C', // R_S14
  'C', // R_S15
  'C', // R_D16
  'C', // R_D16x
  'C', // R_D17
  'C', // R_D17x
  'C', // R_D18
  'C', // R_D18x
  'C', // R_D19
  'C', // R_D19x
  'C', // R_D20
  'C', // R_D20x
  'C', // R_D21
  'C', // R_D21x
  'C', // R_D22
  'C', // R_D22x
  'C', // R_D23
  'C', // R_D23x
  'C', // R_D24
  'C', // R_D24x
  'C', // R_D25
  'C', // R_D25x
  'C', // R_D26
  'C', // R_D26x
  'C', // R_D27
  'C', // R_D27x
  'C', // R_D28
  'C', // R_D28x
  'C', // R_D29
  'C', // R_D29x
  'C', // R_D30
  'C', // R_D30x
  'C', // R_D31
  'C', // R_D31x
  'C', // APSR
  'C' // no trailing comma // FPSCR
};

// Map from machine-independent register number to register_save_type
const        int register_save_type[] = {
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegI,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegF,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegD,
  Op_RegFlags,
  Op_RegFlags // no trailing comma
};


const        int   reduceOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  immIRot_rule,
  /*    9 */  immIRotn_rule,
  /*   10 */  immIRotneg_rule,
  /*   11 */  immU31Rot_rule,
  /*   12 */  immPRot_rule,
  /*   13 */  immLlowRot_rule,
  /*   14 */  immLRot2_rule,
  /*   15 */  immI12_rule,
  /*   16 */  immI10x2_rule,
  /*   17 */  immI12x2_rule,
  /*   18 */  immI_rule,
  /*   19 */  immU8_rule,
  /*   20 */  immI16_rule,
  /*   21 */  immIHD_rule,
  /*   22 */  immIFP_rule,
  /*   23 */  immU5_rule,
  /*   24 */  immU6Big_rule,
  /*   25 */  immI0_rule,
  /*   26 */  immI_1_rule,
  /*   27 */  immI_2_rule,
  /*   28 */  immI_3_rule,
  /*   29 */  immI_4_rule,
  /*   30 */  immI_8_rule,
  /*   31 */  immU31_rule,
  /*   32 */  immI_32_63_rule,
  /*   33 */  immI_16_rule,
  /*   34 */  immI_24_rule,
  /*   35 */  immI_255_rule,
  /*   36 */  immI_65535_rule,
  /*   37 */  aimmI_rule,
  /*   38 */  aimmIneg_rule,
  /*   39 */  aimmU31_rule,
  /*   40 */  limmI_rule,
  /*   41 */  limmIlow8_rule,
  /*   42 */  limmU31_rule,
  /*   43 */  limmIn_rule,
  /*   44 */  immL_FF_rule,
  /*   45 */  immL_FFFF_rule,
  /*   46 */  immP_rule,
  /*   47 */  immP0_rule,
  /*   48 */  immN_rule,
  /*   49 */  immNKlass_rule,
  /*   50 */  immN0_rule,
  /*   51 */  immL_rule,
  /*   52 */  immL0_rule,
  /*   53 */  immL16_rule,
  /*   54 */  immL_32bits_rule,
  /*   55 */  immD_rule,
  /*   56 */  immD0_rule,
  /*   57 */  imm8D_rule,
  /*   58 */  immF_rule,
  /*   59 */  immF0_rule,
  /*   60 */  imm8F_rule,
  /*   61 */  iRegI_rule,
  /*   62 */  iRegP_rule,
  /*   63 */  sp_ptr_RegP_rule,
  /*   64 */  R0RegP_rule,
  /*   65 */  R1RegP_rule,
  /*   66 */  R8RegP_rule,
  /*   67 */  R9RegP_rule,
  /*   68 */  R12RegP_rule,
  /*   69 */  R2RegP_rule,
  /*   70 */  RExceptionRegP_rule,
  /*   71 */  RthreadRegP_rule,
  /*   72 */  IPRegP_rule,
  /*   73 */  SPRegP_rule,
  /*   74 */  LRRegP_rule,
  /*   75 */  R0RegI_rule,
  /*   76 */  R1RegI_rule,
  /*   77 */  R2RegI_rule,
  /*   78 */  R3RegI_rule,
  /*   79 */  R12RegI_rule,
  /*   80 */  iRegL_rule,
  /*   81 */  iRegLd_rule,
  /*   82 */  R0R1RegL_rule,
  /*   83 */  R2R3RegL_rule,
  /*   84 */  flagsReg_rule,
  /*   85 */  flagsReg_EQNELTGE_rule,
  /*   86 */  flagsRegU_rule,
  /*   87 */  flagsRegP_rule,
  /*   88 */  flagsRegL_LTGE_rule,
  /*   89 */  flagsRegL_EQNE_rule,
  /*   90 */  flagsRegL_LEGT_rule,
  /*   91 */  flagsRegUL_LTGE_rule,
  /*   92 */  flagsRegUL_EQNE_rule,
  /*   93 */  flagsRegUL_LEGT_rule,
  /*   94 */  flagsRegF_rule,
  /*   95 */  vecD_rule,
  /*   96 */  vecX_rule,
  /*   97 */  regD_rule,
  /*   98 */  regF_rule,
  /*   99 */  regD_low_rule,
  /*  100 */  inline_cache_regP_rule,
  /*  101 */  indirect_rule,
  /*  102 */  indOffset12_rule,
  /*  103 */  indOffsetFP_rule,
  /*  104 */  indOffsetHD_rule,
  /*  105 */  indOffsetFPx2_rule,
  /*  106 */  indOffset12x2_rule,
  /*  107 */  indIndex_rule,
  /*  108 */  indIndexScale_rule,
  /*  109 */  cmpOp_rule,
  /*  110 */  cmpOp0_rule,
  /*  111 */  cmpOpU_rule,
  /*  112 */  cmpOpP_rule,
  /*  113 */  cmpOpL_rule,
  /*  114 */  cmpOpL_commute_rule,
  /*  115 */  cmpOpUL_rule,
  /*  116 */  cmpOpUL_commute_rule,
  /*  117 */  shiftedX_rule,
  // last operand
  /*  118 */  memoryI_rule,
  /*  119 */  memoryP_rule,
  /*  120 */  memoryF_rule,
  /*  121 */  memoryF2_rule,
  /*  122 */  memoryD_rule,
  /*  123 */  memoryfp_rule,
  /*  124 */  memoryB_rule,
  /*  125 */  memoryS_rule,
  /*  126 */  memoryL_rule,
  /*  127 */  memoryScaledI_rule,
  /*  128 */  memoryScaledP_rule,
  /*  129 */  memoryex_rule,
  /*  130 */  indIndexMemory_rule,
  /*  131 */  memorylong_rule,
  /*  132 */  memoryvld_rule,
  // last operand class
  /*  133 */  _LShiftI_iRegI_immU5_rule,
  /*  134 */  _LoadB_memoryB__rule,
  /*  135 */  _LoadUB_memoryB__rule,
  /*  136 */  _AndI__LoadUB_memoryB__limmIlow8_rule,
  /*  137 */  _LoadS_memoryS__rule,
  /*  138 */  _LShiftI__LoadS_memoryS__immI_24_rule,
  /*  139 */  _LoadUS_memoryB__rule,
  /*  140 */  _LShiftI__LoadUS_memoryB__immI_24_rule,
  /*  141 */  _LoadUS_memoryS__rule,
  /*  142 */  _AndI__LoadUS_memoryB__immI_255_rule,
  /*  143 */  _AndI__LoadUS_memoryS__limmI_rule,
  /*  144 */  _LoadI_memoryS__rule,
  /*  145 */  _LShiftI__LoadI_memoryS__immI_24_rule,
  /*  146 */  _LoadI_memoryB__rule,
  /*  147 */  _LShiftI__LoadI_memoryS__immI_16_rule,
  /*  148 */  _LoadI_memoryI__rule,
  /*  149 */  _AndI__LoadI_memoryB__immI_255_rule,
  /*  150 */  _AndI__LoadI_memoryS__immI_65535_rule,
  /*  151 */  _AndI__LoadI_memoryI__limmU31_rule,
  /*  152 */  _AndI__LoadI_memoryI__immU31_rule,
  /*  153 */  _ConvI2L__LoadI_memoryI___rule,
  /*  154 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  155 */  _Binary_iRegI_iRegI_rule,
  /*  156 */  _Binary_iRegI_immIRot_rule,
  /*  157 */  _Binary_iRegI_immI16_rule,
  /*  158 */  _Binary_cmpOp_flagsReg_rule,
  /*  159 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  160 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  161 */  _Binary_iRegP_iRegP_rule,
  /*  162 */  _Binary_iRegP_immP0_rule,
  /*  163 */  _Binary_regF_regF_rule,
  /*  164 */  _Binary_regD_regD_rule,
  /*  165 */  _Binary_iRegL_iRegL_rule,
  /*  166 */  _Binary_iRegL_immLlowRot_rule,
  /*  167 */  _Binary_iRegL_immL16_rule,
  /*  168 */  _LShiftI_iRegI_iRegI_rule,
  /*  169 */  _RShiftI_iRegI_iRegI_rule,
  /*  170 */  _RShiftI_iRegI_immU5_rule,
  /*  171 */  _URShiftI_iRegI_iRegI_rule,
  /*  172 */  _URShiftI_iRegI_immU5_rule,
  /*  173 */  _Binary_iRegL_iRegLd_rule,
  /*  174 */  _CastP2X_iRegP__rule,
  /*  175 */  _ConvF2D_regF__rule,
  /*  176 */  _SqrtD__ConvF2D_regF___rule,
  /*  177 */  _CmpLTMask_iRegI_iRegI_rule,
  /*  178 */  _AndI__CmpLTMask_iRegI_iRegI_iRegI_rule,
  /*  179 */  _AndI_iRegI__CmpLTMask_iRegI_iRegI_rule,
  /*  180 */  _CmpLTMask_iRegI_aimmI_rule,
  /*  181 */  _AndI__CmpLTMask_iRegI_aimmI_iRegI_rule,
  /*  182 */  _AndI_iRegI__CmpLTMask_iRegI_aimmI_rule,
  /*  183 */  _SubI_iRegI_iRegI_rule,
  /*  184 */  _ConvI2L_iRegI__rule,
  /*  185 */  _RShiftL_iRegL_immI_32_63_rule,
  /*  186 */  _AndI_iRegI_iRegI_rule,
  /*  187 */  _AndI_iRegI__LShiftI_iRegI_iRegI_rule,
  /*  188 */  _AndI__LShiftI_iRegI_iRegI_iRegI_rule,
  /*  189 */  _AndI_iRegI__LShiftI_iRegI_immU5_rule,
  /*  190 */  _AndI__LShiftI_iRegI_immU5_iRegI_rule,
  /*  191 */  _AndI_iRegI__RShiftI_iRegI_iRegI_rule,
  /*  192 */  _AndI__RShiftI_iRegI_iRegI_iRegI_rule,
  /*  193 */  _AndI_iRegI__RShiftI_iRegI_immU5_rule,
  /*  194 */  _AndI__RShiftI_iRegI_immU5_iRegI_rule,
  /*  195 */  _AndI_iRegI__URShiftI_iRegI_iRegI_rule,
  /*  196 */  _AndI__URShiftI_iRegI_iRegI_iRegI_rule,
  /*  197 */  _AndI_iRegI__URShiftI_iRegI_immU5_rule,
  /*  198 */  _AndI__URShiftI_iRegI_immU5_iRegI_rule,
  /*  199 */  _AndI_iRegI_limmI_rule,
  /*  200 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  201 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  202 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  203 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  204 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  205 */  _Binary_iRegL_immL0_rule,
  /*  206 */  _Binary_cmpOpUL_flagsRegUL_EQNE_rule,
  /*  207 */  _LShiftCntV_immI__rule,
  /*  208 */  _RShiftCntV_immI__rule,
  // last internally defined operand
  /*  209 */  iRegI_rule,
  /*  210 */  iRegI_rule,
  /*  211 */  iRegI_rule,
  /*  212 */  iRegI_rule,
  /*  213 */  iRegP_rule,
  /*  214 */  iRegL_rule,
  /*  215 */  iRegL_rule,
  /*  216 */  regF_rule,
  /*  217 */  regF_rule,
  /*  218 */  regD_rule,
  /*  219 */  regD_rule,
  /*  220 */  iRegP_rule,
  /*  221 */  iRegI_rule,
  /*  222 */  RthreadRegP_rule,
  /*  223 */  iRegP_rule,
  /*  224 */  iRegP_rule,
  /*  225 */  iRegI_rule,
  /*  226 */  iRegL_rule,
  /*  227 */  regF_rule,
  /*  228 */  regD_rule,
  /*  229 */  vecD_rule,
  /*  230 */  vecX_rule,
  /*  231 */  regD_rule,
  /*  232 */  regF_rule,
  /*  233 */  regF_rule,
  /*  234 */  regD_rule,
  /*  235 */  iRegI_rule,
  /*  236 */  regF_rule,
  /*  237 */  iRegL_rule,
  /*  238 */  regD_rule,
  /*  239 */  0,
  /*  240 */  0,
  /*  241 */  flagsReg_rule,
  /*  242 */  flagsRegU_rule,
  /*  243 */  flagsReg_rule,
  /*  244 */  flagsReg_rule,
  /*  245 */  flagsReg_EQNELTGE_rule,
  /*  246 */  flagsReg_EQNELTGE_rule,
  /*  247 */  flagsReg_EQNELTGE_rule,
  /*  248 */  flagsReg_EQNELTGE_rule,
  /*  249 */  flagsReg_EQNELTGE_rule,
  /*  250 */  flagsReg_EQNELTGE_rule,
  /*  251 */  flagsReg_EQNELTGE_rule,
  /*  252 */  flagsReg_EQNELTGE_rule,
  /*  253 */  flagsReg_EQNELTGE_rule,
  /*  254 */  flagsReg_EQNELTGE_rule,
  /*  255 */  flagsReg_EQNELTGE_rule,
  /*  256 */  flagsReg_EQNELTGE_rule,
  /*  257 */  flagsReg_EQNELTGE_rule,
  /*  258 */  flagsReg_EQNELTGE_rule,
  /*  259 */  flagsRegL_LTGE_rule,
  /*  260 */  flagsRegUL_LTGE_rule,
  /*  261 */  flagsRegL_EQNE_rule,
  /*  262 */  flagsRegL_LEGT_rule,
  /*  263 */  flagsRegL_LTGE_rule,
  /*  264 */  flagsRegL_EQNE_rule,
  /*  265 */  flagsRegL_LEGT_rule,
  /*  266 */  flagsRegUL_EQNE_rule,
  /*  267 */  flagsRegUL_LEGT_rule,
  /*  268 */  flagsRegUL_LTGE_rule,
  /*  269 */  flagsRegUL_EQNE_rule,
  /*  270 */  flagsRegUL_LEGT_rule,
  /*  271 */  flagsRegU_rule,
  /*  272 */  flagsRegP_rule,
  /*  273 */  flagsRegP_rule,
  /*  274 */  flagsReg_rule,
  /*  275 */  flagsReg_rule,
  /*  276 */  flagsReg_rule,
  /*  277 */  flagsReg_rule,
  /*  278 */  flagsRegP_rule,
  /*  279 */  flagsRegP_rule,
  /*  280 */  iRegI_rule,
  /*  281 */  vecD_rule,
  /*  282 */  vecX_rule,
  /*  283 */  vecD_rule,
  /*  284 */  vecX_rule,
  /*  285 */  vecD_rule,
  /*  286 */  vecX_rule,
  /*  287 */  vecD_rule,
  /*  288 */  vecX_rule,
  /*  289 */  vecD_rule,
  /*  290 */  vecX_rule,
  /*  291 */  vecD_rule,
  /*  292 */  vecX_rule,
  /*  293 */  vecD_rule,
  /*  294 */  vecX_rule,
  /*  295 */  vecX_rule,
  /*  296 */  vecD_rule,
  /*  297 */  vecD_rule,
  /*  298 */  vecD_rule,
  /*  299 */  vecX_rule,
  /*  300 */  vecX_rule,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  vecD_rule,
  /*  304 */  vecX_rule,
  /*  305 */  vecD_rule,
  /*  306 */  vecX_rule,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  0,
  /*  312 */  iRegI_rule,
  /*  313 */  iRegL_rule,
  /*  314 */  iRegI_rule,
  /*  315 */  iRegL_rule,
  /*  316 */  iRegL_rule,
  /*  317 */  iRegI_rule,
  /*  318 */  iRegI_rule,
  /*  319 */  iRegL_rule,
  /*  320 */  iRegI_rule,
  /*  321 */  iRegI_rule,
  /*  322 */  iRegL_rule,
  /*  323 */  iRegL_rule,
  /*  324 */  iRegL_rule,
  /*  325 */  iRegI_rule,
  /*  326 */  iRegI_rule,
  /*  327 */  iRegI_rule,
  /*  328 */  iRegI_rule,
  /*  329 */  iRegI_rule,
  /*  330 */  iRegL_rule,
  /*  331 */  iRegL_rule,
  /*  332 */  iRegL_rule,
  /*  333 */  iRegL_rule,
  /*  334 */  iRegL_rule,
  /*  335 */  iRegL_rule,
  /*  336 */  iRegLd_rule,
  /*  337 */  iRegL_rule,
  /*  338 */  iRegL_rule,
  /*  339 */  iRegL_rule,
  /*  340 */  iRegL_rule,
  /*  341 */  iRegI_rule,
  /*  342 */  iRegP_rule,
  /*  343 */  iRegP_rule,
  /*  344 */  regD_rule,
  /*  345 */  regD_low_rule,
  /*  346 */  regF_rule,
  /*  347 */  Universe_rule,
  /*  348 */  Universe_rule,
  /*  349 */  Universe_rule,
  /*  350 */  Universe_rule,
  /*  351 */  Universe_rule,
  /*  352 */  Universe_rule,
  /*  353 */  Universe_rule,
  /*  354 */  Universe_rule,
  /*  355 */  Universe_rule,
  /*  356 */  Universe_rule,
  /*  357 */  Universe_rule,
  /*  358 */  Universe_rule,
  /*  359 */  Universe_rule,
  /*  360 */  Universe_rule,
  /*  361 */  Universe_rule,
  /*  362 */  Universe_rule,
  /*  363 */  Universe_rule,
  /*  364 */  Universe_rule,
  /*  365 */  Universe_rule,
  /*  366 */  Universe_rule,
  /*  367 */  Universe_rule,
  /*  368 */  Universe_rule,
  /*  369 */  Universe_rule,
  /*  370 */  iRegI_rule,
  /*  371 */  iRegI_rule,
  /*  372 */  iRegI_rule,
  /*  373 */  iRegI_rule,
  /*  374 */  iRegI_rule,
  /*  375 */  iRegI_rule,
  /*  376 */  iRegI_rule,
  /*  377 */  iRegI_rule,
  /*  378 */  iRegI_rule,
  /*  379 */  iRegI_rule,
  /*  380 */  iRegI_rule,
  /*  381 */  iRegI_rule,
  /*  382 */  iRegP_rule,
  /*  383 */  iRegP_rule,
  /*  384 */  iRegP_rule,
  /*  385 */  iRegP_rule,
  /*  386 */  iRegP_rule,
  /*  387 */  iRegP_rule,
  /*  388 */  iRegP_rule,
  /*  389 */  iRegP_rule,
  /*  390 */  regF_rule,
  /*  391 */  regF_rule,
  /*  392 */  regF_rule,
  /*  393 */  regF_rule,
  /*  394 */  regD_rule,
  /*  395 */  regD_rule,
  /*  396 */  regD_rule,
  /*  397 */  regD_rule,
  /*  398 */  iRegL_rule,
  /*  399 */  iRegL_rule,
  /*  400 */  iRegL_rule,
  /*  401 */  iRegL_rule,
  /*  402 */  iRegL_rule,
  /*  403 */  iRegL_rule,
  /*  404 */  iRegL_rule,
  /*  405 */  iRegL_rule,
  /*  406 */  iRegL_rule,
  /*  407 */  iRegL_rule,
  /*  408 */  iRegI_rule,
  /*  409 */  iRegI_rule,
  /*  410 */  iRegI_rule,
  /*  411 */  iRegI_rule,
  /*  412 */  iRegI_rule,
  /*  413 */  iRegI_rule,
  /*  414 */  iRegI_rule,
  /*  415 */  iRegI_rule,
  /*  416 */  iRegI_rule,
  /*  417 */  iRegI_rule,
  /*  418 */  iRegI_rule,
  /*  419 */  iRegI_rule,
  /*  420 */  iRegI_rule,
  /*  421 */  iRegI_rule,
  /*  422 */  iRegP_rule,
  /*  423 */  iRegP_rule,
  /*  424 */  iRegP_rule,
  /*  425 */  iRegL_rule,
  /*  426 */  iRegL_rule,
  /*  427 */  iRegI_rule,
  /*  428 */  iRegI_rule,
  /*  429 */  iRegI_rule,
  /*  430 */  Universe_rule,
  /*  431 */  Universe_rule,
  /*  432 */  iRegI_rule,
  /*  433 */  iRegI_rule,
  /*  434 */  Universe_rule,
  /*  435 */  Universe_rule,
  /*  436 */  iRegLd_rule,
  /*  437 */  iRegLd_rule,
  /*  438 */  iRegI_rule,
  /*  439 */  iRegLd_rule,
  /*  440 */  iRegP_rule,
  /*  441 */  iRegI_rule,
  /*  442 */  iRegI_rule,
  /*  443 */  iRegI_rule,
  /*  444 */  iRegI_rule,
  /*  445 */  iRegI_rule,
  /*  446 */  iRegI_rule,
  /*  447 */  iRegI_rule,
  /*  448 */  iRegI_rule,
  /*  449 */  iRegI_rule,
  /*  450 */  iRegI_rule,
  /*  451 */  iRegI_rule,
  /*  452 */  iRegI_rule,
  /*  453 */  iRegI_rule,
  /*  454 */  iRegI_rule,
  /*  455 */  iRegI_rule,
  /*  456 */  iRegI_rule,
  /*  457 */  iRegL_rule,
  /*  458 */  iRegL_rule,
  /*  459 */  iRegL_rule,
  /*  460 */  iRegI_rule,
  /*  461 */  0,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  iRegL_rule,
  /*  465 */  R1RegI_rule,
  /*  466 */  R0R1RegL_rule,
  /*  467 */  R0RegI_rule,
  /*  468 */  R0R1RegL_rule,
  /*  469 */  iRegI_rule,
  /*  470 */  iRegI_rule,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  iRegL_rule,
  /*  475 */  iRegL_rule,
  /*  476 */  iRegL_rule,
  /*  477 */  iRegI_rule,
  /*  478 */  iRegI_rule,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  iRegL_rule,
  /*  483 */  iRegL_rule,
  /*  484 */  iRegL_rule,
  /*  485 */  iRegI_rule,
  /*  486 */  iRegI_rule,
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  iRegL_rule,
  /*  491 */  iRegL_rule,
  /*  492 */  iRegL_rule,
  /*  493 */  iRegI_rule,
  /*  494 */  regF_rule,
  /*  495 */  regD_rule,
  /*  496 */  regF_rule,
  /*  497 */  regD_rule,
  /*  498 */  regF_rule,
  /*  499 */  regD_rule,
  /*  500 */  regF_rule,
  /*  501 */  regD_rule,
  /*  502 */  regF_rule,
  /*  503 */  regD_rule,
  /*  504 */  iRegI_rule,
  /*  505 */  iRegI_rule,
  /*  506 */  iRegI_rule,
  /*  507 */  iRegI_rule,
  /*  508 */  iRegI_rule,
  /*  509 */  iRegI_rule,
  /*  510 */  iRegI_rule,
  /*  511 */  iRegI_rule,
  /*  512 */  iRegI_rule,
  /*  513 */  iRegI_rule,
  /*  514 */  iRegI_rule,
  /*  515 */  iRegI_rule,
  /*  516 */  iRegI_rule,
  /*  517 */  iRegI_rule,
  /*  518 */  iRegI_rule,
  /*  519 */  iRegL_rule,
  /*  520 */  iRegL_rule,
  /*  521 */  iRegI_rule,
  /*  522 */  iRegI_rule,
  /*  523 */  iRegI_rule,
  /*  524 */  iRegI_rule,
  /*  525 */  iRegI_rule,
  /*  526 */  iRegI_rule,
  /*  527 */  iRegI_rule,
  /*  528 */  iRegI_rule,
  /*  529 */  iRegI_rule,
  /*  530 */  iRegI_rule,
  /*  531 */  iRegI_rule,
  /*  532 */  iRegI_rule,
  /*  533 */  iRegI_rule,
  /*  534 */  iRegI_rule,
  /*  535 */  iRegL_rule,
  /*  536 */  iRegL_rule,
  /*  537 */  iRegI_rule,
  /*  538 */  iRegI_rule,
  /*  539 */  iRegI_rule,
  /*  540 */  iRegI_rule,
  /*  541 */  iRegI_rule,
  /*  542 */  iRegI_rule,
  /*  543 */  iRegI_rule,
  /*  544 */  iRegI_rule,
  /*  545 */  iRegI_rule,
  /*  546 */  iRegI_rule,
  /*  547 */  iRegI_rule,
  /*  548 */  iRegI_rule,
  /*  549 */  iRegI_rule,
  /*  550 */  iRegI_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  iRegL_rule,
  /*  553 */  iRegI_rule,
  /*  554 */  iRegI_rule,
  /*  555 */  iRegI_rule,
  /*  556 */  iRegI_rule,
  /*  557 */  iRegI_rule,
  /*  558 */  iRegI_rule,
  /*  559 */  iRegI_rule,
  /*  560 */  iRegI_rule,
  /*  561 */  iRegI_rule,
  /*  562 */  iRegI_rule,
  /*  563 */  iRegI_rule,
  /*  564 */  iRegI_rule,
  /*  565 */  iRegI_rule,
  /*  566 */  iRegI_rule,
  /*  567 */  regF_rule,
  /*  568 */  iRegI_rule,
  /*  569 */  R0R1RegL_rule,
  /*  570 */  regD_rule,
  /*  571 */  iRegI_rule,
  /*  572 */  R0R1RegL_rule,
  /*  573 */  regD_low_rule,
  /*  574 */  regF_rule,
  /*  575 */  iRegL_rule,
  /*  576 */  iRegL_rule,
  /*  577 */  iRegL_rule,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  regD_rule,
  /*  587 */  iRegI_rule,
  /*  588 */  iRegI_rule,
  /*  589 */  0,
  /*  590 */  iRegI_rule,
  /*  591 */  0,
  /*  592 */  iRegI_rule,
  /*  593 */  iRegI_rule,
  /*  594 */  iRegI_rule,
  /*  595 */  iRegI_rule,
  /*  596 */  iRegI_rule,
  /*  597 */  Universe_rule,
  /*  598 */  Universe_rule,
  /*  599 */  Universe_rule,
  /*  600 */  Universe_rule,
  /*  601 */  Universe_rule,
  /*  602 */  Universe_rule,
  /*  603 */  Universe_rule,
  /*  604 */  Universe_rule,
  /*  605 */  Universe_rule,
  /*  606 */  Universe_rule,
  /*  607 */  Universe_rule,
  /*  608 */  Universe_rule,
  /*  609 */  Universe_rule,
  /*  610 */  iRegI_rule,
  /*  611 */  iRegL_rule,
  /*  612 */  iRegL_rule,
  /*  613 */  iRegL_rule,
  /*  614 */  iRegL_rule,
  /*  615 */  iRegL_rule,
  /*  616 */  iRegL_rule,
  /*  617 */  iRegL_rule,
  /*  618 */  iRegL_rule,
  /*  619 */  iRegL_rule,
  /*  620 */  iRegI_rule,
  /*  621 */  iRegI_rule,
  /*  622 */  iRegI_rule,
  /*  623 */  iRegI_rule,
  /*  624 */  iRegI_rule,
  /*  625 */  iRegI_rule,
  /*  626 */  iRegI_rule,
  /*  627 */  iRegI_rule,
  /*  628 */  iRegI_rule,
  /*  629 */  iRegI_rule,
  /*  630 */  iRegI_rule,
  /*  631 */  iRegI_rule,
  /*  632 */  iRegI_rule,
  /*  633 */  iRegI_rule,
  /*  634 */  iRegI_rule,
  /*  635 */  iRegI_rule,
  /*  636 */  iRegI_rule,
  /*  637 */  iRegI_rule,
  /*  638 */  iRegP_rule,
  /*  639 */  iRegP_rule,
  /*  640 */  iRegP_rule,
  /*  641 */  iRegP_rule,
  /*  642 */  iRegP_rule,
  /*  643 */  iRegP_rule,
  /*  644 */  iRegP_rule,
  /*  645 */  iRegP_rule,
  /*  646 */  iRegP_rule,
  /*  647 */  iRegP_rule,
  /*  648 */  iRegP_rule,
  /*  649 */  iRegP_rule,
  /*  650 */  regF_rule,
  /*  651 */  regF_rule,
  /*  652 */  regF_rule,
  /*  653 */  regD_rule,
  /*  654 */  regD_rule,
  /*  655 */  regD_rule,
  /*  656 */  Universe_rule,
  /*  657 */  Universe_rule,
  /*  658 */  Universe_rule,
  /*  659 */  Universe_rule,
  /*  660 */  Universe_rule,
  /*  661 */  Universe_rule,
  /*  662 */  Universe_rule,
  /*  663 */  Universe_rule,
  /*  664 */  Universe_rule,
  /*  665 */  Universe_rule,
  /*  666 */  RExceptionRegP_rule,
  /*  667 */  Universe_rule,
  /*  668 */  Universe_rule,
  /*  669 */  R0RegP_rule,
  /*  670 */  Universe_rule,
  /*  671 */  iRegI_rule,
  /*  672 */  iRegI_rule,
  /*  673 */  iRegI_rule,
  /*  674 */  iRegI_rule,
  /*  675 */  iRegI_rule,
  /*  676 */  iRegI_rule,
  /*  677 */  iRegL_rule,
  /*  678 */  iRegI_rule,
  /*  679 */  iRegI_rule,
  /*  680 */  vecD_rule,
  /*  681 */  vecX_rule,
  /*  682 */  Universe_rule,
  /*  683 */  Universe_rule,
  /*  684 */  vecD_rule,
  /*  685 */  vecD_rule,
  /*  686 */  vecD_rule,
  /*  687 */  vecD_rule,
  /*  688 */  vecD_rule,
  /*  689 */  vecX_rule,
  /*  690 */  vecD_rule,
  /*  691 */  vecD_rule,
  /*  692 */  vecX_rule,
  /*  693 */  vecD_rule,
  /*  694 */  vecX_rule,
  /*  695 */  vecD_rule,
  /*  696 */  vecX_rule,
  /*  697 */  vecX_rule,
  /*  698 */  vecD_rule,
  /*  699 */  vecD_rule,
  /*  700 */  vecX_rule,
  /*  701 */  vecX_rule,
  /*  702 */  vecX_rule,
  /*  703 */  vecD_rule,
  /*  704 */  vecX_rule,
  /*  705 */  vecD_rule,
  /*  706 */  vecX_rule,
  /*  707 */  vecD_rule,
  /*  708 */  vecX_rule,
  /*  709 */  vecX_rule,
  /*  710 */  vecD_rule,
  /*  711 */  vecD_rule,
  /*  712 */  vecX_rule,
  /*  713 */  vecX_rule,
  /*  714 */  vecX_rule,
  /*  715 */  vecD_rule,
  /*  716 */  vecX_rule,
  /*  717 */  vecD_rule,
  /*  718 */  vecX_rule,
  /*  719 */  vecD_rule,
  /*  720 */  vecD_rule,
  /*  721 */  vecX_rule,
  /*  722 */  vecX_rule,
  /*  723 */  vecX_rule,
  /*  724 */  vecD_rule,
  /*  725 */  vecX_rule,
  /*  726 */  vecX_rule,
  /*  727 */  0,
  /*  728 */  0,
  /*  729 */  0,
  /*  730 */  0,
  /*  731 */  0,
  /*  732 */  0,
  /*  733 */  0,
  /*  734 */  vecD_rule,
  /*  735 */  vecX_rule,
  /*  736 */  vecD_rule,
  /*  737 */  vecX_rule,
  /*  738 */  vecD_rule,
  /*  739 */  vecX_rule,
  /*  740 */  vecD_rule,
  /*  741 */  vecX_rule,
  /*  742 */  vecD_rule,
  /*  743 */  vecX_rule,
  /*  744 */  vecD_rule,
  /*  745 */  vecX_rule,
  /*  746 */  vecX_rule,
  /*  747 */  vecX_rule,
  /*  748 */  vecD_rule,
  /*  749 */  vecD_rule,
  /*  750 */  vecX_rule,
  /*  751 */  vecX_rule,
  /*  752 */  vecD_rule,
  /*  753 */  vecX_rule,
  /*  754 */  vecD_rule,
  /*  755 */  vecD_rule,
  /*  756 */  vecX_rule,
  /*  757 */  vecX_rule,
  /*  758 */  vecD_rule,
  /*  759 */  vecX_rule,
  /*  760 */  vecX_rule,
  /*  761 */  vecX_rule,
  /*  762 */  vecX_rule,
  /*  763 */  0,
  /*  764 */  0,
  /*  765 */  0,
  /*  766 */  0,
  /*  767 */  0,
  /*  768 */  0,
  /*  769 */  0,
  /*  770 */  vecD_rule,
  /*  771 */  vecD_rule,
  /*  772 */  vecX_rule,
  /*  773 */  vecX_rule,
  /*  774 */  vecD_rule,
  /*  775 */  vecX_rule,
  /*  776 */  vecD_rule,
  /*  777 */  vecD_rule,
  /*  778 */  vecX_rule,
  /*  779 */  vecX_rule,
  /*  780 */  vecD_rule,
  /*  781 */  vecX_rule,
  /*  782 */  vecD_rule,
  /*  783 */  vecD_rule,
  /*  784 */  vecX_rule,
  /*  785 */  vecX_rule,
  /*  786 */  vecD_rule,
  /*  787 */  vecX_rule,
  /*  788 */  vecX_rule,
  /*  789 */  vecX_rule,
  /*  790 */  vecX_rule,
  /*  791 */  vecD_rule,
  /*  792 */  vecX_rule,
  /*  793 */  vecD_rule,
  /*  794 */  vecX_rule,
  /*  795 */  vecD_rule,
  /*  796 */  vecX_rule,
  // last instruction
  0 // no trailing comma
};

const        int   leftOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  sp_ptr_RegP_rule,
  /*  103 */  sp_ptr_RegP_rule,
  /*  104 */  sp_ptr_RegP_rule,
  /*  105 */  sp_ptr_RegP_rule,
  /*  106 */  sp_ptr_RegP_rule,
  /*  107 */  iRegP_rule,
  /*  108 */  iRegP_rule,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  iRegI_rule,
  // last operand
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  // last operand class
  /*  133 */  iRegI_rule,
  /*  134 */  memoryB_rule,
  /*  135 */  memoryB_rule,
  /*  136 */  _LoadUB_memoryB__rule,
  /*  137 */  memoryS_rule,
  /*  138 */  _LoadS_memoryS__rule,
  /*  139 */  memoryB_rule,
  /*  140 */  _LoadUS_memoryB__rule,
  /*  141 */  memoryS_rule,
  /*  142 */  _LoadUS_memoryB__rule,
  /*  143 */  _LoadUS_memoryS__rule,
  /*  144 */  memoryS_rule,
  /*  145 */  _LoadI_memoryS__rule,
  /*  146 */  memoryB_rule,
  /*  147 */  _LoadI_memoryS__rule,
  /*  148 */  memoryI_rule,
  /*  149 */  _LoadI_memoryB__rule,
  /*  150 */  _LoadI_memoryS__rule,
  /*  151 */  _LoadI_memoryI__rule,
  /*  152 */  _LoadI_memoryI__rule,
  /*  153 */  _LoadI_memoryI__rule,
  /*  154 */  cmpOpP_rule,
  /*  155 */  iRegI_rule,
  /*  156 */  iRegI_rule,
  /*  157 */  iRegI_rule,
  /*  158 */  cmpOp_rule,
  /*  159 */  cmpOp0_rule,
  /*  160 */  cmpOpU_rule,
  /*  161 */  iRegP_rule,
  /*  162 */  iRegP_rule,
  /*  163 */  regF_rule,
  /*  164 */  regD_rule,
  /*  165 */  iRegL_rule,
  /*  166 */  iRegL_rule,
  /*  167 */  iRegL_rule,
  /*  168 */  iRegI_rule,
  /*  169 */  iRegI_rule,
  /*  170 */  iRegI_rule,
  /*  171 */  iRegI_rule,
  /*  172 */  iRegI_rule,
  /*  173 */  iRegL_rule,
  /*  174 */  iRegP_rule,
  /*  175 */  regF_rule,
  /*  176 */  _ConvF2D_regF__rule,
  /*  177 */  iRegI_rule,
  /*  178 */  _CmpLTMask_iRegI_iRegI_rule,
  /*  179 */  iRegI_rule,
  /*  180 */  iRegI_rule,
  /*  181 */  _CmpLTMask_iRegI_aimmI_rule,
  /*  182 */  iRegI_rule,
  /*  183 */  iRegI_rule,
  /*  184 */  iRegI_rule,
  /*  185 */  iRegL_rule,
  /*  186 */  iRegI_rule,
  /*  187 */  iRegI_rule,
  /*  188 */  _LShiftI_iRegI_iRegI_rule,
  /*  189 */  iRegI_rule,
  /*  190 */  _LShiftI_iRegI_immU5_rule,
  /*  191 */  iRegI_rule,
  /*  192 */  _RShiftI_iRegI_iRegI_rule,
  /*  193 */  iRegI_rule,
  /*  194 */  _RShiftI_iRegI_immU5_rule,
  /*  195 */  iRegI_rule,
  /*  196 */  _URShiftI_iRegI_iRegI_rule,
  /*  197 */  iRegI_rule,
  /*  198 */  _URShiftI_iRegI_immU5_rule,
  /*  199 */  iRegI_rule,
  /*  200 */  cmpOpL_rule,
  /*  201 */  cmpOpUL_rule,
  /*  202 */  cmpOpL_rule,
  /*  203 */  cmpOpL_commute_rule,
  /*  204 */  cmpOpUL_commute_rule,
  /*  205 */  iRegL_rule,
  /*  206 */  cmpOpUL_rule,
  /*  207 */  immI_rule,
  /*  208 */  immI_rule,
  // last internally defined operand
  /*  209 */  immI_rule,
  /*  210 */  immIRot_rule,
  /*  211 */  immIRotn_rule,
  /*  212 */  immI16_rule,
  /*  213 */  immP_rule,
  /*  214 */  immL_rule,
  /*  215 */  immL16_rule,
  /*  216 */  imm8F_rule,
  /*  217 */  immF_rule,
  /*  218 */  imm8D_rule,
  /*  219 */  immD_rule,
  /*  220 */  iRegI_rule,
  /*  221 */  iRegP_rule,
  /*  222 */  0,
  /*  223 */  iRegP_rule,
  /*  224 */  iRegP_rule,
  /*  225 */  iRegI_rule,
  /*  226 */  iRegL_rule,
  /*  227 */  regF_rule,
  /*  228 */  regD_rule,
  /*  229 */  vecD_rule,
  /*  230 */  vecX_rule,
  /*  231 */  regD_rule,
  /*  232 */  regF_rule,
  /*  233 */  regF_rule,
  /*  234 */  regD_rule,
  /*  235 */  regF_rule,
  /*  236 */  iRegI_rule,
  /*  237 */  regD_rule,
  /*  238 */  iRegL_rule,
  /*  239 */  0,
  /*  240 */  0,
  /*  241 */  iRegI_rule,
  /*  242 */  iRegI_rule,
  /*  243 */  iRegI_rule,
  /*  244 */  iRegI_rule,
  /*  245 */  _AndI_iRegI_iRegI_rule,
  /*  246 */  _AndI_iRegI__LShiftI_iRegI_iRegI_rule,
  /*  247 */  _AndI__LShiftI_iRegI_iRegI_iRegI_rule,
  /*  248 */  _AndI_iRegI__LShiftI_iRegI_immU5_rule,
  /*  249 */  _AndI__LShiftI_iRegI_immU5_iRegI_rule,
  /*  250 */  _AndI_iRegI__RShiftI_iRegI_iRegI_rule,
  /*  251 */  _AndI__RShiftI_iRegI_iRegI_iRegI_rule,
  /*  252 */  _AndI_iRegI__RShiftI_iRegI_immU5_rule,
  /*  253 */  _AndI__RShiftI_iRegI_immU5_iRegI_rule,
  /*  254 */  _AndI_iRegI__URShiftI_iRegI_iRegI_rule,
  /*  255 */  _AndI__URShiftI_iRegI_iRegI_iRegI_rule,
  /*  256 */  _AndI_iRegI__URShiftI_iRegI_immU5_rule,
  /*  257 */  _AndI__URShiftI_iRegI_immU5_iRegI_rule,
  /*  258 */  _AndI_iRegI_limmI_rule,
  /*  259 */  iRegL_rule,
  /*  260 */  iRegL_rule,
  /*  261 */  iRegL_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  iRegL_rule,
  /*  264 */  iRegL_rule,
  /*  265 */  iRegL_rule,
  /*  266 */  iRegL_rule,
  /*  267 */  iRegL_rule,
  /*  268 */  iRegL_rule,
  /*  269 */  iRegL_rule,
  /*  270 */  iRegL_rule,
  /*  271 */  iRegI_rule,
  /*  272 */  iRegP_rule,
  /*  273 */  iRegP_rule,
  /*  274 */  regF_rule,
  /*  275 */  regF_rule,
  /*  276 */  regD_rule,
  /*  277 */  regD_rule,
  /*  278 */  iRegP_rule,
  /*  279 */  iRegP_rule,
  /*  280 */  iRegI_rule,
  /*  281 */  iRegI_rule,
  /*  282 */  iRegI_rule,
  /*  283 */  immU8_rule,
  /*  284 */  immU8_rule,
  /*  285 */  iRegI_rule,
  /*  286 */  iRegI_rule,
  /*  287 */  immU8_rule,
  /*  288 */  immU8_rule,
  /*  289 */  iRegI_rule,
  /*  290 */  iRegI_rule,
  /*  291 */  iRegI_rule,
  /*  292 */  iRegI_rule,
  /*  293 */  immU8_rule,
  /*  294 */  immU8_rule,
  /*  295 */  iRegL_rule,
  /*  296 */  iRegI_rule,
  /*  297 */  regF_rule,
  /*  298 */  regF_rule,
  /*  299 */  regF_rule,
  /*  300 */  regD_rule,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  iRegI_rule,
  /*  304 */  iRegI_rule,
  /*  305 */  iRegI_rule,
  /*  306 */  iRegI_rule,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  0,
  /*  312 */  memoryB_rule,
  /*  313 */  _LoadB_memoryB__rule,
  /*  314 */  memoryB_rule,
  /*  315 */  _LoadUB_memoryB__rule,
  /*  316 */  _AndI__LoadUB_memoryB__limmIlow8_rule,
  /*  317 */  memoryS_rule,
  /*  318 */  _LShiftI__LoadS_memoryS__immI_24_rule,
  /*  319 */  _LoadS_memoryS__rule,
  /*  320 */  memoryS_rule,
  /*  321 */  _LShiftI__LoadUS_memoryB__immI_24_rule,
  /*  322 */  _LoadUS_memoryS__rule,
  /*  323 */  _AndI__LoadUS_memoryB__immI_255_rule,
  /*  324 */  _AndI__LoadUS_memoryS__limmI_rule,
  /*  325 */  memoryI_rule,
  /*  326 */  _LShiftI__LoadI_memoryS__immI_24_rule,
  /*  327 */  _LoadI_memoryB__rule,
  /*  328 */  _LShiftI__LoadI_memoryS__immI_16_rule,
  /*  329 */  _LoadI_memoryS__rule,
  /*  330 */  _LoadI_memoryI__rule,
  /*  331 */  _AndI__LoadI_memoryB__immI_255_rule,
  /*  332 */  _AndI__LoadI_memoryS__immI_65535_rule,
  /*  333 */  _AndI__LoadI_memoryI__limmU31_rule,
  /*  334 */  _AndI__LoadI_memoryI__immU31_rule,
  /*  335 */  _ConvI2L__LoadI_memoryI___rule,
  /*  336 */  memoryL_rule,
  /*  337 */  memorylong_rule,
  /*  338 */  indirect_rule,
  /*  339 */  memoryD_rule,
  /*  340 */  memorylong_rule,
  /*  341 */  memoryI_rule,
  /*  342 */  memoryP_rule,
  /*  343 */  memoryI_rule,
  /*  344 */  memoryD_rule,
  /*  345 */  memoryF2_rule,
  /*  346 */  memoryF_rule,
  /*  347 */  memoryP_rule,
  /*  348 */  memoryP_rule,
  /*  349 */  memoryB_rule,
  /*  350 */  memoryB_rule,
  /*  351 */  memoryS_rule,
  /*  352 */  memoryI_rule,
  /*  353 */  memoryL_rule,
  /*  354 */  memorylong_rule,
  /*  355 */  indirect_rule,
  /*  356 */  memoryD_rule,
  /*  357 */  memoryP_rule,
  /*  358 */  memoryD_rule,
  /*  359 */  memoryF_rule,
  /*  360 */  0,
  /*  361 */  0,
  /*  362 */  0,
  /*  363 */  0,
  /*  364 */  0,
  /*  365 */  0,
  /*  366 */  0,
  /*  367 */  0,
  /*  368 */  0,
  /*  369 */  0,
  /*  370 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  371 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  372 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  373 */  _Binary_cmpOp_flagsReg_rule,
  /*  374 */  _Binary_cmpOp_flagsReg_rule,
  /*  375 */  _Binary_cmpOp_flagsReg_rule,
  /*  376 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  377 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  378 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  379 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  380 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  381 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  382 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  383 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  384 */  _Binary_cmpOp_flagsReg_rule,
  /*  385 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  386 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  387 */  _Binary_cmpOp_flagsReg_rule,
  /*  388 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  389 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  390 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  391 */  _Binary_cmpOp_flagsReg_rule,
  /*  392 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  393 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  394 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  395 */  _Binary_cmpOp_flagsReg_rule,
  /*  396 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  397 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  398 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  399 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  400 */  _Binary_cmpOpP_flagsRegP_rule,
  /*  401 */  _Binary_cmpOp_flagsReg_rule,
  /*  402 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  403 */  _Binary_cmpOp_flagsReg_rule,
  /*  404 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  405 */  _Binary_cmpOp_flagsReg_rule,
  /*  406 */  _Binary_cmpOp0_flagsReg_EQNELTGE_rule,
  /*  407 */  _Binary_cmpOpU_flagsRegU_rule,
  /*  408 */  iRegI_rule,
  /*  409 */  _LShiftI_iRegI_iRegI_rule,
  /*  410 */  iRegI_rule,
  /*  411 */  _LShiftI_iRegI_immU5_rule,
  /*  412 */  iRegI_rule,
  /*  413 */  _RShiftI_iRegI_iRegI_rule,
  /*  414 */  iRegI_rule,
  /*  415 */  _RShiftI_iRegI_immU5_rule,
  /*  416 */  iRegI_rule,
  /*  417 */  _URShiftI_iRegI_iRegI_rule,
  /*  418 */  iRegI_rule,
  /*  419 */  _URShiftI_iRegI_immU5_rule,
  /*  420 */  iRegI_rule,
  /*  421 */  iRegI_rule,
  /*  422 */  iRegP_rule,
  /*  423 */  iRegP_rule,
  /*  424 */  iRegP_rule,
  /*  425 */  iRegL_rule,
  /*  426 */  iRegL_rule,
  /*  427 */  memoryex_rule,
  /*  428 */  memoryex_rule,
  /*  429 */  memoryex_rule,
  /*  430 */  memoryex_rule,
  /*  431 */  memoryex_rule,
  /*  432 */  memoryex_rule,
  /*  433 */  memoryex_rule,
  /*  434 */  memoryex_rule,
  /*  435 */  memoryex_rule,
  /*  436 */  memoryex_rule,
  /*  437 */  memoryex_rule,
  /*  438 */  memoryex_rule,
  /*  439 */  memoryex_rule,
  /*  440 */  memoryex_rule,
  /*  441 */  iRegI_rule,
  /*  442 */  iRegI_rule,
  /*  443 */  iRegI_rule,
  /*  444 */  iRegI_rule,
  /*  445 */  iRegI_rule,
  /*  446 */  iRegI_rule,
  /*  447 */  iRegI_rule,
  /*  448 */  _LShiftI_iRegI_iRegI_rule,
  /*  449 */  _LShiftI_iRegI_immU5_rule,
  /*  450 */  _RShiftI_iRegI_iRegI_rule,
  /*  451 */  _RShiftI_iRegI_immU5_rule,
  /*  452 */  _URShiftI_iRegI_iRegI_rule,
  /*  453 */  _URShiftI_iRegI_immU5_rule,
  /*  454 */  iRegI_rule,
  /*  455 */  iRegI_rule,
  /*  456 */  immIRot_rule,
  /*  457 */  iRegL_rule,
  /*  458 */  iRegL_rule,
  /*  459 */  immL0_rule,
  /*  460 */  iRegI_rule,
  /*  461 */  0,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  iRegL_rule,
  /*  465 */  R0RegI_rule,
  /*  466 */  R2R3RegL_rule,
  /*  467 */  R0RegI_rule,
  /*  468 */  R2R3RegL_rule,
  /*  469 */  iRegI_rule,
  /*  470 */  iRegI_rule,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  iRegL_rule,
  /*  475 */  iRegL_rule,
  /*  476 */  iRegL_rule,
  /*  477 */  iRegI_rule,
  /*  478 */  iRegI_rule,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  iRegL_rule,
  /*  483 */  iRegL_rule,
  /*  484 */  iRegL_rule,
  /*  485 */  iRegI_rule,
  /*  486 */  iRegI_rule,
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  iRegL_rule,
  /*  491 */  iRegL_rule,
  /*  492 */  iRegL_rule,
  /*  493 */  _CastP2X_iRegP__rule,
  /*  494 */  regF_rule,
  /*  495 */  regD_rule,
  /*  496 */  regF_rule,
  /*  497 */  regD_rule,
  /*  498 */  regF_rule,
  /*  499 */  regD_rule,
  /*  500 */  regF_rule,
  /*  501 */  regD_rule,
  /*  502 */  _SqrtD__ConvF2D_regF___rule,
  /*  503 */  regD_rule,
  /*  504 */  iRegI_rule,
  /*  505 */  iRegI_rule,
  /*  506 */  _LShiftI_iRegI_iRegI_rule,
  /*  507 */  iRegI_rule,
  /*  508 */  _LShiftI_iRegI_immU5_rule,
  /*  509 */  iRegI_rule,
  /*  510 */  _RShiftI_iRegI_iRegI_rule,
  /*  511 */  iRegI_rule,
  /*  512 */  _RShiftI_iRegI_immU5_rule,
  /*  513 */  iRegI_rule,
  /*  514 */  _URShiftI_iRegI_iRegI_rule,
  /*  515 */  iRegI_rule,
  /*  516 */  _URShiftI_iRegI_immU5_rule,
  /*  517 */  iRegI_rule,
  /*  518 */  iRegI_rule,
  /*  519 */  iRegL_rule,
  /*  520 */  iRegL_rule,
  /*  521 */  iRegI_rule,
  /*  522 */  iRegI_rule,
  /*  523 */  _LShiftI_iRegI_iRegI_rule,
  /*  524 */  iRegI_rule,
  /*  525 */  _LShiftI_iRegI_immU5_rule,
  /*  526 */  iRegI_rule,
  /*  527 */  _RShiftI_iRegI_iRegI_rule,
  /*  528 */  iRegI_rule,
  /*  529 */  _RShiftI_iRegI_immU5_rule,
  /*  530 */  iRegI_rule,
  /*  531 */  _URShiftI_iRegI_iRegI_rule,
  /*  532 */  iRegI_rule,
  /*  533 */  _URShiftI_iRegI_immU5_rule,
  /*  534 */  iRegI_rule,
  /*  535 */  iRegL_rule,
  /*  536 */  iRegL_rule,
  /*  537 */  iRegI_rule,
  /*  538 */  iRegI_rule,
  /*  539 */  _LShiftI_iRegI_iRegI_rule,
  /*  540 */  iRegI_rule,
  /*  541 */  _LShiftI_iRegI_immU5_rule,
  /*  542 */  iRegI_rule,
  /*  543 */  _RShiftI_iRegI_iRegI_rule,
  /*  544 */  iRegI_rule,
  /*  545 */  _RShiftI_iRegI_immU5_rule,
  /*  546 */  iRegI_rule,
  /*  547 */  _URShiftI_iRegI_iRegI_rule,
  /*  548 */  iRegI_rule,
  /*  549 */  _URShiftI_iRegI_immU5_rule,
  /*  550 */  iRegI_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  iRegL_rule,
  /*  553 */  iRegI_rule,
  /*  554 */  iRegI_rule,
  /*  555 */  _AndI__CmpLTMask_iRegI_iRegI_iRegI_rule,
  /*  556 */  iRegI_rule,
  /*  557 */  _AndI_iRegI__CmpLTMask_iRegI_iRegI_rule,
  /*  558 */  iRegI_rule,
  /*  559 */  _AndI__CmpLTMask_iRegI_aimmI_iRegI_rule,
  /*  560 */  iRegI_rule,
  /*  561 */  _AndI_iRegI__CmpLTMask_iRegI_aimmI_rule,
  /*  562 */  iRegI_rule,
  /*  563 */  _AndI__CmpLTMask_iRegI_iRegI_iRegI_rule,
  /*  564 */  _SubI_iRegI_iRegI_rule,
  /*  565 */  _AndI_iRegI__CmpLTMask_iRegI_iRegI_rule,
  /*  566 */  _SubI_iRegI_iRegI_rule,
  /*  567 */  regD_rule,
  /*  568 */  regD_rule,
  /*  569 */  regD_rule,
  /*  570 */  regF_rule,
  /*  571 */  regF_rule,
  /*  572 */  regF_rule,
  /*  573 */  iRegI_rule,
  /*  574 */  iRegI_rule,
  /*  575 */  iRegI_rule,
  /*  576 */  _ConvI2L_iRegI__rule,
  /*  577 */  iRegL_rule,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  iRegL_rule,
  /*  587 */  iRegL_rule,
  /*  588 */  _RShiftL_iRegL_immI_32_63_rule,
  /*  589 */  0,
  /*  590 */  iRegI_rule,
  /*  591 */  0,
  /*  592 */  iRegI_rule,
  /*  593 */  regF_rule,
  /*  594 */  regF_rule,
  /*  595 */  regD_rule,
  /*  596 */  regD_rule,
  /*  597 */  iRegI_rule,
  /*  598 */  0,
  /*  599 */  cmpOp_rule,
  /*  600 */  cmpOp0_rule,
  /*  601 */  cmpOpU_rule,
  /*  602 */  cmpOpP_rule,
  /*  603 */  cmpOpL_rule,
  /*  604 */  cmpOpL_rule,
  /*  605 */  cmpOpL_commute_rule,
  /*  606 */  cmpOpUL_rule,
  /*  607 */  cmpOpUL_rule,
  /*  608 */  cmpOpUL_commute_rule,
  /*  609 */  cmpOp_rule,
  /*  610 */  iRegL_rule,
  /*  611 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  612 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  613 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  614 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  615 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  616 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  617 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  618 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  619 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  620 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  621 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  622 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  623 */  _Binary_cmpOpUL_flagsRegUL_EQNE_rule,
  /*  624 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  625 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  626 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  627 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  628 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  629 */  _Binary_cmpOpUL_flagsRegUL_EQNE_rule,
  /*  630 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  631 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  632 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  633 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  634 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  635 */  _Binary_cmpOpUL_flagsRegUL_EQNE_rule,
  /*  636 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  637 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  638 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  639 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  640 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  641 */  _Binary_cmpOpUL_flagsRegUL_EQNE_rule,
  /*  642 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  643 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  644 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  645 */  _Binary_cmpOpUL_flagsRegUL_LTGE_rule,
  /*  646 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  647 */  _Binary_cmpOpUL_flagsRegUL_EQNE_rule,
  /*  648 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  649 */  _Binary_cmpOpUL_commute_flagsRegUL_LEGT_rule,
  /*  650 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  651 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  652 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  653 */  _Binary_cmpOpL_flagsRegL_LTGE_rule,
  /*  654 */  _Binary_cmpOpL_flagsRegL_EQNE_rule,
  /*  655 */  _Binary_cmpOpL_commute_flagsRegL_LEGT_rule,
  /*  656 */  iRegP_rule,
  /*  657 */  0,
  /*  658 */  0,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  IPRegP_rule,
  /*  664 */  0,
  /*  665 */  IPRegP_rule,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  R1RegP_rule,
  /*  670 */  iRegI_rule,
  /*  671 */  iRegL_rule,
  /*  672 */  iRegI_rule,
  /*  673 */  iRegL_rule,
  /*  674 */  iRegI_rule,
  /*  675 */  iRegL_rule,
  /*  676 */  iRegI_rule,
  /*  677 */  iRegL_rule,
  /*  678 */  iRegI_rule,
  /*  679 */  iRegI_rule,
  /*  680 */  memoryD_rule,
  /*  681 */  memoryvld_rule,
  /*  682 */  memoryD_rule,
  /*  683 */  memoryvld_rule,
  /*  684 */  iRegI_rule,
  /*  685 */  immI_rule,
  /*  686 */  iRegI_rule,
  /*  687 */  immI_rule,
  /*  688 */  immI_rule,
  /*  689 */  regF_rule,
  /*  690 */  immF_rule,
  /*  691 */  vecD_rule,
  /*  692 */  vecX_rule,
  /*  693 */  vecD_rule,
  /*  694 */  vecX_rule,
  /*  695 */  vecD_rule,
  /*  696 */  vecX_rule,
  /*  697 */  vecX_rule,
  /*  698 */  vecD_rule,
  /*  699 */  vecD_rule,
  /*  700 */  vecX_rule,
  /*  701 */  vecX_rule,
  /*  702 */  vecX_rule,
  /*  703 */  vecD_rule,
  /*  704 */  vecX_rule,
  /*  705 */  vecD_rule,
  /*  706 */  vecX_rule,
  /*  707 */  vecD_rule,
  /*  708 */  vecX_rule,
  /*  709 */  vecX_rule,
  /*  710 */  vecD_rule,
  /*  711 */  vecD_rule,
  /*  712 */  vecX_rule,
  /*  713 */  vecX_rule,
  /*  714 */  vecX_rule,
  /*  715 */  vecD_rule,
  /*  716 */  vecX_rule,
  /*  717 */  vecD_rule,
  /*  718 */  vecX_rule,
  /*  719 */  vecD_rule,
  /*  720 */  vecD_rule,
  /*  721 */  vecX_rule,
  /*  722 */  vecX_rule,
  /*  723 */  vecX_rule,
  /*  724 */  vecD_rule,
  /*  725 */  vecX_rule,
  /*  726 */  vecX_rule,
  /*  727 */  0,
  /*  728 */  0,
  /*  729 */  0,
  /*  730 */  0,
  /*  731 */  0,
  /*  732 */  0,
  /*  733 */  0,
  /*  734 */  vecD_rule,
  /*  735 */  vecX_rule,
  /*  736 */  vecD_rule,
  /*  737 */  vecX_rule,
  /*  738 */  vecD_rule,
  /*  739 */  vecX_rule,
  /*  740 */  vecD_rule,
  /*  741 */  vecX_rule,
  /*  742 */  vecD_rule,
  /*  743 */  vecX_rule,
  /*  744 */  vecD_rule,
  /*  745 */  vecX_rule,
  /*  746 */  vecX_rule,
  /*  747 */  vecX_rule,
  /*  748 */  vecD_rule,
  /*  749 */  vecD_rule,
  /*  750 */  vecX_rule,
  /*  751 */  vecX_rule,
  /*  752 */  vecD_rule,
  /*  753 */  vecX_rule,
  /*  754 */  vecD_rule,
  /*  755 */  vecD_rule,
  /*  756 */  vecX_rule,
  /*  757 */  vecX_rule,
  /*  758 */  vecD_rule,
  /*  759 */  vecX_rule,
  /*  760 */  vecX_rule,
  /*  761 */  vecX_rule,
  /*  762 */  vecX_rule,
  /*  763 */  0,
  /*  764 */  0,
  /*  765 */  0,
  /*  766 */  0,
  /*  767 */  0,
  /*  768 */  0,
  /*  769 */  0,
  /*  770 */  vecD_rule,
  /*  771 */  vecD_rule,
  /*  772 */  vecX_rule,
  /*  773 */  vecX_rule,
  /*  774 */  vecD_rule,
  /*  775 */  vecX_rule,
  /*  776 */  vecD_rule,
  /*  777 */  vecD_rule,
  /*  778 */  vecX_rule,
  /*  779 */  vecX_rule,
  /*  780 */  vecD_rule,
  /*  781 */  vecX_rule,
  /*  782 */  vecD_rule,
  /*  783 */  vecD_rule,
  /*  784 */  vecX_rule,
  /*  785 */  vecX_rule,
  /*  786 */  vecD_rule,
  /*  787 */  vecX_rule,
  /*  788 */  vecX_rule,
  /*  789 */  vecX_rule,
  /*  790 */  vecX_rule,
  /*  791 */  vecD_rule,
  /*  792 */  vecX_rule,
  /*  793 */  vecD_rule,
  /*  794 */  vecX_rule,
  /*  795 */  vecD_rule,
  /*  796 */  vecX_rule,
  // last instruction
  0 // no trailing comma
};

const        int   rightOp[] = {
  /*    0 */  0,
  /*    1 */  0,
  /*    2 */  0,
  /*    3 */  0,
  /*    4 */  0,
  /*    5 */  0,
  /*    6 */  0,
  /*    7 */  0,
  /*    8 */  0,
  /*    9 */  0,
  /*   10 */  0,
  /*   11 */  0,
  /*   12 */  0,
  /*   13 */  0,
  /*   14 */  0,
  /*   15 */  0,
  /*   16 */  0,
  /*   17 */  0,
  /*   18 */  0,
  /*   19 */  0,
  /*   20 */  0,
  /*   21 */  0,
  /*   22 */  0,
  /*   23 */  0,
  /*   24 */  0,
  /*   25 */  0,
  /*   26 */  0,
  /*   27 */  0,
  /*   28 */  0,
  /*   29 */  0,
  /*   30 */  0,
  /*   31 */  0,
  /*   32 */  0,
  /*   33 */  0,
  /*   34 */  0,
  /*   35 */  0,
  /*   36 */  0,
  /*   37 */  0,
  /*   38 */  0,
  /*   39 */  0,
  /*   40 */  0,
  /*   41 */  0,
  /*   42 */  0,
  /*   43 */  0,
  /*   44 */  0,
  /*   45 */  0,
  /*   46 */  0,
  /*   47 */  0,
  /*   48 */  0,
  /*   49 */  0,
  /*   50 */  0,
  /*   51 */  0,
  /*   52 */  0,
  /*   53 */  0,
  /*   54 */  0,
  /*   55 */  0,
  /*   56 */  0,
  /*   57 */  0,
  /*   58 */  0,
  /*   59 */  0,
  /*   60 */  0,
  /*   61 */  0,
  /*   62 */  0,
  /*   63 */  0,
  /*   64 */  0,
  /*   65 */  0,
  /*   66 */  0,
  /*   67 */  0,
  /*   68 */  0,
  /*   69 */  0,
  /*   70 */  0,
  /*   71 */  0,
  /*   72 */  0,
  /*   73 */  0,
  /*   74 */  0,
  /*   75 */  0,
  /*   76 */  0,
  /*   77 */  0,
  /*   78 */  0,
  /*   79 */  0,
  /*   80 */  0,
  /*   81 */  0,
  /*   82 */  0,
  /*   83 */  0,
  /*   84 */  0,
  /*   85 */  0,
  /*   86 */  0,
  /*   87 */  0,
  /*   88 */  0,
  /*   89 */  0,
  /*   90 */  0,
  /*   91 */  0,
  /*   92 */  0,
  /*   93 */  0,
  /*   94 */  0,
  /*   95 */  0,
  /*   96 */  0,
  /*   97 */  0,
  /*   98 */  0,
  /*   99 */  0,
  /*  100 */  0,
  /*  101 */  0,
  /*  102 */  immI12_rule,
  /*  103 */  immIFP_rule,
  /*  104 */  immIHD_rule,
  /*  105 */  immI10x2_rule,
  /*  106 */  immI12x2_rule,
  /*  107 */  iRegI_rule,
  /*  108 */  _LShiftI_iRegI_immU5_rule,
  /*  109 */  0,
  /*  110 */  0,
  /*  111 */  0,
  /*  112 */  0,
  /*  113 */  0,
  /*  114 */  0,
  /*  115 */  0,
  /*  116 */  0,
  /*  117 */  immU5_rule,
  // last operand
  /*  118 */  0,
  /*  119 */  0,
  /*  120 */  0,
  /*  121 */  0,
  /*  122 */  0,
  /*  123 */  0,
  /*  124 */  0,
  /*  125 */  0,
  /*  126 */  0,
  /*  127 */  0,
  /*  128 */  0,
  /*  129 */  0,
  /*  130 */  0,
  /*  131 */  0,
  /*  132 */  0,
  // last operand class
  /*  133 */  immU5_rule,
  /*  134 */  0,
  /*  135 */  0,
  /*  136 */  limmIlow8_rule,
  /*  137 */  0,
  /*  138 */  immI_24_rule,
  /*  139 */  0,
  /*  140 */  immI_24_rule,
  /*  141 */  0,
  /*  142 */  immI_255_rule,
  /*  143 */  limmI_rule,
  /*  144 */  0,
  /*  145 */  immI_24_rule,
  /*  146 */  0,
  /*  147 */  immI_16_rule,
  /*  148 */  0,
  /*  149 */  immI_255_rule,
  /*  150 */  immI_65535_rule,
  /*  151 */  limmU31_rule,
  /*  152 */  immU31_rule,
  /*  153 */  0,
  /*  154 */  flagsRegP_rule,
  /*  155 */  iRegI_rule,
  /*  156 */  immIRot_rule,
  /*  157 */  immI16_rule,
  /*  158 */  flagsReg_rule,
  /*  159 */  flagsReg_EQNELTGE_rule,
  /*  160 */  flagsRegU_rule,
  /*  161 */  iRegP_rule,
  /*  162 */  immP0_rule,
  /*  163 */  regF_rule,
  /*  164 */  regD_rule,
  /*  165 */  iRegL_rule,
  /*  166 */  immLlowRot_rule,
  /*  167 */  immL16_rule,
  /*  168 */  iRegI_rule,
  /*  169 */  iRegI_rule,
  /*  170 */  immU5_rule,
  /*  171 */  iRegI_rule,
  /*  172 */  immU5_rule,
  /*  173 */  iRegLd_rule,
  /*  174 */  0,
  /*  175 */  0,
  /*  176 */  0,
  /*  177 */  iRegI_rule,
  /*  178 */  iRegI_rule,
  /*  179 */  _CmpLTMask_iRegI_iRegI_rule,
  /*  180 */  aimmI_rule,
  /*  181 */  iRegI_rule,
  /*  182 */  _CmpLTMask_iRegI_aimmI_rule,
  /*  183 */  iRegI_rule,
  /*  184 */  0,
  /*  185 */  immI_32_63_rule,
  /*  186 */  iRegI_rule,
  /*  187 */  _LShiftI_iRegI_iRegI_rule,
  /*  188 */  iRegI_rule,
  /*  189 */  _LShiftI_iRegI_immU5_rule,
  /*  190 */  iRegI_rule,
  /*  191 */  _RShiftI_iRegI_iRegI_rule,
  /*  192 */  iRegI_rule,
  /*  193 */  _RShiftI_iRegI_immU5_rule,
  /*  194 */  iRegI_rule,
  /*  195 */  _URShiftI_iRegI_iRegI_rule,
  /*  196 */  iRegI_rule,
  /*  197 */  _URShiftI_iRegI_immU5_rule,
  /*  198 */  iRegI_rule,
  /*  199 */  limmI_rule,
  /*  200 */  flagsRegL_LTGE_rule,
  /*  201 */  flagsRegUL_LTGE_rule,
  /*  202 */  flagsRegL_EQNE_rule,
  /*  203 */  flagsRegL_LEGT_rule,
  /*  204 */  flagsRegUL_LEGT_rule,
  /*  205 */  immL0_rule,
  /*  206 */  flagsRegUL_EQNE_rule,
  /*  207 */  0,
  /*  208 */  0,
  // last internally defined operand
  /*  209 */  0,
  /*  210 */  0,
  /*  211 */  0,
  /*  212 */  0,
  /*  213 */  0,
  /*  214 */  0,
  /*  215 */  0,
  /*  216 */  0,
  /*  217 */  0,
  /*  218 */  0,
  /*  219 */  0,
  /*  220 */  0,
  /*  221 */  0,
  /*  222 */  0,
  /*  223 */  0,
  /*  224 */  0,
  /*  225 */  0,
  /*  226 */  0,
  /*  227 */  0,
  /*  228 */  0,
  /*  229 */  0,
  /*  230 */  0,
  /*  231 */  0,
  /*  232 */  0,
  /*  233 */  0,
  /*  234 */  0,
  /*  235 */  0,
  /*  236 */  0,
  /*  237 */  0,
  /*  238 */  0,
  /*  239 */  0,
  /*  240 */  0,
  /*  241 */  iRegI_rule,
  /*  242 */  iRegI_rule,
  /*  243 */  aimmIneg_rule,
  /*  244 */  aimmI_rule,
  /*  245 */  immI0_rule,
  /*  246 */  immI0_rule,
  /*  247 */  immI0_rule,
  /*  248 */  immI0_rule,
  /*  249 */  immI0_rule,
  /*  250 */  immI0_rule,
  /*  251 */  immI0_rule,
  /*  252 */  immI0_rule,
  /*  253 */  immI0_rule,
  /*  254 */  immI0_rule,
  /*  255 */  immI0_rule,
  /*  256 */  immI0_rule,
  /*  257 */  immI0_rule,
  /*  258 */  immI0_rule,
  /*  259 */  iRegL_rule,
  /*  260 */  iRegL_rule,
  /*  261 */  iRegL_rule,
  /*  262 */  iRegL_rule,
  /*  263 */  immLlowRot_rule,
  /*  264 */  immLlowRot_rule,
  /*  265 */  immLlowRot_rule,
  /*  266 */  iRegL_rule,
  /*  267 */  iRegL_rule,
  /*  268 */  immLlowRot_rule,
  /*  269 */  immLlowRot_rule,
  /*  270 */  immLlowRot_rule,
  /*  271 */  aimmU31_rule,
  /*  272 */  iRegP_rule,
  /*  273 */  immPRot_rule,
  /*  274 */  regF_rule,
  /*  275 */  immF0_rule,
  /*  276 */  regD_rule,
  /*  277 */  immD0_rule,
  /*  278 */  iRegP_rule,
  /*  279 */  iRegP_rule,
  /*  280 */  0,
  /*  281 */  0,
  /*  282 */  0,
  /*  283 */  0,
  /*  284 */  0,
  /*  285 */  0,
  /*  286 */  0,
  /*  287 */  0,
  /*  288 */  0,
  /*  289 */  0,
  /*  290 */  0,
  /*  291 */  0,
  /*  292 */  0,
  /*  293 */  0,
  /*  294 */  0,
  /*  295 */  0,
  /*  296 */  0,
  /*  297 */  0,
  /*  298 */  0,
  /*  299 */  0,
  /*  300 */  0,
  /*  301 */  0,
  /*  302 */  0,
  /*  303 */  0,
  /*  304 */  0,
  /*  305 */  0,
  /*  306 */  0,
  /*  307 */  0,
  /*  308 */  0,
  /*  309 */  0,
  /*  310 */  0,
  /*  311 */  0,
  /*  312 */  0,
  /*  313 */  0,
  /*  314 */  0,
  /*  315 */  0,
  /*  316 */  0,
  /*  317 */  0,
  /*  318 */  immI_24_rule,
  /*  319 */  0,
  /*  320 */  0,
  /*  321 */  immI_24_rule,
  /*  322 */  0,
  /*  323 */  0,
  /*  324 */  0,
  /*  325 */  0,
  /*  326 */  immI_24_rule,
  /*  327 */  immI_255_rule,
  /*  328 */  immI_16_rule,
  /*  329 */  immI_65535_rule,
  /*  330 */  0,
  /*  331 */  0,
  /*  332 */  0,
  /*  333 */  0,
  /*  334 */  0,
  /*  335 */  immL_32bits_rule,
  /*  336 */  0,
  /*  337 */  0,
  /*  338 */  0,
  /*  339 */  0,
  /*  340 */  0,
  /*  341 */  0,
  /*  342 */  0,
  /*  343 */  0,
  /*  344 */  0,
  /*  345 */  0,
  /*  346 */  0,
  /*  347 */  0,
  /*  348 */  0,
  /*  349 */  iRegI_rule,
  /*  350 */  iRegI_rule,
  /*  351 */  iRegI_rule,
  /*  352 */  iRegI_rule,
  /*  353 */  iRegLd_rule,
  /*  354 */  iRegL_rule,
  /*  355 */  iRegL_rule,
  /*  356 */  iRegL_rule,
  /*  357 */  iRegP_rule,
  /*  358 */  regD_rule,
  /*  359 */  regF_rule,
  /*  360 */  0,
  /*  361 */  0,
  /*  362 */  0,
  /*  363 */  0,
  /*  364 */  0,
  /*  365 */  0,
  /*  366 */  0,
  /*  367 */  0,
  /*  368 */  0,
  /*  369 */  0,
  /*  370 */  _Binary_iRegI_iRegI_rule,
  /*  371 */  _Binary_iRegI_immIRot_rule,
  /*  372 */  _Binary_iRegI_immI16_rule,
  /*  373 */  _Binary_iRegI_iRegI_rule,
  /*  374 */  _Binary_iRegI_immIRot_rule,
  /*  375 */  _Binary_iRegI_immI16_rule,
  /*  376 */  _Binary_iRegI_iRegI_rule,
  /*  377 */  _Binary_iRegI_immIRot_rule,
  /*  378 */  _Binary_iRegI_immI16_rule,
  /*  379 */  _Binary_iRegI_iRegI_rule,
  /*  380 */  _Binary_iRegI_immIRot_rule,
  /*  381 */  _Binary_iRegI_immI16_rule,
  /*  382 */  _Binary_iRegP_iRegP_rule,
  /*  383 */  _Binary_iRegP_immP0_rule,
  /*  384 */  _Binary_iRegP_iRegP_rule,
  /*  385 */  _Binary_iRegP_iRegP_rule,
  /*  386 */  _Binary_iRegP_iRegP_rule,
  /*  387 */  _Binary_iRegP_immP0_rule,
  /*  388 */  _Binary_iRegP_immP0_rule,
  /*  389 */  _Binary_iRegP_immP0_rule,
  /*  390 */  _Binary_regF_regF_rule,
  /*  391 */  _Binary_regF_regF_rule,
  /*  392 */  _Binary_regF_regF_rule,
  /*  393 */  _Binary_regF_regF_rule,
  /*  394 */  _Binary_regD_regD_rule,
  /*  395 */  _Binary_regD_regD_rule,
  /*  396 */  _Binary_regD_regD_rule,
  /*  397 */  _Binary_regD_regD_rule,
  /*  398 */  _Binary_iRegL_iRegL_rule,
  /*  399 */  _Binary_iRegL_immLlowRot_rule,
  /*  400 */  _Binary_iRegL_immL16_rule,
  /*  401 */  _Binary_iRegL_iRegL_rule,
  /*  402 */  _Binary_iRegL_iRegL_rule,
  /*  403 */  _Binary_iRegL_immLlowRot_rule,
  /*  404 */  _Binary_iRegL_immLlowRot_rule,
  /*  405 */  _Binary_iRegL_immL16_rule,
  /*  406 */  _Binary_iRegL_immL16_rule,
  /*  407 */  _Binary_iRegL_iRegL_rule,
  /*  408 */  iRegI_rule,
  /*  409 */  iRegI_rule,
  /*  410 */  _LShiftI_iRegI_iRegI_rule,
  /*  411 */  iRegI_rule,
  /*  412 */  _LShiftI_iRegI_immU5_rule,
  /*  413 */  iRegI_rule,
  /*  414 */  _RShiftI_iRegI_iRegI_rule,
  /*  415 */  iRegI_rule,
  /*  416 */  _RShiftI_iRegI_immU5_rule,
  /*  417 */  iRegI_rule,
  /*  418 */  _URShiftI_iRegI_iRegI_rule,
  /*  419 */  iRegI_rule,
  /*  420 */  _URShiftI_iRegI_immU5_rule,
  /*  421 */  aimmI_rule,
  /*  422 */  iRegI_rule,
  /*  423 */  shiftedX_rule,
  /*  424 */  aimmI_rule,
  /*  425 */  iRegL_rule,
  /*  426 */  immLlowRot_rule,
  /*  427 */  _Binary_iRegL_iRegLd_rule,
  /*  428 */  _Binary_iRegI_iRegI_rule,
  /*  429 */  _Binary_iRegP_iRegP_rule,
  /*  430 */  aimmI_rule,
  /*  431 */  iRegI_rule,
  /*  432 */  aimmI_rule,
  /*  433 */  iRegI_rule,
  /*  434 */  iRegL_rule,
  /*  435 */  immLlowRot_rule,
  /*  436 */  iRegL_rule,
  /*  437 */  immLlowRot_rule,
  /*  438 */  iRegI_rule,
  /*  439 */  iRegLd_rule,
  /*  440 */  iRegP_rule,
  /*  441 */  iRegI_rule,
  /*  442 */  _LShiftI_iRegI_iRegI_rule,
  /*  443 */  _LShiftI_iRegI_immU5_rule,
  /*  444 */  _RShiftI_iRegI_iRegI_rule,
  /*  445 */  _RShiftI_iRegI_immU5_rule,
  /*  446 */  _URShiftI_iRegI_iRegI_rule,
  /*  447 */  _URShiftI_iRegI_immU5_rule,
  /*  448 */  iRegI_rule,
  /*  449 */  iRegI_rule,
  /*  450 */  iRegI_rule,
  /*  451 */  iRegI_rule,
  /*  452 */  iRegI_rule,
  /*  453 */  iRegI_rule,
  /*  454 */  aimmI_rule,
  /*  455 */  aimmIneg_rule,
  /*  456 */  iRegI_rule,
  /*  457 */  iRegL_rule,
  /*  458 */  immLlowRot_rule,
  /*  459 */  iRegL_rule,
  /*  460 */  iRegI_rule,
  /*  461 */  0,
  /*  462 */  0,
  /*  463 */  0,
  /*  464 */  iRegL_rule,
  /*  465 */  R2RegI_rule,
  /*  466 */  R0R1RegL_rule,
  /*  467 */  R2RegI_rule,
  /*  468 */  R0R1RegL_rule,
  /*  469 */  iRegI_rule,
  /*  470 */  immU5_rule,
  /*  471 */  0,
  /*  472 */  0,
  /*  473 */  0,
  /*  474 */  iRegI_rule,
  /*  475 */  immU6Big_rule,
  /*  476 */  immU5_rule,
  /*  477 */  iRegI_rule,
  /*  478 */  immU5_rule,
  /*  479 */  0,
  /*  480 */  0,
  /*  481 */  0,
  /*  482 */  iRegI_rule,
  /*  483 */  immU6Big_rule,
  /*  484 */  immU5_rule,
  /*  485 */  iRegI_rule,
  /*  486 */  immU5_rule,
  /*  487 */  0,
  /*  488 */  0,
  /*  489 */  0,
  /*  490 */  iRegI_rule,
  /*  491 */  immU6Big_rule,
  /*  492 */  immU5_rule,
  /*  493 */  immU5_rule,
  /*  494 */  regF_rule,
  /*  495 */  regD_rule,
  /*  496 */  regF_rule,
  /*  497 */  regD_rule,
  /*  498 */  regF_rule,
  /*  499 */  regD_rule,
  /*  500 */  regF_rule,
  /*  501 */  regD_rule,
  /*  502 */  0,
  /*  503 */  0,
  /*  504 */  iRegI_rule,
  /*  505 */  _LShiftI_iRegI_iRegI_rule,
  /*  506 */  iRegI_rule,
  /*  507 */  _LShiftI_iRegI_immU5_rule,
  /*  508 */  iRegI_rule,
  /*  509 */  _RShiftI_iRegI_iRegI_rule,
  /*  510 */  iRegI_rule,
  /*  511 */  _RShiftI_iRegI_immU5_rule,
  /*  512 */  iRegI_rule,
  /*  513 */  _URShiftI_iRegI_iRegI_rule,
  /*  514 */  iRegI_rule,
  /*  515 */  _URShiftI_iRegI_immU5_rule,
  /*  516 */  iRegI_rule,
  /*  517 */  limmI_rule,
  /*  518 */  limmIn_rule,
  /*  519 */  iRegL_rule,
  /*  520 */  immLlowRot_rule,
  /*  521 */  iRegI_rule,
  /*  522 */  _LShiftI_iRegI_iRegI_rule,
  /*  523 */  iRegI_rule,
  /*  524 */  _LShiftI_iRegI_immU5_rule,
  /*  525 */  iRegI_rule,
  /*  526 */  _RShiftI_iRegI_iRegI_rule,
  /*  527 */  iRegI_rule,
  /*  528 */  _RShiftI_iRegI_immU5_rule,
  /*  529 */  iRegI_rule,
  /*  530 */  _URShiftI_iRegI_iRegI_rule,
  /*  531 */  iRegI_rule,
  /*  532 */  _URShiftI_iRegI_immU5_rule,
  /*  533 */  iRegI_rule,
  /*  534 */  limmI_rule,
  /*  535 */  iRegL_rule,
  /*  536 */  immLlowRot_rule,
  /*  537 */  iRegI_rule,
  /*  538 */  _LShiftI_iRegI_iRegI_rule,
  /*  539 */  iRegI_rule,
  /*  540 */  _LShiftI_iRegI_immU5_rule,
  /*  541 */  iRegI_rule,
  /*  542 */  _RShiftI_iRegI_iRegI_rule,
  /*  543 */  iRegI_rule,
  /*  544 */  _RShiftI_iRegI_immU5_rule,
  /*  545 */  iRegI_rule,
  /*  546 */  _URShiftI_iRegI_iRegI_rule,
  /*  547 */  iRegI_rule,
  /*  548 */  _URShiftI_iRegI_immU5_rule,
  /*  549 */  iRegI_rule,
  /*  550 */  limmI_rule,
  /*  551 */  iRegL_rule,
  /*  552 */  immLlowRot_rule,
  /*  553 */  iRegI_rule,
  /*  554 */  aimmI_rule,
  /*  555 */  iRegI_rule,
  /*  556 */  _AndI__CmpLTMask_iRegI_iRegI_iRegI_rule,
  /*  557 */  iRegI_rule,
  /*  558 */  _AndI_iRegI__CmpLTMask_iRegI_iRegI_rule,
  /*  559 */  iRegI_rule,
  /*  560 */  _AndI__CmpLTMask_iRegI_aimmI_iRegI_rule,
  /*  561 */  iRegI_rule,
  /*  562 */  _AndI_iRegI__CmpLTMask_iRegI_aimmI_rule,
  /*  563 */  _SubI_iRegI_iRegI_rule,
  /*  564 */  _AndI__CmpLTMask_iRegI_iRegI_iRegI_rule,
  /*  565 */  _SubI_iRegI_iRegI_rule,
  /*  566 */  _AndI_iRegI__CmpLTMask_iRegI_iRegI_rule,
  /*  567 */  0,
  /*  568 */  0,
  /*  569 */  0,
  /*  570 */  0,
  /*  571 */  0,
  /*  572 */  0,
  /*  573 */  0,
  /*  574 */  0,
  /*  575 */  0,
  /*  576 */  immL_32bits_rule,
  /*  577 */  immL_32bits_rule,
  /*  578 */  0,
  /*  579 */  0,
  /*  580 */  0,
  /*  581 */  0,
  /*  582 */  0,
  /*  583 */  0,
  /*  584 */  0,
  /*  585 */  0,
  /*  586 */  0,
  /*  587 */  0,
  /*  588 */  0,
  /*  589 */  0,
  /*  590 */  iRegI_rule,
  /*  591 */  0,
  /*  592 */  iRegI_rule,
  /*  593 */  regF_rule,
  /*  594 */  immF0_rule,
  /*  595 */  regD_rule,
  /*  596 */  immD0_rule,
  /*  597 */  0,
  /*  598 */  0,
  /*  599 */  flagsReg_rule,
  /*  600 */  flagsReg_EQNELTGE_rule,
  /*  601 */  flagsRegU_rule,
  /*  602 */  flagsRegP_rule,
  /*  603 */  flagsRegL_LTGE_rule,
  /*  604 */  flagsRegL_EQNE_rule,
  /*  605 */  flagsRegL_LEGT_rule,
  /*  606 */  flagsRegUL_LTGE_rule,
  /*  607 */  flagsRegUL_EQNE_rule,
  /*  608 */  flagsRegUL_LEGT_rule,
  /*  609 */  flagsReg_rule,
  /*  610 */  iRegL_rule,
  /*  611 */  _Binary_iRegL_iRegL_rule,
  /*  612 */  _Binary_iRegL_iRegL_rule,
  /*  613 */  _Binary_iRegL_iRegL_rule,
  /*  614 */  _Binary_iRegL_iRegL_rule,
  /*  615 */  _Binary_iRegL_iRegL_rule,
  /*  616 */  _Binary_iRegL_immL0_rule,
  /*  617 */  _Binary_iRegL_immL0_rule,
  /*  618 */  _Binary_iRegL_immL0_rule,
  /*  619 */  _Binary_iRegL_immL0_rule,
  /*  620 */  _Binary_iRegI_iRegI_rule,
  /*  621 */  _Binary_iRegI_iRegI_rule,
  /*  622 */  _Binary_iRegI_iRegI_rule,
  /*  623 */  _Binary_iRegI_iRegI_rule,
  /*  624 */  _Binary_iRegI_iRegI_rule,
  /*  625 */  _Binary_iRegI_iRegI_rule,
  /*  626 */  _Binary_iRegI_immI16_rule,
  /*  627 */  _Binary_iRegI_immI16_rule,
  /*  628 */  _Binary_iRegI_immI16_rule,
  /*  629 */  _Binary_iRegI_immI16_rule,
  /*  630 */  _Binary_iRegI_immI16_rule,
  /*  631 */  _Binary_iRegI_immI16_rule,
  /*  632 */  _Binary_iRegI_immIRot_rule,
  /*  633 */  _Binary_iRegI_immIRot_rule,
  /*  634 */  _Binary_iRegI_immIRot_rule,
  /*  635 */  _Binary_iRegI_immIRot_rule,
  /*  636 */  _Binary_iRegI_immIRot_rule,
  /*  637 */  _Binary_iRegI_immIRot_rule,
  /*  638 */  _Binary_iRegP_iRegP_rule,
  /*  639 */  _Binary_iRegP_iRegP_rule,
  /*  640 */  _Binary_iRegP_iRegP_rule,
  /*  641 */  _Binary_iRegP_iRegP_rule,
  /*  642 */  _Binary_iRegP_iRegP_rule,
  /*  643 */  _Binary_iRegP_iRegP_rule,
  /*  644 */  _Binary_iRegP_immP0_rule,
  /*  645 */  _Binary_iRegP_immP0_rule,
  /*  646 */  _Binary_iRegP_immP0_rule,
  /*  647 */  _Binary_iRegP_immP0_rule,
  /*  648 */  _Binary_iRegP_immP0_rule,
  /*  649 */  _Binary_iRegP_immP0_rule,
  /*  650 */  _Binary_regF_regF_rule,
  /*  651 */  _Binary_regF_regF_rule,
  /*  652 */  _Binary_regF_regF_rule,
  /*  653 */  _Binary_regD_regD_rule,
  /*  654 */  _Binary_regD_regD_rule,
  /*  655 */  _Binary_regD_regD_rule,
  /*  656 */  0,
  /*  657 */  0,
  /*  658 */  0,
  /*  659 */  0,
  /*  660 */  0,
  /*  661 */  0,
  /*  662 */  0,
  /*  663 */  inline_cache_regP_rule,
  /*  664 */  0,
  /*  665 */  RExceptionRegP_rule,
  /*  666 */  0,
  /*  667 */  0,
  /*  668 */  0,
  /*  669 */  R2RegP_rule,
  /*  670 */  iRegP_rule,
  /*  671 */  0,
  /*  672 */  0,
  /*  673 */  0,
  /*  674 */  0,
  /*  675 */  0,
  /*  676 */  0,
  /*  677 */  0,
  /*  678 */  0,
  /*  679 */  0,
  /*  680 */  0,
  /*  681 */  0,
  /*  682 */  vecD_rule,
  /*  683 */  vecX_rule,
  /*  684 */  0,
  /*  685 */  0,
  /*  686 */  0,
  /*  687 */  0,
  /*  688 */  0,
  /*  689 */  0,
  /*  690 */  0,
  /*  691 */  vecD_rule,
  /*  692 */  vecX_rule,
  /*  693 */  vecD_rule,
  /*  694 */  vecX_rule,
  /*  695 */  vecD_rule,
  /*  696 */  vecX_rule,
  /*  697 */  vecX_rule,
  /*  698 */  vecD_rule,
  /*  699 */  vecD_rule,
  /*  700 */  vecX_rule,
  /*  701 */  vecX_rule,
  /*  702 */  vecX_rule,
  /*  703 */  vecD_rule,
  /*  704 */  vecX_rule,
  /*  705 */  vecD_rule,
  /*  706 */  vecX_rule,
  /*  707 */  vecD_rule,
  /*  708 */  vecX_rule,
  /*  709 */  vecX_rule,
  /*  710 */  vecD_rule,
  /*  711 */  vecD_rule,
  /*  712 */  vecX_rule,
  /*  713 */  vecX_rule,
  /*  714 */  vecX_rule,
  /*  715 */  vecD_rule,
  /*  716 */  vecX_rule,
  /*  717 */  vecD_rule,
  /*  718 */  vecX_rule,
  /*  719 */  vecD_rule,
  /*  720 */  vecD_rule,
  /*  721 */  vecX_rule,
  /*  722 */  vecX_rule,
  /*  723 */  vecX_rule,
  /*  724 */  vecD_rule,
  /*  725 */  vecX_rule,
  /*  726 */  vecX_rule,
  /*  727 */  0,
  /*  728 */  0,
  /*  729 */  0,
  /*  730 */  0,
  /*  731 */  0,
  /*  732 */  0,
  /*  733 */  0,
  /*  734 */  vecD_rule,
  /*  735 */  vecX_rule,
  /*  736 */  _LShiftCntV_immI__rule,
  /*  737 */  _LShiftCntV_immI__rule,
  /*  738 */  vecD_rule,
  /*  739 */  vecX_rule,
  /*  740 */  _LShiftCntV_immI__rule,
  /*  741 */  immI_rule,
  /*  742 */  vecD_rule,
  /*  743 */  vecX_rule,
  /*  744 */  _LShiftCntV_immI__rule,
  /*  745 */  _LShiftCntV_immI__rule,
  /*  746 */  vecX_rule,
  /*  747 */  _LShiftCntV_immI__rule,
  /*  748 */  vecD_rule,
  /*  749 */  vecD_rule,
  /*  750 */  vecX_rule,
  /*  751 */  vecX_rule,
  /*  752 */  _RShiftCntV_immI__rule,
  /*  753 */  _RShiftCntV_immI__rule,
  /*  754 */  vecD_rule,
  /*  755 */  vecD_rule,
  /*  756 */  vecX_rule,
  /*  757 */  vecX_rule,
  /*  758 */  _RShiftCntV_immI__rule,
  /*  759 */  _RShiftCntV_immI__rule,
  /*  760 */  vecX_rule,
  /*  761 */  vecX_rule,
  /*  762 */  _RShiftCntV_immI__rule,
  /*  763 */  0,
  /*  764 */  0,
  /*  765 */  0,
  /*  766 */  0,
  /*  767 */  0,
  /*  768 */  0,
  /*  769 */  0,
  /*  770 */  vecD_rule,
  /*  771 */  vecD_rule,
  /*  772 */  vecX_rule,
  /*  773 */  vecX_rule,
  /*  774 */  _RShiftCntV_immI__rule,
  /*  775 */  _RShiftCntV_immI__rule,
  /*  776 */  vecD_rule,
  /*  777 */  vecD_rule,
  /*  778 */  vecX_rule,
  /*  779 */  vecX_rule,
  /*  780 */  _RShiftCntV_immI__rule,
  /*  781 */  _RShiftCntV_immI__rule,
  /*  782 */  vecD_rule,
  /*  783 */  vecD_rule,
  /*  784 */  vecX_rule,
  /*  785 */  vecX_rule,
  /*  786 */  _RShiftCntV_immI__rule,
  /*  787 */  _RShiftCntV_immI__rule,
  /*  788 */  vecX_rule,
  /*  789 */  vecX_rule,
  /*  790 */  _RShiftCntV_immI__rule,
  /*  791 */  vecD_rule,
  /*  792 */  vecX_rule,
  /*  793 */  vecD_rule,
  /*  794 */  vecX_rule,
  /*  795 */  vecD_rule,
  /*  796 */  vecX_rule,
  // last instruction
  0 // no trailing comma
};

const char        *ruleName[] = {
  /*    0 */  "UNIVERSE",
  /*    1 */  "LABEL",
  /*    2 */  "SREGI",
  /*    3 */  "SREGP",
  /*    4 */  "SREGF",
  /*    5 */  "SREGD",
  /*    6 */  "SREGL",
  /*    7 */  "METHOD",
  /*    8 */  "IMMIROT",
  /*    9 */  "IMMIROTN",
  /*   10 */  "IMMIROTNEG",
  /*   11 */  "IMMU31ROT",
  /*   12 */  "IMMPROT",
  /*   13 */  "IMMLLOWROT",
  /*   14 */  "IMMLROT2",
  /*   15 */  "IMMI12",
  /*   16 */  "IMMI10X2",
  /*   17 */  "IMMI12X2",
  /*   18 */  "IMMI",
  /*   19 */  "IMMU8",
  /*   20 */  "IMMI16",
  /*   21 */  "IMMIHD",
  /*   22 */  "IMMIFP",
  /*   23 */  "IMMU5",
  /*   24 */  "IMMU6BIG",
  /*   25 */  "IMMI0",
  /*   26 */  "IMMI_1",
  /*   27 */  "IMMI_2",
  /*   28 */  "IMMI_3",
  /*   29 */  "IMMI_4",
  /*   30 */  "IMMI_8",
  /*   31 */  "IMMU31",
  /*   32 */  "IMMI_32_63",
  /*   33 */  "IMMI_16",
  /*   34 */  "IMMI_24",
  /*   35 */  "IMMI_255",
  /*   36 */  "IMMI_65535",
  /*   37 */  "AIMMI",
  /*   38 */  "AIMMINEG",
  /*   39 */  "AIMMU31",
  /*   40 */  "LIMMI",
  /*   41 */  "LIMMILOW8",
  /*   42 */  "LIMMU31",
  /*   43 */  "LIMMIN",
  /*   44 */  "IMML_FF",
  /*   45 */  "IMML_FFFF",
  /*   46 */  "IMMP",
  /*   47 */  "IMMP0",
  /*   48 */  "IMMN",
  /*   49 */  "IMMNKLASS",
  /*   50 */  "IMMN0",
  /*   51 */  "IMML",
  /*   52 */  "IMML0",
  /*   53 */  "IMML16",
  /*   54 */  "IMML_32BITS",
  /*   55 */  "IMMD",
  /*   56 */  "IMMD0",
  /*   57 */  "IMM8D",
  /*   58 */  "IMMF",
  /*   59 */  "IMMF0",
  /*   60 */  "IMM8F",
  /*   61 */  "IREGI",
  /*   62 */  "IREGP",
  /*   63 */  "SP_PTR_REGP",
  /*   64 */  "R0REGP",
  /*   65 */  "R1REGP",
  /*   66 */  "R8REGP",
  /*   67 */  "R9REGP",
  /*   68 */  "R12REGP",
  /*   69 */  "R2REGP",
  /*   70 */  "REXCEPTIONREGP",
  /*   71 */  "RTHREADREGP",
  /*   72 */  "IPREGP",
  /*   73 */  "SPREGP",
  /*   74 */  "LRREGP",
  /*   75 */  "R0REGI",
  /*   76 */  "R1REGI",
  /*   77 */  "R2REGI",
  /*   78 */  "R3REGI",
  /*   79 */  "R12REGI",
  /*   80 */  "IREGL",
  /*   81 */  "IREGLD",
  /*   82 */  "R0R1REGL",
  /*   83 */  "R2R3REGL",
  /*   84 */  "FLAGSREG",
  /*   85 */  "FLAGSREG_EQNELTGE",
  /*   86 */  "FLAGSREGU",
  /*   87 */  "FLAGSREGP",
  /*   88 */  "FLAGSREGL_LTGE",
  /*   89 */  "FLAGSREGL_EQNE",
  /*   90 */  "FLAGSREGL_LEGT",
  /*   91 */  "FLAGSREGUL_LTGE",
  /*   92 */  "FLAGSREGUL_EQNE",
  /*   93 */  "FLAGSREGUL_LEGT",
  /*   94 */  "FLAGSREGF",
  /*   95 */  "VECD",
  /*   96 */  "VECX",
  /*   97 */  "REGD",
  /*   98 */  "REGF",
  /*   99 */  "REGD_LOW",
  /*  100 */  "INLINE_CACHE_REGP",
  /*  101 */  "INDIRECT",
  /*  102 */  "INDOFFSET12",
  /*  103 */  "INDOFFSETFP",
  /*  104 */  "INDOFFSETHD",
  /*  105 */  "INDOFFSETFPX2",
  /*  106 */  "INDOFFSET12X2",
  /*  107 */  "INDINDEX",
  /*  108 */  "INDINDEXSCALE",
  /*  109 */  "CMPOP",
  /*  110 */  "CMPOP0",
  /*  111 */  "CMPOPU",
  /*  112 */  "CMPOPP",
  /*  113 */  "CMPOPL",
  /*  114 */  "CMPOPL_COMMUTE",
  /*  115 */  "CMPOPUL",
  /*  116 */  "CMPOPUL_COMMUTE",
  /*  117 */  "SHIFTEDX",
  // last operand
  /*  118 */  "MEMORYI",
  /*  119 */  "MEMORYP",
  /*  120 */  "MEMORYF",
  /*  121 */  "MEMORYF2",
  /*  122 */  "MEMORYD",
  /*  123 */  "MEMORYFP",
  /*  124 */  "MEMORYB",
  /*  125 */  "MEMORYS",
  /*  126 */  "MEMORYL",
  /*  127 */  "MEMORYSCALEDI",
  /*  128 */  "MEMORYSCALEDP",
  /*  129 */  "MEMORYEX",
  /*  130 */  "INDINDEXMEMORY",
  /*  131 */  "MEMORYLONG",
  /*  132 */  "MEMORYVLD",
  // last operand class
  /*  133 */  "_LShiftI_iRegI_immU5",
  /*  134 */  "_LoadB_memoryB_",
  /*  135 */  "_LoadUB_memoryB_",
  /*  136 */  "_AndI__LoadUB_memoryB__limmIlow8",
  /*  137 */  "_LoadS_memoryS_",
  /*  138 */  "_LShiftI__LoadS_memoryS__immI_24",
  /*  139 */  "_LoadUS_memoryB_",
  /*  140 */  "_LShiftI__LoadUS_memoryB__immI_24",
  /*  141 */  "_LoadUS_memoryS_",
  /*  142 */  "_AndI__LoadUS_memoryB__immI_255",
  /*  143 */  "_AndI__LoadUS_memoryS__limmI",
  /*  144 */  "_LoadI_memoryS_",
  /*  145 */  "_LShiftI__LoadI_memoryS__immI_24",
  /*  146 */  "_LoadI_memoryB_",
  /*  147 */  "_LShiftI__LoadI_memoryS__immI_16",
  /*  148 */  "_LoadI_memoryI_",
  /*  149 */  "_AndI__LoadI_memoryB__immI_255",
  /*  150 */  "_AndI__LoadI_memoryS__immI_65535",
  /*  151 */  "_AndI__LoadI_memoryI__limmU31",
  /*  152 */  "_AndI__LoadI_memoryI__immU31",
  /*  153 */  "_ConvI2L__LoadI_memoryI__",
  /*  154 */  "_Binary_cmpOpP_flagsRegP",
  /*  155 */  "_Binary_iRegI_iRegI",
  /*  156 */  "_Binary_iRegI_immIRot",
  /*  157 */  "_Binary_iRegI_immI16",
  /*  158 */  "_Binary_cmpOp_flagsReg",
  /*  159 */  "_Binary_cmpOp0_flagsReg_EQNELTGE",
  /*  160 */  "_Binary_cmpOpU_flagsRegU",
  /*  161 */  "_Binary_iRegP_iRegP",
  /*  162 */  "_Binary_iRegP_immP0",
  /*  163 */  "_Binary_regF_regF",
  /*  164 */  "_Binary_regD_regD",
  /*  165 */  "_Binary_iRegL_iRegL",
  /*  166 */  "_Binary_iRegL_immLlowRot",
  /*  167 */  "_Binary_iRegL_immL16",
  /*  168 */  "_LShiftI_iRegI_iRegI",
  /*  169 */  "_RShiftI_iRegI_iRegI",
  /*  170 */  "_RShiftI_iRegI_immU5",
  /*  171 */  "_URShiftI_iRegI_iRegI",
  /*  172 */  "_URShiftI_iRegI_immU5",
  /*  173 */  "_Binary_iRegL_iRegLd",
  /*  174 */  "_CastP2X_iRegP_",
  /*  175 */  "_ConvF2D_regF_",
  /*  176 */  "_SqrtD__ConvF2D_regF__",
  /*  177 */  "_CmpLTMask_iRegI_iRegI",
  /*  178 */  "_AndI__CmpLTMask_iRegI_iRegI_iRegI",
  /*  179 */  "_AndI_iRegI__CmpLTMask_iRegI_iRegI",
  /*  180 */  "_CmpLTMask_iRegI_aimmI",
  /*  181 */  "_AndI__CmpLTMask_iRegI_aimmI_iRegI",
  /*  182 */  "_AndI_iRegI__CmpLTMask_iRegI_aimmI",
  /*  183 */  "_SubI_iRegI_iRegI",
  /*  184 */  "_ConvI2L_iRegI_",
  /*  185 */  "_RShiftL_iRegL_immI_32_63",
  /*  186 */  "_AndI_iRegI_iRegI",
  /*  187 */  "_AndI_iRegI__LShiftI_iRegI_iRegI",
  /*  188 */  "_AndI__LShiftI_iRegI_iRegI_iRegI",
  /*  189 */  "_AndI_iRegI__LShiftI_iRegI_immU5",
  /*  190 */  "_AndI__LShiftI_iRegI_immU5_iRegI",
  /*  191 */  "_AndI_iRegI__RShiftI_iRegI_iRegI",
  /*  192 */  "_AndI__RShiftI_iRegI_iRegI_iRegI",
  /*  193 */  "_AndI_iRegI__RShiftI_iRegI_immU5",
  /*  194 */  "_AndI__RShiftI_iRegI_immU5_iRegI",
  /*  195 */  "_AndI_iRegI__URShiftI_iRegI_iRegI",
  /*  196 */  "_AndI__URShiftI_iRegI_iRegI_iRegI",
  /*  197 */  "_AndI_iRegI__URShiftI_iRegI_immU5",
  /*  198 */  "_AndI__URShiftI_iRegI_immU5_iRegI",
  /*  199 */  "_AndI_iRegI_limmI",
  /*  200 */  "_Binary_cmpOpL_flagsRegL_LTGE",
  /*  201 */  "_Binary_cmpOpUL_flagsRegUL_LTGE",
  /*  202 */  "_Binary_cmpOpL_flagsRegL_EQNE",
  /*  203 */  "_Binary_cmpOpL_commute_flagsRegL_LEGT",
  /*  204 */  "_Binary_cmpOpUL_commute_flagsRegUL_LEGT",
  /*  205 */  "_Binary_iRegL_immL0",
  /*  206 */  "_Binary_cmpOpUL_flagsRegUL_EQNE",
  /*  207 */  "_LShiftCntV_immI_",
  /*  208 */  "_RShiftCntV_immI_",
  // last internally defined operand
  /*  209 */  "loadConI",
  /*  210 */  "loadConIMov",
  /*  211 */  "loadConIMovn",
  /*  212 */  "loadConI16",
  /*  213 */  "loadConP",
  /*  214 */  "loadConL",
  /*  215 */  "loadConL16",
  /*  216 */  "loadConF_imm8",
  /*  217 */  "loadConF",
  /*  218 */  "loadConD_imm8",
  /*  219 */  "loadConD",
  /*  220 */  "castX2P",
  /*  221 */  "castP2X",
  /*  222 */  "tlsLoadP",
  /*  223 */  "checkCastPP",
  /*  224 */  "castPP",
  /*  225 */  "castII",
  /*  226 */  "castLL",
  /*  227 */  "castFF",
  /*  228 */  "castDD",
  /*  229 */  "castVVD",
  /*  230 */  "castVVX",
  /*  231 */  "absD_reg",
  /*  232 */  "absF_reg",
  /*  233 */  "negF_reg",
  /*  234 */  "negD_reg",
  /*  235 */  "MoveF2I_reg_reg",
  /*  236 */  "MoveI2F_reg_reg",
  /*  237 */  "MoveD2L_reg_reg",
  /*  238 */  "MoveL2D_reg_reg",
  /*  239 */  "convI2D_regDHi_regD",
  /*  240 */  "regL_to_regD",
  /*  241 */  "compI_iReg",
  /*  242 */  "compU_iReg",
  /*  243 */  "compI_iReg_immneg",
  /*  244 */  "compI_iReg_imm",
  /*  245 */  "testI_reg_reg",
  /*  246 */  "testshlI_reg_reg_reg",
  /*  247 */  "testshlI_reg_reg_reg_0",
  /*  248 */  "testshlI_reg_reg_imm",
  /*  249 */  "testshlI_reg_reg_imm_0",
  /*  250 */  "testsarI_reg_reg_reg",
  /*  251 */  "testsarI_reg_reg_reg_0",
  /*  252 */  "testsarI_reg_reg_imm",
  /*  253 */  "testsarI_reg_reg_imm_0",
  /*  254 */  "testshrI_reg_reg_reg",
  /*  255 */  "testshrI_reg_reg_reg_0",
  /*  256 */  "testshrI_reg_reg_imm",
  /*  257 */  "testshrI_reg_reg_imm_0",
  /*  258 */  "testI_reg_imm",
  /*  259 */  "compL_reg_reg_LTGE",
  /*  260 */  "compUL_reg_reg_LTGE",
  /*  261 */  "compL_reg_reg_EQNE",
  /*  262 */  "compL_reg_reg_LEGT",
  /*  263 */  "compL_reg_con_LTGE",
  /*  264 */  "compL_reg_con_EQNE",
  /*  265 */  "compL_reg_con_LEGT",
  /*  266 */  "compUL_reg_reg_EQNE",
  /*  267 */  "compUL_reg_reg_LEGT",
  /*  268 */  "compUL_reg_con_LTGE",
  /*  269 */  "compUL_reg_con_EQNE",
  /*  270 */  "compUL_reg_con_LEGT",
  /*  271 */  "compU_iReg_imm",
  /*  272 */  "compP_iRegP",
  /*  273 */  "compP_iRegP_imm",
  /*  274 */  "cmpF_cc",
  /*  275 */  "cmpF0_cc",
  /*  276 */  "cmpD_cc",
  /*  277 */  "cmpD0_cc",
  /*  278 */  "cmpFastLock",
  /*  279 */  "cmpFastUnlock",
  /*  280 */  "countLeadingZerosI",
  /*  281 */  "Repl8B_reg_simd",
  /*  282 */  "Repl16B_reg",
  /*  283 */  "Repl8B_immU8",
  /*  284 */  "Repl16B_immU8",
  /*  285 */  "Repl4S_reg_simd",
  /*  286 */  "Repl8S_reg",
  /*  287 */  "Repl4S_immU8",
  /*  288 */  "Repl8S_immU8",
  /*  289 */  "Repl2I_reg",
  /*  290 */  "Repl4I_reg",
  /*  291 */  "Repl2I_reg_simd",
  /*  292 */  "Repl4I_reg_simd",
  /*  293 */  "Repl2I_immU8",
  /*  294 */  "Repl4I_immU8",
  /*  295 */  "Repl2L_reg",
  /*  296 */  "Repl2F_regI",
  /*  297 */  "Repl2F_reg_vfp",
  /*  298 */  "Repl2F_reg_simd",
  /*  299 */  "Repl4F_reg_simd",
  /*  300 */  "Repl2D_reg",
  /*  301 */  "vneg8B_reg",
  /*  302 */  "vneg16B_reg",
  /*  303 */  "vslcntD",
  /*  304 */  "vslcntX",
  /*  305 */  "vsrcntD",
  /*  306 */  "vsrcntX",
  /*  307 */  "Nop_A0",
  /*  308 */  "Nop_A1",
  /*  309 */  "Nop_MS",
  /*  310 */  "Nop_FA",
  /*  311 */  "Nop_BR",
  /*  312 */  "loadB",
  /*  313 */  "loadB2L",
  /*  314 */  "loadUB",
  /*  315 */  "loadUB2L",
  /*  316 */  "loadUB2L_limmI",
  /*  317 */  "loadS",
  /*  318 */  "loadS2B",
  /*  319 */  "loadS2L",
  /*  320 */  "loadUS",
  /*  321 */  "loadUS2B",
  /*  322 */  "loadUS2L",
  /*  323 */  "loadUS2L_immI_255",
  /*  324 */  "loadUS2L_limmI",
  /*  325 */  "loadI",
  /*  326 */  "loadI2B",
  /*  327 */  "loadI2UB",
  /*  328 */  "loadI2S",
  /*  329 */  "loadI2US",
  /*  330 */  "loadI2L",
  /*  331 */  "loadI2L_immI_255",
  /*  332 */  "loadI2L_immI_65535",
  /*  333 */  "loadI2L_limmU31",
  /*  334 */  "loadI2L_immU31",
  /*  335 */  "loadUI2L",
  /*  336 */  "loadL",
  /*  337 */  "loadL_2instr",
  /*  338 */  "loadL_volatile",
  /*  339 */  "loadL_volatile_fp",
  /*  340 */  "loadL_unaligned",
  /*  341 */  "loadRange",
  /*  342 */  "loadP",
  /*  343 */  "loadKlass",
  /*  344 */  "loadD",
  /*  345 */  "loadD_unaligned",
  /*  346 */  "loadF",
  /*  347 */  "prefetchAlloc_mp",
  /*  348 */  "prefetchAlloc_sp",
  /*  349 */  "storeB",
  /*  350 */  "storeCM",
  /*  351 */  "storeC",
  /*  352 */  "storeI",
  /*  353 */  "storeL",
  /*  354 */  "storeL_2instr",
  /*  355 */  "storeL_volatile",
  /*  356 */  "storeL_volatile_fp",
  /*  357 */  "storeP",
  /*  358 */  "storeD",
  /*  359 */  "storeF",
  /*  360 */  "membar_storestore",
  /*  361 */  "membar_storestore_0",
  /*  362 */  "membar_acquire",
  /*  363 */  "membar_acquire_0",
  /*  364 */  "membar_acquire_lock",
  /*  365 */  "membar_release",
  /*  366 */  "membar_release_0",
  /*  367 */  "membar_release_lock",
  /*  368 */  "membar_volatile",
  /*  369 */  "unnecessary_membar_volatile",
  /*  370 */  "cmovIP_reg",
  /*  371 */  "cmovIP_immMov",
  /*  372 */  "cmovIP_imm16",
  /*  373 */  "cmovI_reg",
  /*  374 */  "cmovI_immMov",
  /*  375 */  "cmovII_imm16",
  /*  376 */  "cmovII_reg_EQNELTGE",
  /*  377 */  "cmovII_immMov_EQNELTGE",
  /*  378 */  "cmovII_imm16_EQNELTGE",
  /*  379 */  "cmovIIu_reg",
  /*  380 */  "cmovIIu_immMov",
  /*  381 */  "cmovIIu_imm16",
  /*  382 */  "cmovPP_reg",
  /*  383 */  "cmovPP_imm",
  /*  384 */  "cmovPI_reg",
  /*  385 */  "cmovPI_reg_EQNELTGE",
  /*  386 */  "cmovPIu_reg",
  /*  387 */  "cmovPI_imm",
  /*  388 */  "cmovPI_imm_EQNELTGE",
  /*  389 */  "cmovPIu_imm",
  /*  390 */  "cmovFP_reg",
  /*  391 */  "cmovFI_reg",
  /*  392 */  "cmovFI_reg_EQNELTGE",
  /*  393 */  "cmovFIu_reg",
  /*  394 */  "cmovDP_reg",
  /*  395 */  "cmovDI_reg",
  /*  396 */  "cmovDI_reg_EQNELTGE",
  /*  397 */  "cmovDIu_reg",
  /*  398 */  "cmovLP_reg",
  /*  399 */  "cmovLP_immRot",
  /*  400 */  "cmovLP_imm16",
  /*  401 */  "cmovLI_reg",
  /*  402 */  "cmovLI_reg_EQNELTGE",
  /*  403 */  "cmovLI_immRot",
  /*  404 */  "cmovLI_immRot_EQNELTGE",
  /*  405 */  "cmovLI_imm16",
  /*  406 */  "cmovLI_imm16_EQNELTGE",
  /*  407 */  "cmovLIu_reg",
  /*  408 */  "addI_reg_reg",
  /*  409 */  "addshlI_reg_reg_reg",
  /*  410 */  "addshlI_reg_reg_reg_0",
  /*  411 */  "addshlI_reg_imm_reg",
  /*  412 */  "addshlI_reg_imm_reg_0",
  /*  413 */  "addsarI_reg_reg_reg",
  /*  414 */  "addsarI_reg_reg_reg_0",
  /*  415 */  "addsarI_reg_imm_reg",
  /*  416 */  "addsarI_reg_imm_reg_0",
  /*  417 */  "addshrI_reg_reg_reg",
  /*  418 */  "addshrI_reg_reg_reg_0",
  /*  419 */  "addshrI_reg_imm_reg",
  /*  420 */  "addshrI_reg_imm_reg_0",
  /*  421 */  "addI_reg_aimmI",
  /*  422 */  "addP_reg_reg",
  /*  423 */  "addshlP_reg_reg_imm",
  /*  424 */  "addP_reg_aimmX",
  /*  425 */  "addL_reg_reg",
  /*  426 */  "addL_reg_immRot",
  /*  427 */  "compareAndSwapL_bool",
  /*  428 */  "compareAndSwapI_bool",
  /*  429 */  "compareAndSwapP_bool",
  /*  430 */  "xaddI_aimmI_no_res",
  /*  431 */  "xaddI_reg_no_res",
  /*  432 */  "xaddI_aimmI",
  /*  433 */  "xaddI_reg",
  /*  434 */  "xaddL_reg_no_res",
  /*  435 */  "xaddL_immRot_no_res",
  /*  436 */  "xaddL_reg",
  /*  437 */  "xaddL_immRot",
  /*  438 */  "xchgI",
  /*  439 */  "xchgL",
  /*  440 */  "xchgP",
  /*  441 */  "subI_reg_reg",
  /*  442 */  "subshlI_reg_reg_reg",
  /*  443 */  "subshlI_reg_reg_imm",
  /*  444 */  "subsarI_reg_reg_reg",
  /*  445 */  "subsarI_reg_reg_imm",
  /*  446 */  "subshrI_reg_reg_reg",
  /*  447 */  "subshrI_reg_reg_imm",
  /*  448 */  "rsbshlI_reg_reg_reg",
  /*  449 */  "rsbshlI_reg_imm_reg",
  /*  450 */  "rsbsarI_reg_reg_reg",
  /*  451 */  "rsbsarI_reg_imm_reg",
  /*  452 */  "rsbshrI_reg_reg_reg",
  /*  453 */  "rsbshrI_reg_imm_reg",
  /*  454 */  "subI_reg_aimmI",
  /*  455 */  "subI_reg_immRotneg",
  /*  456 */  "subI_immRot_reg",
  /*  457 */  "subL_reg_reg",
  /*  458 */  "subL_reg_immRot",
  /*  459 */  "negL_reg_reg",
  /*  460 */  "mulI_reg_reg",
  /*  461 */  "mulL_lo1_hi2",
  /*  462 */  "mulL_hi1_lo2",
  /*  463 */  "mulL_lo1_lo2",
  /*  464 */  "mulL_reg_reg",
  /*  465 */  "divI_reg_reg",
  /*  466 */  "divL_reg_reg",
  /*  467 */  "modI_reg_reg",
  /*  468 */  "modL_reg_reg",
  /*  469 */  "shlI_reg_reg",
  /*  470 */  "shlI_reg_imm5",
  /*  471 */  "shlL_reg_reg_merge_hi",
  /*  472 */  "shlL_reg_reg_merge_lo",
  /*  473 */  "shlL_reg_reg_overlap",
  /*  474 */  "shlL_reg_reg",
  /*  475 */  "shlL_reg_imm6",
  /*  476 */  "shlL_reg_imm5",
  /*  477 */  "sarI_reg_reg",
  /*  478 */  "sarI_reg_imm5",
  /*  479 */  "sarL_reg_reg_merge_lo",
  /*  480 */  "sarL_reg_reg_merge_hi",
  /*  481 */  "sarL_reg_reg_overlap",
  /*  482 */  "sarL_reg_reg",
  /*  483 */  "sarL_reg_imm6",
  /*  484 */  "sarL_reg_imm5",
  /*  485 */  "shrI_reg_reg",
  /*  486 */  "shrI_reg_imm5",
  /*  487 */  "shrL_reg_reg_merge_lo",
  /*  488 */  "shrL_reg_reg_merge_hi",
  /*  489 */  "shrL_reg_reg_overlap",
  /*  490 */  "shrL_reg_reg",
  /*  491 */  "shrL_reg_imm6",
  /*  492 */  "shrL_reg_imm5",
  /*  493 */  "shrP_reg_imm5",
  /*  494 */  "addF_reg_reg",
  /*  495 */  "addD_reg_reg",
  /*  496 */  "subF_reg_reg",
  /*  497 */  "subD_reg_reg",
  /*  498 */  "mulF_reg_reg",
  /*  499 */  "mulD_reg_reg",
  /*  500 */  "divF_reg_reg",
  /*  501 */  "divD_reg_reg",
  /*  502 */  "sqrtF_reg_reg",
  /*  503 */  "sqrtD_reg_reg",
  /*  504 */  "andI_reg_reg",
  /*  505 */  "andshlI_reg_reg_reg",
  /*  506 */  "andshlI_reg_reg_reg_0",
  /*  507 */  "andshlI_reg_reg_imm",
  /*  508 */  "andshlI_reg_reg_imm_0",
  /*  509 */  "andsarI_reg_reg_reg",
  /*  510 */  "andsarI_reg_reg_reg_0",
  /*  511 */  "andsarI_reg_reg_imm",
  /*  512 */  "andsarI_reg_reg_imm_0",
  /*  513 */  "andshrI_reg_reg_reg",
  /*  514 */  "andshrI_reg_reg_reg_0",
  /*  515 */  "andshrI_reg_reg_imm",
  /*  516 */  "andshrI_reg_reg_imm_0",
  /*  517 */  "andI_reg_limm",
  /*  518 */  "andI_reg_limmn",
  /*  519 */  "andL_reg_reg",
  /*  520 */  "andL_reg_immRot",
  /*  521 */  "orI_reg_reg",
  /*  522 */  "orshlI_reg_reg_reg",
  /*  523 */  "orshlI_reg_reg_reg_0",
  /*  524 */  "orshlI_reg_reg_imm",
  /*  525 */  "orshlI_reg_reg_imm_0",
  /*  526 */  "orsarI_reg_reg_reg",
  /*  527 */  "orsarI_reg_reg_reg_0",
  /*  528 */  "orsarI_reg_reg_imm",
  /*  529 */  "orsarI_reg_reg_imm_0",
  /*  530 */  "orshrI_reg_reg_reg",
  /*  531 */  "orshrI_reg_reg_reg_0",
  /*  532 */  "orshrI_reg_reg_imm",
  /*  533 */  "orshrI_reg_reg_imm_0",
  /*  534 */  "orI_reg_limm",
  /*  535 */  "orL_reg_reg",
  /*  536 */  "orL_reg_immRot",
  /*  537 */  "xorI_reg_reg",
  /*  538 */  "xorshlI_reg_reg_reg",
  /*  539 */  "xorshlI_reg_reg_reg_0",
  /*  540 */  "xorshlI_reg_reg_imm",
  /*  541 */  "xorshlI_reg_reg_imm_0",
  /*  542 */  "xorsarI_reg_reg_reg",
  /*  543 */  "xorsarI_reg_reg_reg_0",
  /*  544 */  "xorsarI_reg_reg_imm",
  /*  545 */  "xorsarI_reg_reg_imm_0",
  /*  546 */  "xorshrI_reg_reg_reg",
  /*  547 */  "xorshrI_reg_reg_reg_0",
  /*  548 */  "xorshrI_reg_reg_imm",
  /*  549 */  "xorshrI_reg_reg_imm_0",
  /*  550 */  "xorI_reg_imm",
  /*  551 */  "xorL_reg_reg",
  /*  552 */  "xorL_reg_immRot",
  /*  553 */  "cmpLTMask_reg_reg",
  /*  554 */  "cmpLTMask_reg_imm",
  /*  555 */  "cadd_cmpLTMask3",
  /*  556 */  "cadd_cmpLTMask3_1",
  /*  557 */  "cadd_cmpLTMask3_0",
  /*  558 */  "cadd_cmpLTMask3_2",
  /*  559 */  "cadd_cmpLTMask4",
  /*  560 */  "cadd_cmpLTMask4_1",
  /*  561 */  "cadd_cmpLTMask4_0",
  /*  562 */  "cadd_cmpLTMask4_2",
  /*  563 */  "cadd_cmpLTMask",
  /*  564 */  "cadd_cmpLTMask_1",
  /*  565 */  "cadd_cmpLTMask_0",
  /*  566 */  "cadd_cmpLTMask_2",
  /*  567 */  "convD2F_reg",
  /*  568 */  "convD2I_reg_reg",
  /*  569 */  "convD2L_reg",
  /*  570 */  "convF2D_reg",
  /*  571 */  "convF2I_reg_reg",
  /*  572 */  "convF2L_reg",
  /*  573 */  "convI2D_reg_reg",
  /*  574 */  "convI2F_reg_reg",
  /*  575 */  "convI2L_reg",
  /*  576 */  "convI2L_reg_zex",
  /*  577 */  "zerox_long",
  /*  578 */  "loadConI_x43300000",
  /*  579 */  "loadConI_x41f00000",
  /*  580 */  "loadConI_x0",
  /*  581 */  "regDHi_regDLo_to_regD",
  /*  582 */  "addD_regD_regD",
  /*  583 */  "subD_regD_regD",
  /*  584 */  "mulD_regD_regD",
  /*  585 */  "regI_regI_to_regD",
  /*  586 */  "convL2D_reg_slow_fxtof",
  /*  587 */  "convL2I_reg",
  /*  588 */  "shrL_reg_imm6_L2I",
  /*  589 */  "cmovI_reg_lt",
  /*  590 */  "minI_eReg",
  /*  591 */  "cmovI_reg_gt",
  /*  592 */  "maxI_eReg",
  /*  593 */  "cmpF_reg",
  /*  594 */  "cmpF0_reg",
  /*  595 */  "cmpD_reg",
  /*  596 */  "cmpD0_reg",
  /*  597 */  "jumpXtnd",
  /*  598 */  "branch",
  /*  599 */  "branchCon",
  /*  600 */  "branchCon_EQNELTGE",
  /*  601 */  "branchConU",
  /*  602 */  "branchConP",
  /*  603 */  "branchConL_LTGE",
  /*  604 */  "branchConL_EQNE",
  /*  605 */  "branchConL_LEGT",
  /*  606 */  "branchConUL_LTGE",
  /*  607 */  "branchConUL_EQNE",
  /*  608 */  "branchConUL_LEGT",
  /*  609 */  "branchLoopEnd",
  /*  610 */  "cmpL3_reg_reg",
  /*  611 */  "cmovLL_reg_LTGE",
  /*  612 */  "cmovLL_reg_LTGE_U",
  /*  613 */  "cmovLL_reg_EQNE",
  /*  614 */  "cmovLL_reg_LEGT",
  /*  615 */  "cmovLL_reg_LEGT_U",
  /*  616 */  "cmovLL_imm_LTGE",
  /*  617 */  "cmovLL_imm_LTGE_U",
  /*  618 */  "cmovLL_imm_EQNE",
  /*  619 */  "cmovLL_imm_LEGT",
  /*  620 */  "cmovIL_reg_LTGE",
  /*  621 */  "cmovIL_reg_LTGE_U",
  /*  622 */  "cmovIL_reg_EQNE",
  /*  623 */  "cmovIL_reg_EQNE_U",
  /*  624 */  "cmovIL_reg_LEGT",
  /*  625 */  "cmovIL_reg_LEGT_U",
  /*  626 */  "cmovIL_imm16_LTGE",
  /*  627 */  "cmovIL_imm16_LTGE_U",
  /*  628 */  "cmovIL_imm16_EQNE",
  /*  629 */  "cmovIL_imm16_EQNE_U",
  /*  630 */  "cmovIL_imm16_LEGT",
  /*  631 */  "cmovIL_imm16_LEGT_U",
  /*  632 */  "cmovIL_immMov_LTGE",
  /*  633 */  "cmovIL_immMov_LTGE_U",
  /*  634 */  "cmovIL_immMov_EQNE",
  /*  635 */  "cmovIL_immMov_EQNE_U",
  /*  636 */  "cmovIL_immMov_LEGT",
  /*  637 */  "cmovIL_immMov_LEGT_U",
  /*  638 */  "cmovPL_reg_LTGE",
  /*  639 */  "cmovPL_reg_LTGE_U",
  /*  640 */  "cmovPL_reg_EQNE",
  /*  641 */  "cmovPL_reg_EQNE_U",
  /*  642 */  "cmovPL_reg_LEGT",
  /*  643 */  "cmovPL_reg_LEGT_U",
  /*  644 */  "cmovPL_imm_LTGE",
  /*  645 */  "cmovPL_imm_LTGE_U",
  /*  646 */  "cmovPL_imm_EQNE",
  /*  647 */  "cmovPL_imm_EQNE_U",
  /*  648 */  "cmovPL_imm_LEGT",
  /*  649 */  "cmovPL_imm_LEGT_U",
  /*  650 */  "cmovFL_reg_LTGE",
  /*  651 */  "cmovFL_reg_EQNE",
  /*  652 */  "cmovFL_reg_LEGT",
  /*  653 */  "cmovDL_reg_LTGE",
  /*  654 */  "cmovDL_reg_EQNE",
  /*  655 */  "cmovDL_reg_LEGT",
  /*  656 */  "safePoint_poll",
  /*  657 */  "CallStaticJavaDirect",
  /*  658 */  "CallStaticJavaHandle",
  /*  659 */  "CallDynamicJavaDirect",
  /*  660 */  "CallRuntimeDirect",
  /*  661 */  "CallLeafDirect",
  /*  662 */  "CallLeafNoFPDirect",
  /*  663 */  "TailCalljmpInd",
  /*  664 */  "Ret",
  /*  665 */  "tailjmpInd",
  /*  666 */  "CreateException",
  /*  667 */  "RethrowException",
  /*  668 */  "ShouldNotReachHere",
  /*  669 */  "partialSubtypeCheck",
  /*  670 */  "clear_array",
  /*  671 */  "countLeadingZerosL",
  /*  672 */  "countTrailingZerosI",
  /*  673 */  "countTrailingZerosL",
  /*  674 */  "popCountI",
  /*  675 */  "popCountL",
  /*  676 */  "bytes_reverse_int",
  /*  677 */  "bytes_reverse_long",
  /*  678 */  "bytes_reverse_unsigned_short",
  /*  679 */  "bytes_reverse_short",
  /*  680 */  "loadV8",
  /*  681 */  "loadV16",
  /*  682 */  "storeV8",
  /*  683 */  "storeV16",
  /*  684 */  "Repl8B_reg",
  /*  685 */  "Repl8B_immI",
  /*  686 */  "Repl4S_reg",
  /*  687 */  "Repl4S_immI",
  /*  688 */  "Repl2I_immI",
  /*  689 */  "Repl4F_reg",
  /*  690 */  "Repl2F_immI",
  /*  691 */  "vadd8B_reg",
  /*  692 */  "vadd16B_reg",
  /*  693 */  "vadd4S_reg",
  /*  694 */  "vadd8S_reg",
  /*  695 */  "vadd2I_reg",
  /*  696 */  "vadd4I_reg",
  /*  697 */  "vadd2L_reg",
  /*  698 */  "vadd2F_reg",
  /*  699 */  "vadd2F_reg_vfp",
  /*  700 */  "vadd4F_reg_simd",
  /*  701 */  "vadd4F_reg_vfp",
  /*  702 */  "vadd2D_reg_vfp",
  /*  703 */  "vsub8B_reg",
  /*  704 */  "vsub16B_reg",
  /*  705 */  "vsub4S_reg",
  /*  706 */  "vsub16S_reg",
  /*  707 */  "vsub2I_reg",
  /*  708 */  "vsub4I_reg",
  /*  709 */  "vsub2L_reg",
  /*  710 */  "vsub2F_reg",
  /*  711 */  "vsub2F_reg_vfp",
  /*  712 */  "vsub4F_reg",
  /*  713 */  "vsub4F_reg_vfp",
  /*  714 */  "vsub2D_reg_vfp",
  /*  715 */  "vmul4S_reg",
  /*  716 */  "vmul8S_reg",
  /*  717 */  "vmul2I_reg",
  /*  718 */  "vmul4I_reg",
  /*  719 */  "vmul2F_reg",
  /*  720 */  "vmul2F_reg_vfp",
  /*  721 */  "vmul4F_reg",
  /*  722 */  "vmul4F_reg_vfp",
  /*  723 */  "vmul2D_reg_vfp",
  /*  724 */  "vdiv2F_reg_vfp",
  /*  725 */  "vdiv4F_reg_vfp",
  /*  726 */  "vdiv2D_reg_vfp",
  /*  727 */  "vsh8B_reg",
  /*  728 */  "vsh16B_reg",
  /*  729 */  "vsh4S_reg",
  /*  730 */  "vsh8S_reg",
  /*  731 */  "vsh2I_reg",
  /*  732 */  "vsh4I_reg",
  /*  733 */  "vsh2L_reg",
  /*  734 */  "vsl8B_reg",
  /*  735 */  "vsl16B_reg",
  /*  736 */  "vsl8B_immI",
  /*  737 */  "vsl16B_immI",
  /*  738 */  "vsl4S_reg",
  /*  739 */  "vsl8S_reg",
  /*  740 */  "vsl4S_immI",
  /*  741 */  "vsl8S_immI",
  /*  742 */  "vsl2I_reg",
  /*  743 */  "vsl4I_reg",
  /*  744 */  "vsl2I_immI",
  /*  745 */  "vsl4I_immI",
  /*  746 */  "vsl2L_reg",
  /*  747 */  "vsl2L_immI",
  /*  748 */  "vsrl4S_reg",
  /*  749 */  "vsrl4S_reg_var",
  /*  750 */  "vsrl8S_reg",
  /*  751 */  "vsrl8S_reg_var",
  /*  752 */  "vsrl4S_immI",
  /*  753 */  "vsrl8S_immI",
  /*  754 */  "vsrl2I_reg",
  /*  755 */  "vsrl2I_reg_var",
  /*  756 */  "vsrl4I_reg",
  /*  757 */  "vsrl4I_reg_var",
  /*  758 */  "vsrl2I_immI",
  /*  759 */  "vsrl4I_immI",
  /*  760 */  "vsrl2L_reg",
  /*  761 */  "vsrl2L_reg_var",
  /*  762 */  "vsrl2L_immI",
  /*  763 */  "vsha8B_reg",
  /*  764 */  "vsha16B_reg",
  /*  765 */  "vsha4S_reg",
  /*  766 */  "vsha8S_reg",
  /*  767 */  "vsha2I_reg",
  /*  768 */  "vsha4I_reg",
  /*  769 */  "vsha2L_reg",
  /*  770 */  "vsra8B_reg",
  /*  771 */  "vsra8B_reg_var",
  /*  772 */  "vsra16B_reg",
  /*  773 */  "vsra16B_reg_var",
  /*  774 */  "vsra8B_immI",
  /*  775 */  "vsra16B_immI",
  /*  776 */  "vsra4S_reg",
  /*  777 */  "vsra4S_reg_var",
  /*  778 */  "vsra8S_reg",
  /*  779 */  "vsra8S_reg_var",
  /*  780 */  "vsra4S_immI",
  /*  781 */  "vsra8S_immI",
  /*  782 */  "vsra2I_reg",
  /*  783 */  "vsra2I_reg_var",
  /*  784 */  "vsra4I_reg",
  /*  785 */  "vsra4I_reg_var",
  /*  786 */  "vsra2I_immI",
  /*  787 */  "vsra4I_immI",
  /*  788 */  "vsra2L_reg",
  /*  789 */  "vsra2L_reg_var",
  /*  790 */  "vsra2L_immI",
  /*  791 */  "vandD",
  /*  792 */  "vandX",
  /*  793 */  "vorD",
  /*  794 */  "vorX",
  /*  795 */  "vxorD",
  /*  796 */  "vxorX",
  // last instruction
  "invalid rule name" // no trailing comma
};

const        bool  swallowed[] = {
  /*    0 */  false,
  /*    1 */  false,
  /*    2 */  false,
  /*    3 */  false,
  /*    4 */  false,
  /*    5 */  false,
  /*    6 */  false,
  /*    7 */  false,
  /*    8 */  true,
  /*    9 */  true,
  /*   10 */  true,
  /*   11 */  true,
  /*   12 */  true,
  /*   13 */  true,
  /*   14 */  true,
  /*   15 */  true,
  /*   16 */  true,
  /*   17 */  true,
  /*   18 */  true,
  /*   19 */  true,
  /*   20 */  true,
  /*   21 */  true,
  /*   22 */  true,
  /*   23 */  true,
  /*   24 */  true,
  /*   25 */  true,
  /*   26 */  true,
  /*   27 */  true,
  /*   28 */  true,
  /*   29 */  true,
  /*   30 */  true,
  /*   31 */  true,
  /*   32 */  true,
  /*   33 */  true,
  /*   34 */  true,
  /*   35 */  true,
  /*   36 */  true,
  /*   37 */  true,
  /*   38 */  true,
  /*   39 */  true,
  /*   40 */  true,
  /*   41 */  true,
  /*   42 */  true,
  /*   43 */  true,
  /*   44 */  true,
  /*   45 */  true,
  /*   46 */  true,
  /*   47 */  true,
  /*   48 */  true,
  /*   49 */  true,
  /*   50 */  true,
  /*   51 */  true,
  /*   52 */  true,
  /*   53 */  true,
  /*   54 */  true,
  /*   55 */  true,
  /*   56 */  true,
  /*   57 */  true,
  /*   58 */  true,
  /*   59 */  true,
  /*   60 */  true,
  /*   61 */  false,
  /*   62 */  false,
  /*   63 */  false,
  /*   64 */  false,
  /*   65 */  false,
  /*   66 */  false,
  /*   67 */  false,
  /*   68 */  false,
  /*   69 */  false,
  /*   70 */  false,
  /*   71 */  false,
  /*   72 */  false,
  /*   73 */  false,
  /*   74 */  false,
  /*   75 */  false,
  /*   76 */  false,
  /*   77 */  false,
  /*   78 */  false,
  /*   79 */  false,
  /*   80 */  false,
  /*   81 */  false,
  /*   82 */  false,
  /*   83 */  false,
  /*   84 */  false,
  /*   85 */  false,
  /*   86 */  false,
  /*   87 */  false,
  /*   88 */  false,
  /*   89 */  false,
  /*   90 */  false,
  /*   91 */  false,
  /*   92 */  false,
  /*   93 */  false,
  /*   94 */  false,
  /*   95 */  false,
  /*   96 */  false,
  /*   97 */  false,
  /*   98 */  false,
  /*   99 */  false,
  /*  100 */  false,
  /*  101 */  false,
  /*  102 */  false,
  /*  103 */  false,
  /*  104 */  false,
  /*  105 */  false,
  /*  106 */  false,
  /*  107 */  false,
  /*  108 */  false,
  /*  109 */  true,
  /*  110 */  true,
  /*  111 */  true,
  /*  112 */  true,
  /*  113 */  true,
  /*  114 */  true,
  /*  115 */  true,
  /*  116 */  true,
  /*  117 */  false,
  // last operand
  /*  118 */  false,
  /*  119 */  false,
  /*  120 */  false,
  /*  121 */  false,
  /*  122 */  false,
  /*  123 */  false,
  /*  124 */  false,
  /*  125 */  false,
  /*  126 */  false,
  /*  127 */  false,
  /*  128 */  false,
  /*  129 */  false,
  /*  130 */  false,
  /*  131 */  false,
  /*  132 */  false,
  // last operand class
  /*  133 */  false,
  /*  134 */  false,
  /*  135 */  false,
  /*  136 */  false,
  /*  137 */  false,
  /*  138 */  false,
  /*  139 */  false,
  /*  140 */  false,
  /*  141 */  false,
  /*  142 */  false,
  /*  143 */  false,
  /*  144 */  false,
  /*  145 */  false,
  /*  146 */  false,
  /*  147 */  false,
  /*  148 */  false,
  /*  149 */  false,
  /*  150 */  false,
  /*  151 */  false,
  /*  152 */  false,
  /*  153 */  false,
  /*  154 */  false,
  /*  155 */  false,
  /*  156 */  false,
  /*  157 */  false,
  /*  158 */  false,
  /*  159 */  false,
  /*  160 */  false,
  /*  161 */  false,
  /*  162 */  false,
  /*  163 */  false,
  /*  164 */  false,
  /*  165 */  false,
  /*  166 */  false,
  /*  167 */  false,
  /*  168 */  false,
  /*  169 */  false,
  /*  170 */  false,
  /*  171 */  false,
  /*  172 */  false,
  /*  173 */  false,
  /*  174 */  false,
  /*  175 */  false,
  /*  176 */  false,
  /*  177 */  false,
  /*  178 */  false,
  /*  179 */  false,
  /*  180 */  false,
  /*  181 */  false,
  /*  182 */  false,
  /*  183 */  false,
  /*  184 */  false,
  /*  185 */  false,
  /*  186 */  false,
  /*  187 */  false,
  /*  188 */  false,
  /*  189 */  false,
  /*  190 */  false,
  /*  191 */  false,
  /*  192 */  false,
  /*  193 */  false,
  /*  194 */  false,
  /*  195 */  false,
  /*  196 */  false,
  /*  197 */  false,
  /*  198 */  false,
  /*  199 */  false,
  /*  200 */  false,
  /*  201 */  false,
  /*  202 */  false,
  /*  203 */  false,
  /*  204 */  false,
  /*  205 */  false,
  /*  206 */  false,
  /*  207 */  false,
  /*  208 */  false,
  // last internally defined operand
  /*  209 */  false,
  /*  210 */  false,
  /*  211 */  false,
  /*  212 */  false,
  /*  213 */  false,
  /*  214 */  false,
  /*  215 */  false,
  /*  216 */  false,
  /*  217 */  false,
  /*  218 */  false,
  /*  219 */  false,
  /*  220 */  false,
  /*  221 */  false,
  /*  222 */  false,
  /*  223 */  false,
  /*  224 */  false,
  /*  225 */  false,
  /*  226 */  false,
  /*  227 */  false,
  /*  228 */  false,
  /*  229 */  false,
  /*  230 */  false,
  /*  231 */  false,
  /*  232 */  false,
  /*  233 */  false,
  /*  234 */  false,
  /*  235 */  false,
  /*  236 */  false,
  /*  237 */  false,
  /*  238 */  false,
  /*  239 */  false,
  /*  240 */  false,
  /*  241 */  false,
  /*  242 */  false,
  /*  243 */  false,
  /*  244 */  false,
  /*  245 */  false,
  /*  246 */  false,
  /*  247 */  false,
  /*  248 */  false,
  /*  249 */  false,
  /*  250 */  false,
  /*  251 */  false,
  /*  252 */  false,
  /*  253 */  false,
  /*  254 */  false,
  /*  255 */  false,
  /*  256 */  false,
  /*  257 */  false,
  /*  258 */  false,
  /*  259 */  false,
  /*  260 */  false,
  /*  261 */  false,
  /*  262 */  false,
  /*  263 */  false,
  /*  264 */  false,
  /*  265 */  false,
  /*  266 */  false,
  /*  267 */  false,
  /*  268 */  false,
  /*  269 */  false,
  /*  270 */  false,
  /*  271 */  false,
  /*  272 */  false,
  /*  273 */  false,
  /*  274 */  false,
  /*  275 */  false,
  /*  276 */  false,
  /*  277 */  false,
  /*  278 */  false,
  /*  279 */  false,
  /*  280 */  false,
  /*  281 */  false,
  /*  282 */  false,
  /*  283 */  false,
  /*  284 */  false,
  /*  285 */  false,
  /*  286 */  false,
  /*  287 */  false,
  /*  288 */  false,
  /*  289 */  false,
  /*  290 */  false,
  /*  291 */  false,
  /*  292 */  false,
  /*  293 */  false,
  /*  294 */  false,
  /*  295 */  false,
  /*  296 */  false,
  /*  297 */  false,
  /*  298 */  false,
  /*  299 */  false,
  /*  300 */  false,
  /*  301 */  false,
  /*  302 */  false,
  /*  303 */  false,
  /*  304 */  false,
  /*  305 */  false,
  /*  306 */  false,
  /*  307 */  false,
  /*  308 */  false,
  /*  309 */  false,
  /*  310 */  false,
  /*  311 */  false,
  /*  312 */  false,
  /*  313 */  false,
  /*  314 */  false,
  /*  315 */  false,
  /*  316 */  false,
  /*  317 */  false,
  /*  318 */  false,
  /*  319 */  false,
  /*  320 */  false,
  /*  321 */  false,
  /*  322 */  false,
  /*  323 */  false,
  /*  324 */  false,
  /*  325 */  false,
  /*  326 */  false,
  /*  327 */  false,
  /*  328 */  false,
  /*  329 */  false,
  /*  330 */  false,
  /*  331 */  false,
  /*  332 */  false,
  /*  333 */  false,
  /*  334 */  false,
  /*  335 */  false,
  /*  336 */  false,
  /*  337 */  false,
  /*  338 */  false,
  /*  339 */  false,
  /*  340 */  false,
  /*  341 */  false,
  /*  342 */  false,
  /*  343 */  false,
  /*  344 */  false,
  /*  345 */  false,
  /*  346 */  false,
  /*  347 */  false,
  /*  348 */  false,
  /*  349 */  false,
  /*  350 */  false,
  /*  351 */  false,
  /*  352 */  false,
  /*  353 */  false,
  /*  354 */  false,
  /*  355 */  false,
  /*  356 */  false,
  /*  357 */  false,
  /*  358 */  false,
  /*  359 */  false,
  /*  360 */  false,
  /*  361 */  false,
  /*  362 */  false,
  /*  363 */  false,
  /*  364 */  false,
  /*  365 */  false,
  /*  366 */  false,
  /*  367 */  false,
  /*  368 */  false,
  /*  369 */  false,
  /*  370 */  false,
  /*  371 */  false,
  /*  372 */  false,
  /*  373 */  false,
  /*  374 */  false,
  /*  375 */  false,
  /*  376 */  false,
  /*  377 */  false,
  /*  378 */  false,
  /*  379 */  false,
  /*  380 */  false,
  /*  381 */  false,
  /*  382 */  false,
  /*  383 */  false,
  /*  384 */  false,
  /*  385 */  false,
  /*  386 */  false,
  /*  387 */  false,
  /*  388 */  false,
  /*  389 */  false,
  /*  390 */  false,
  /*  391 */  false,
  /*  392 */  false,
  /*  393 */  false,
  /*  394 */  false,
  /*  395 */  false,
  /*  396 */  false,
  /*  397 */  false,
  /*  398 */  false,
  /*  399 */  false,
  /*  400 */  false,
  /*  401 */  false,
  /*  402 */  false,
  /*  403 */  false,
  /*  404 */  false,
  /*  405 */  false,
  /*  406 */  false,
  /*  407 */  false,
  /*  408 */  false,
  /*  409 */  false,
  /*  410 */  false,
  /*  411 */  false,
  /*  412 */  false,
  /*  413 */  false,
  /*  414 */  false,
  /*  415 */  false,
  /*  416 */  false,
  /*  417 */  false,
  /*  418 */  false,
  /*  419 */  false,
  /*  420 */  false,
  /*  421 */  false,
  /*  422 */  false,
  /*  423 */  false,
  /*  424 */  false,
  /*  425 */  false,
  /*  426 */  false,
  /*  427 */  false,
  /*  428 */  false,
  /*  429 */  false,
  /*  430 */  false,
  /*  431 */  false,
  /*  432 */  false,
  /*  433 */  false,
  /*  434 */  false,
  /*  435 */  false,
  /*  436 */  false,
  /*  437 */  false,
  /*  438 */  false,
  /*  439 */  false,
  /*  440 */  false,
  /*  441 */  false,
  /*  442 */  false,
  /*  443 */  false,
  /*  444 */  false,
  /*  445 */  false,
  /*  446 */  false,
  /*  447 */  false,
  /*  448 */  false,
  /*  449 */  false,
  /*  450 */  false,
  /*  451 */  false,
  /*  452 */  false,
  /*  453 */  false,
  /*  454 */  false,
  /*  455 */  false,
  /*  456 */  false,
  /*  457 */  false,
  /*  458 */  false,
  /*  459 */  false,
  /*  460 */  false,
  /*  461 */  false,
  /*  462 */  false,
  /*  463 */  false,
  /*  464 */  false,
  /*  465 */  false,
  /*  466 */  false,
  /*  467 */  false,
  /*  468 */  false,
  /*  469 */  false,
  /*  470 */  false,
  /*  471 */  false,
  /*  472 */  false,
  /*  473 */  false,
  /*  474 */  false,
  /*  475 */  false,
  /*  476 */  false,
  /*  477 */  false,
  /*  478 */  false,
  /*  479 */  false,
  /*  480 */  false,
  /*  481 */  false,
  /*  482 */  false,
  /*  483 */  false,
  /*  484 */  false,
  /*  485 */  false,
  /*  486 */  false,
  /*  487 */  false,
  /*  488 */  false,
  /*  489 */  false,
  /*  490 */  false,
  /*  491 */  false,
  /*  492 */  false,
  /*  493 */  false,
  /*  494 */  false,
  /*  495 */  false,
  /*  496 */  false,
  /*  497 */  false,
  /*  498 */  false,
  /*  499 */  false,
  /*  500 */  false,
  /*  501 */  false,
  /*  502 */  false,
  /*  503 */  false,
  /*  504 */  false,
  /*  505 */  false,
  /*  506 */  false,
  /*  507 */  false,
  /*  508 */  false,
  /*  509 */  false,
  /*  510 */  false,
  /*  511 */  false,
  /*  512 */  false,
  /*  513 */  false,
  /*  514 */  false,
  /*  515 */  false,
  /*  516 */  false,
  /*  517 */  false,
  /*  518 */  false,
  /*  519 */  false,
  /*  520 */  false,
  /*  521 */  false,
  /*  522 */  false,
  /*  523 */  false,
  /*  524 */  false,
  /*  525 */  false,
  /*  526 */  false,
  /*  527 */  false,
  /*  528 */  false,
  /*  529 */  false,
  /*  530 */  false,
  /*  531 */  false,
  /*  532 */  false,
  /*  533 */  false,
  /*  534 */  false,
  /*  535 */  false,
  /*  536 */  false,
  /*  537 */  false,
  /*  538 */  false,
  /*  539 */  false,
  /*  540 */  false,
  /*  541 */  false,
  /*  542 */  false,
  /*  543 */  false,
  /*  544 */  false,
  /*  545 */  false,
  /*  546 */  false,
  /*  547 */  false,
  /*  548 */  false,
  /*  549 */  false,
  /*  550 */  false,
  /*  551 */  false,
  /*  552 */  false,
  /*  553 */  false,
  /*  554 */  false,
  /*  555 */  false,
  /*  556 */  false,
  /*  557 */  false,
  /*  558 */  false,
  /*  559 */  false,
  /*  560 */  false,
  /*  561 */  false,
  /*  562 */  false,
  /*  563 */  false,
  /*  564 */  false,
  /*  565 */  false,
  /*  566 */  false,
  /*  567 */  false,
  /*  568 */  false,
  /*  569 */  false,
  /*  570 */  false,
  /*  571 */  false,
  /*  572 */  false,
  /*  573 */  false,
  /*  574 */  false,
  /*  575 */  false,
  /*  576 */  false,
  /*  577 */  false,
  /*  578 */  false,
  /*  579 */  false,
  /*  580 */  false,
  /*  581 */  false,
  /*  582 */  false,
  /*  583 */  false,
  /*  584 */  false,
  /*  585 */  false,
  /*  586 */  false,
  /*  587 */  false,
  /*  588 */  false,
  /*  589 */  false,
  /*  590 */  false,
  /*  591 */  false,
  /*  592 */  false,
  /*  593 */  false,
  /*  594 */  false,
  /*  595 */  false,
  /*  596 */  false,
  /*  597 */  false,
  /*  598 */  false,
  /*  599 */  false,
  /*  600 */  false,
  /*  601 */  false,
  /*  602 */  false,
  /*  603 */  false,
  /*  604 */  false,
  /*  605 */  false,
  /*  606 */  false,
  /*  607 */  false,
  /*  608 */  false,
  /*  609 */  false,
  /*  610 */  false,
  /*  611 */  false,
  /*  612 */  false,
  /*  613 */  false,
  /*  614 */  false,
  /*  615 */  false,
  /*  616 */  false,
  /*  617 */  false,
  /*  618 */  false,
  /*  619 */  false,
  /*  620 */  false,
  /*  621 */  false,
  /*  622 */  false,
  /*  623 */  false,
  /*  624 */  false,
  /*  625 */  false,
  /*  626 */  false,
  /*  627 */  false,
  /*  628 */  false,
  /*  629 */  false,
  /*  630 */  false,
  /*  631 */  false,
  /*  632 */  false,
  /*  633 */  false,
  /*  634 */  false,
  /*  635 */  false,
  /*  636 */  false,
  /*  637 */  false,
  /*  638 */  false,
  /*  639 */  false,
  /*  640 */  false,
  /*  641 */  false,
  /*  642 */  false,
  /*  643 */  false,
  /*  644 */  false,
  /*  645 */  false,
  /*  646 */  false,
  /*  647 */  false,
  /*  648 */  false,
  /*  649 */  false,
  /*  650 */  false,
  /*  651 */  false,
  /*  652 */  false,
  /*  653 */  false,
  /*  654 */  false,
  /*  655 */  false,
  /*  656 */  false,
  /*  657 */  false,
  /*  658 */  false,
  /*  659 */  false,
  /*  660 */  false,
  /*  661 */  false,
  /*  662 */  false,
  /*  663 */  false,
  /*  664 */  false,
  /*  665 */  false,
  /*  666 */  false,
  /*  667 */  false,
  /*  668 */  false,
  /*  669 */  false,
  /*  670 */  false,
  /*  671 */  false,
  /*  672 */  false,
  /*  673 */  false,
  /*  674 */  false,
  /*  675 */  false,
  /*  676 */  false,
  /*  677 */  false,
  /*  678 */  false,
  /*  679 */  false,
  /*  680 */  false,
  /*  681 */  false,
  /*  682 */  false,
  /*  683 */  false,
  /*  684 */  false,
  /*  685 */  false,
  /*  686 */  false,
  /*  687 */  false,
  /*  688 */  false,
  /*  689 */  false,
  /*  690 */  false,
  /*  691 */  false,
  /*  692 */  false,
  /*  693 */  false,
  /*  694 */  false,
  /*  695 */  false,
  /*  696 */  false,
  /*  697 */  false,
  /*  698 */  false,
  /*  699 */  false,
  /*  700 */  false,
  /*  701 */  false,
  /*  702 */  false,
  /*  703 */  false,
  /*  704 */  false,
  /*  705 */  false,
  /*  706 */  false,
  /*  707 */  false,
  /*  708 */  false,
  /*  709 */  false,
  /*  710 */  false,
  /*  711 */  false,
  /*  712 */  false,
  /*  713 */  false,
  /*  714 */  false,
  /*  715 */  false,
  /*  716 */  false,
  /*  717 */  false,
  /*  718 */  false,
  /*  719 */  false,
  /*  720 */  false,
  /*  721 */  false,
  /*  722 */  false,
  /*  723 */  false,
  /*  724 */  false,
  /*  725 */  false,
  /*  726 */  false,
  /*  727 */  false,
  /*  728 */  false,
  /*  729 */  false,
  /*  730 */  false,
  /*  731 */  false,
  /*  732 */  false,
  /*  733 */  false,
  /*  734 */  false,
  /*  735 */  false,
  /*  736 */  false,
  /*  737 */  false,
  /*  738 */  false,
  /*  739 */  false,
  /*  740 */  false,
  /*  741 */  false,
  /*  742 */  false,
  /*  743 */  false,
  /*  744 */  false,
  /*  745 */  false,
  /*  746 */  false,
  /*  747 */  false,
  /*  748 */  false,
  /*  749 */  false,
  /*  750 */  false,
  /*  751 */  false,
  /*  752 */  false,
  /*  753 */  false,
  /*  754 */  false,
  /*  755 */  false,
  /*  756 */  false,
  /*  757 */  false,
  /*  758 */  false,
  /*  759 */  false,
  /*  760 */  false,
  /*  761 */  false,
  /*  762 */  false,
  /*  763 */  false,
  /*  764 */  false,
  /*  765 */  false,
  /*  766 */  false,
  /*  767 */  false,
  /*  768 */  false,
  /*  769 */  false,
  /*  770 */  false,
  /*  771 */  false,
  /*  772 */  false,
  /*  773 */  false,
  /*  774 */  false,
  /*  775 */  false,
  /*  776 */  false,
  /*  777 */  false,
  /*  778 */  false,
  /*  779 */  false,
  /*  780 */  false,
  /*  781 */  false,
  /*  782 */  false,
  /*  783 */  false,
  /*  784 */  false,
  /*  785 */  false,
  /*  786 */  false,
  /*  787 */  false,
  /*  788 */  false,
  /*  789 */  false,
  /*  790 */  false,
  /*  791 */  false,
  /*  792 */  false,
  /*  793 */  false,
  /*  794 */  false,
  /*  795 */  false,
  /*  796 */  false,
  // last instruction
  false // no trailing comma
};

// Mapping from machine-independent opcode to boolean
const        char must_clone[] = {
  0, // Node: 0
  0, // Set: 1
  0, // RegN: 2
  0, // RegI: 3
  0, // RegP: 4
  0, // RegF: 5
  0, // RegD: 6
  0, // RegL: 7
  0, // VecA: 8
  0, // VecS: 9
  0, // VecD: 10
  0, // VecX: 11
  0, // VecY: 12
  0, // VecZ: 13
  0, // RegVectMask: 14
  0, // RegFlags: 15
  0, // _last_machine_leaf: 16
  0, // AbsD: 17
  0, // AbsF: 18
  0, // AbsI: 19
  0, // AbsL: 20
  0, // AddD: 21
  0, // AddF: 22
  0, // AddI: 23
  0, // AddL: 24
  0, // AddP: 25
  0, // Allocate: 26
  0, // AllocateArray: 27
  0, // AndI: 28
  0, // AndL: 29
  0, // ArrayCopy: 30
  0, // AryEq: 31
  0, // AtanD: 32
  1, // Binary: 33
  0, // Blackhole: 34
  1, // Bool: 35
  0, // BoxLock: 36
  0, // ReverseBytesI: 37
  0, // ReverseBytesL: 38
  0, // ReverseBytesUS: 39
  0, // ReverseBytesS: 40
  0, // ReverseBytesV: 41
  0, // CProj: 42
  0, // CacheWB: 43
  0, // CacheWBPreSync: 44
  0, // CacheWBPostSync: 45
  0, // CallDynamicJava: 46
  0, // CallJava: 47
  0, // CallLeaf: 48
  0, // CallLeafNoFP: 49
  0, // CallLeafVector: 50
  0, // CallRuntime: 51
  0, // CallStaticJava: 52
  0, // CastDD: 53
  0, // CastFF: 54
  0, // CastII: 55
  0, // CastLL: 56
  0, // CastVV: 57
  0, // CastX2P: 58
  0, // CastP2X: 59
  0, // CastPP: 60
  0, // Catch: 61
  0, // CatchProj: 62
  0, // CheckCastPP: 63
  0, // ClearArray: 64
  0, // CompressBits: 65
  0, // ExpandBits: 66
  0, // CompressBitsV: 67
  0, // ExpandBitsV: 68
  0, // ConstraintCast: 69
  0, // CMoveD: 70
  0, // CMoveF: 71
  0, // CMoveI: 72
  0, // CMoveL: 73
  0, // CMoveP: 74
  0, // CMoveN: 75
  1, // CmpN: 76
  1, // CmpD: 77
  0, // CmpD3: 78
  1, // CmpF: 79
  0, // CmpF3: 80
  1, // CmpI: 81
  1, // CmpL: 82
  0, // CmpL3: 83
  0, // CmpLTMask: 84
  1, // CmpP: 85
  1, // CmpU: 86
  0, // CmpU3: 87
  1, // CmpUL: 88
  0, // CmpUL3: 89
  0, // CompareAndSwapB: 90
  0, // CompareAndSwapS: 91
  0, // CompareAndSwapI: 92
  0, // CompareAndSwapL: 93
  0, // CompareAndSwapP: 94
  0, // CompareAndSwapN: 95
  0, // WeakCompareAndSwapB: 96
  0, // WeakCompareAndSwapS: 97
  0, // WeakCompareAndSwapI: 98
  0, // WeakCompareAndSwapL: 99
  0, // WeakCompareAndSwapP: 100
  0, // WeakCompareAndSwapN: 101
  0, // CompareAndExchangeB: 102
  0, // CompareAndExchangeS: 103
  0, // CompareAndExchangeI: 104
  0, // CompareAndExchangeL: 105
  0, // CompareAndExchangeP: 106
  0, // CompareAndExchangeN: 107
  0, // GetAndAddB: 108
  0, // GetAndAddS: 109
  0, // GetAndAddI: 110
  0, // GetAndAddL: 111
  0, // GetAndSetB: 112
  0, // GetAndSetS: 113
  0, // GetAndSetI: 114
  0, // GetAndSetL: 115
  0, // GetAndSetP: 116
  0, // GetAndSetN: 117
  0, // Con: 118
  0, // ConN: 119
  0, // ConNKlass: 120
  0, // ConD: 121
  0, // ConF: 122
  0, // ConI: 123
  0, // ConL: 124
  0, // ConP: 125
  0, // Conv2B: 126
  0, // ConvD2F: 127
  0, // ConvD2I: 128
  0, // ConvD2L: 129
  0, // ConvF2D: 130
  0, // ConvF2I: 131
  0, // ConvF2L: 132
  0, // ConvI2D: 133
  0, // ConvI2F: 134
  0, // ConvI2L: 135
  0, // ConvL2D: 136
  0, // ConvL2F: 137
  0, // ConvL2I: 138
  0, // ConvF2HF: 139
  0, // ConvHF2F: 140
  0, // CountedLoop: 141
  0, // CountedLoopEnd: 142
  0, // OuterStripMinedLoop: 143
  0, // OuterStripMinedLoopEnd: 144
  0, // LongCountedLoop: 145
  0, // LongCountedLoopEnd: 146
  0, // CountLeadingZerosI: 147
  0, // CountLeadingZerosL: 148
  0, // CountLeadingZerosV: 149
  0, // CountTrailingZerosI: 150
  0, // CountTrailingZerosL: 151
  0, // CountTrailingZerosV: 152
  0, // CreateEx: 153
  0, // DecodeN: 154
  0, // DecodeNKlass: 155
  0, // DivD: 156
  0, // DivF: 157
  0, // DivI: 158
  0, // DivL: 159
  0, // UDivI: 160
  0, // UDivL: 161
  0, // DivMod: 162
  0, // DivModI: 163
  0, // DivModL: 164
  0, // UDivModI: 165
  0, // UDivModL: 166
  0, // EncodeISOArray: 167
  0, // EncodeP: 168
  0, // EncodePKlass: 169
  1, // FastLock: 170
  1, // FastUnlock: 171
  0, // FmaD: 172
  0, // FmaF: 173
  0, // Goto: 174
  0, // Halt: 175
  0, // CountPositives: 176
  0, // If: 177
  0, // RangeCheck: 178
  0, // IfFalse: 179
  0, // IfTrue: 180
  0, // Initialize: 181
  0, // JProj: 182
  0, // Jump: 183
  0, // JumpProj: 184
  0, // LShiftI: 185
  0, // LShiftL: 186
  0, // LoadB: 187
  0, // LoadUB: 188
  0, // LoadUS: 189
  0, // LoadD: 190
  0, // LoadD_unaligned: 191
  0, // LoadF: 192
  0, // LoadI: 193
  0, // LoadKlass: 194
  0, // LoadNKlass: 195
  0, // LoadL: 196
  0, // LoadL_unaligned: 197
  0, // LoadP: 198
  0, // LoadN: 199
  0, // LoadRange: 200
  0, // LoadS: 201
  0, // Lock: 202
  0, // Loop: 203
  0, // LoopLimit: 204
  0, // Mach: 205
  0, // MachNullCheck: 206
  0, // MachProj: 207
  0, // MulAddS2I: 208
  0, // MaxI: 209
  0, // MaxL: 210
  0, // MaxD: 211
  0, // MaxF: 212
  0, // MemBarAcquire: 213
  0, // LoadFence: 214
  0, // MemBarAcquireLock: 215
  0, // MemBarCPUOrder: 216
  0, // MemBarRelease: 217
  0, // StoreFence: 218
  0, // StoreStoreFence: 219
  0, // MemBarReleaseLock: 220
  0, // MemBarVolatile: 221
  0, // MemBarStoreStore: 222
  0, // MergeMem: 223
  0, // MinI: 224
  0, // MinL: 225
  0, // MinF: 226
  0, // MinD: 227
  0, // ModD: 228
  0, // ModF: 229
  0, // ModI: 230
  0, // ModL: 231
  0, // UModI: 232
  0, // UModL: 233
  0, // MoveI2F: 234
  0, // MoveF2I: 235
  0, // MoveL2D: 236
  0, // MoveD2L: 237
  0, // IsInfiniteF: 238
  0, // IsFiniteF: 239
  0, // IsInfiniteD: 240
  0, // IsFiniteD: 241
  0, // MulD: 242
  0, // MulF: 243
  0, // MulHiL: 244
  0, // UMulHiL: 245
  0, // MulI: 246
  0, // MulL: 247
  0, // Multi: 248
  0, // NegI: 249
  0, // NegL: 250
  0, // NegD: 251
  0, // NegF: 252
  0, // NeverBranch: 253
  0, // OnSpinWait: 254
  0, // Opaque1: 255
  0, // OpaqueLoopInit: 256
  0, // OpaqueLoopStride: 257
  0, // OpaqueZeroTripGuard: 258
  0, // Opaque3: 259
  0, // Opaque4: 260
  0, // ProfileBoolean: 261
  0, // OrI: 262
  0, // OrL: 263
  1, // OverflowAddI: 264
  1, // OverflowSubI: 265
  1, // OverflowMulI: 266
  1, // OverflowAddL: 267
  1, // OverflowSubL: 268
  1, // OverflowMulL: 269
  0, // PCTable: 270
  0, // Parm: 271
  0, // ParsePredicate: 272
  0, // PartialSubtypeCheck: 273
  0, // SubTypeCheck: 274
  0, // Phi: 275
  0, // PopCountI: 276
  0, // PopCountL: 277
  0, // PopCountVI: 278
  0, // PopCountVL: 279
  0, // PopulateIndex: 280
  0, // PrefetchAllocation: 281
  0, // Proj: 282
  0, // RShiftI: 283
  0, // RShiftL: 284
  0, // Region: 285
  0, // Rethrow: 286
  0, // Return: 287
  0, // ReverseI: 288
  0, // ReverseL: 289
  0, // ReverseV: 290
  0, // Root: 291
  0, // RoundDouble: 292
  0, // RoundDoubleMode: 293
  0, // RoundDoubleModeV: 294
  0, // RoundFloat: 295
  0, // RotateLeft: 296
  0, // RotateLeftV: 297
  0, // RotateRight: 298
  0, // RotateRightV: 299
  0, // SafePoint: 300
  0, // SafePointScalarObject: 301
  0, // ShenandoahCompareAndExchangeP: 302
  0, // ShenandoahCompareAndExchangeN: 303
  0, // ShenandoahCompareAndSwapN: 304
  0, // ShenandoahCompareAndSwapP: 305
  0, // ShenandoahWeakCompareAndSwapN: 306
  0, // ShenandoahWeakCompareAndSwapP: 307
  0, // ShenandoahIUBarrier: 308
  0, // ShenandoahLoadReferenceBarrier: 309
  0, // SCMemProj: 310
  0, // CopySignD: 311
  0, // CopySignF: 312
  0, // SignumD: 313
  0, // SignumF: 314
  0, // SignumVF: 315
  0, // SignumVD: 316
  0, // SqrtD: 317
  0, // SqrtF: 318
  0, // RoundF: 319
  0, // RoundD: 320
  0, // Start: 321
  0, // StartOSR: 322
  0, // StoreB: 323
  0, // StoreC: 324
  0, // StoreCM: 325
  0, // StoreD: 326
  0, // StoreF: 327
  0, // StoreI: 328
  0, // StoreL: 329
  0, // StoreP: 330
  0, // StoreN: 331
  0, // StoreNKlass: 332
  0, // StrComp: 333
  0, // StrCompressedCopy: 334
  0, // StrEquals: 335
  0, // StrIndexOf: 336
  0, // StrIndexOfChar: 337
  0, // StrInflatedCopy: 338
  0, // SubD: 339
  0, // SubF: 340
  0, // SubI: 341
  0, // SubL: 342
  0, // TailCall: 343
  0, // TailJump: 344
  0, // MacroLogicV: 345
  0, // ThreadLocal: 346
  0, // Unlock: 347
  0, // URShiftB: 348
  0, // URShiftS: 349
  0, // URShiftI: 350
  0, // URShiftL: 351
  0, // XorI: 352
  0, // XorL: 353
  0, // Vector: 354
  0, // AddVB: 355
  0, // AddVS: 356
  0, // AddVI: 357
  0, // AddReductionVI: 358
  0, // AddVL: 359
  0, // AddReductionVL: 360
  0, // AddVF: 361
  0, // AddReductionVF: 362
  0, // AddVD: 363
  0, // AddReductionVD: 364
  0, // SubVB: 365
  0, // SubVS: 366
  0, // SubVI: 367
  0, // SubVL: 368
  0, // SubVF: 369
  0, // SubVD: 370
  0, // MulVB: 371
  0, // MulVS: 372
  0, // MulVI: 373
  0, // MulReductionVI: 374
  0, // MulVL: 375
  0, // MulReductionVL: 376
  0, // MulVF: 377
  0, // MulReductionVF: 378
  0, // MulVD: 379
  0, // MulReductionVD: 380
  0, // MulAddVS2VI: 381
  0, // FmaVD: 382
  0, // FmaVF: 383
  0, // DivVF: 384
  0, // DivVD: 385
  0, // AbsVB: 386
  0, // AbsVS: 387
  0, // AbsVI: 388
  0, // AbsVL: 389
  0, // AbsVF: 390
  0, // AbsVD: 391
  0, // NegVI: 392
  0, // NegVL: 393
  0, // NegVF: 394
  0, // NegVD: 395
  0, // SqrtVD: 396
  0, // SqrtVF: 397
  0, // LShiftCntV: 398
  0, // RShiftCntV: 399
  0, // LShiftVB: 400
  0, // LShiftVS: 401
  0, // LShiftVI: 402
  0, // LShiftVL: 403
  0, // RShiftVB: 404
  0, // RShiftVS: 405
  0, // RShiftVI: 406
  0, // RShiftVL: 407
  0, // URShiftVB: 408
  0, // URShiftVS: 409
  0, // URShiftVI: 410
  0, // URShiftVL: 411
  0, // AndV: 412
  0, // AndReductionV: 413
  0, // OrV: 414
  0, // OrReductionV: 415
  0, // XorV: 416
  0, // XorReductionV: 417
  0, // MinV: 418
  0, // MaxV: 419
  0, // MinReductionV: 420
  0, // MaxReductionV: 421
  0, // CompressV: 422
  0, // CompressM: 423
  0, // ExpandV: 424
  0, // LoadVector: 425
  0, // LoadVectorGather: 426
  0, // LoadVectorGatherMasked: 427
  0, // StoreVector: 428
  0, // StoreVectorScatter: 429
  0, // StoreVectorScatterMasked: 430
  0, // LoadVectorMasked: 431
  0, // StoreVectorMasked: 432
  0, // VectorCmpMasked: 433
  0, // VectorMaskGen: 434
  0, // VectorMaskOp: 435
  0, // VectorMaskTrueCount: 436
  0, // VectorMaskFirstTrue: 437
  0, // VectorMaskLastTrue: 438
  0, // VectorMaskToLong: 439
  0, // VectorLongToMask: 440
  0, // Pack: 441
  0, // PackB: 442
  0, // PackS: 443
  0, // PackI: 444
  0, // PackL: 445
  0, // PackF: 446
  0, // PackD: 447
  0, // Pack2L: 448
  0, // Pack2D: 449
  0, // ReplicateB: 450
  0, // ReplicateS: 451
  0, // ReplicateI: 452
  0, // ReplicateL: 453
  0, // ReplicateF: 454
  0, // ReplicateD: 455
  0, // RoundVF: 456
  0, // RoundVD: 457
  0, // Extract: 458
  0, // ExtractB: 459
  0, // ExtractUB: 460
  0, // ExtractC: 461
  0, // ExtractS: 462
  0, // ExtractI: 463
  0, // ExtractL: 464
  0, // ExtractF: 465
  0, // ExtractD: 466
  0, // Digit: 467
  0, // LowerCase: 468
  0, // UpperCase: 469
  0, // Whitespace: 470
  0, // VectorBox: 471
  0, // VectorBoxAllocate: 472
  0, // VectorUnbox: 473
  0, // VectorMaskWrapper: 474
  0, // VectorMaskCmp: 475
  0, // VectorMaskCast: 476
  1, // VectorTest: 477
  0, // VectorBlend: 478
  0, // VectorRearrange: 479
  0, // VectorLoadMask: 480
  0, // VectorLoadShuffle: 481
  0, // VectorLoadConst: 482
  0, // VectorStoreMask: 483
  0, // VectorReinterpret: 484
  0, // VectorCast: 485
  0, // VectorCastB2X: 486
  0, // VectorCastS2X: 487
  0, // VectorCastI2X: 488
  0, // VectorCastL2X: 489
  0, // VectorCastF2X: 490
  0, // VectorCastD2X: 491
  0, // VectorCastF2HF: 492
  0, // VectorCastHF2F: 493
  0, // VectorUCastB2X: 494
  0, // VectorUCastS2X: 495
  0, // VectorUCastI2X: 496
  0, // VectorizedHashCode: 497
  0, // VectorInsert: 498
  0, // MaskAll: 499
  0, // AndVMask: 500
  0, // OrVMask: 501
  0 // no trailing comma // XorVMask: 502
};
//  The following instructions can cisc-spill



// An array of character pointers to machine register names.
const char *Matcher::regName[REG_COUNT] = {
  "R_R4",
  "R_R5",
  "R_R6",
  "R_R7",
  "R_R8",
  "R_R9",
  "R_R11",
  "R_R12",
  "R_R10",
  "R_R13",
  "R_R14",
  "R_R15",
  "R_R0",
  "R_R1",
  "R_R2",
  "R_R3",
  "R_S16",
  "R_S17",
  "R_S18",
  "R_S19",
  "R_S20",
  "R_S21",
  "R_S22",
  "R_S23",
  "R_S24",
  "R_S25",
  "R_S26",
  "R_S27",
  "R_S28",
  "R_S29",
  "R_S30",
  "R_S31",
  "R_S0",
  "R_S1",
  "R_S2",
  "R_S3",
  "R_S4",
  "R_S5",
  "R_S6",
  "R_S7",
  "R_S8",
  "R_S9",
  "R_S10",
  "R_S11",
  "R_S12",
  "R_S13",
  "R_S14",
  "R_S15",
  "R_D16",
  "R_D16x",
  "R_D17",
  "R_D17x",
  "R_D18",
  "R_D18x",
  "R_D19",
  "R_D19x",
  "R_D20",
  "R_D20x",
  "R_D21",
  "R_D21x",
  "R_D22",
  "R_D22x",
  "R_D23",
  "R_D23x",
  "R_D24",
  "R_D24x",
  "R_D25",
  "R_D25x",
  "R_D26",
  "R_D26x",
  "R_D27",
  "R_D27x",
  "R_D28",
  "R_D28x",
  "R_D29",
  "R_D29x",
  "R_D30",
  "R_D30x",
  "R_D31",
  "R_D31x",
  "APSR",
  "FPSCR" // no trailing comma
};

// An array of character pointers to machine register names.
const VMReg OptoReg::opto2vm[REG_COUNT] = {
	R(4)->as_VMReg(),
	R(5)->as_VMReg(),
	R(6)->as_VMReg(),
	R(7)->as_VMReg(),
	R(8)->as_VMReg(),
	R(9)->as_VMReg(),
	R(11)->as_VMReg(),
	R(12)->as_VMReg(),
	R(10)->as_VMReg(),
	R(13)->as_VMReg(),
	R(14)->as_VMReg(),
	R(15)->as_VMReg(),
	R(0)->as_VMReg(),
	R(1)->as_VMReg(),
	R(2)->as_VMReg(),
	R(3)->as_VMReg(),
	S16->as_VMReg(),
	S17->as_VMReg(),
	S18->as_VMReg(),
	S19->as_VMReg(),
	S20->as_VMReg(),
	S21->as_VMReg(),
	S22->as_VMReg(),
	S23->as_VMReg(),
	S24->as_VMReg(),
	S25->as_VMReg(),
	S26->as_VMReg(),
	S27->as_VMReg(),
	S28->as_VMReg(),
	S29->as_VMReg(),
	S30->as_VMReg(),
	S31->as_VMReg(),
	S0->as_VMReg(),
	S1_reg->as_VMReg(),
	S2_reg->as_VMReg(),
	S3_reg->as_VMReg(),
	S4_reg->as_VMReg(),
	S5_reg->as_VMReg(),
	S6_reg->as_VMReg(),
	S7->as_VMReg(),
	S8->as_VMReg(),
	S9->as_VMReg(),
	S10->as_VMReg(),
	S11->as_VMReg(),
	S12->as_VMReg(),
	S13->as_VMReg(),
	S14->as_VMReg(),
	S15->as_VMReg(),
	D16->as_VMReg(),
	D16->as_VMReg()->next(),
	D17->as_VMReg(),
	D17->as_VMReg()->next(),
	D18->as_VMReg(),
	D18->as_VMReg()->next(),
	D19->as_VMReg(),
	D19->as_VMReg()->next(),
	D20->as_VMReg(),
	D20->as_VMReg()->next(),
	D21->as_VMReg(),
	D21->as_VMReg()->next(),
	D22->as_VMReg(),
	D22->as_VMReg()->next(),
	D23->as_VMReg(),
	D23->as_VMReg()->next(),
	D24->as_VMReg(),
	D24->as_VMReg()->next(),
	D25->as_VMReg(),
	D25->as_VMReg()->next(),
	D26->as_VMReg(),
	D26->as_VMReg()->next(),
	D27->as_VMReg(),
	D27->as_VMReg()->next(),
	D28->as_VMReg(),
	D28->as_VMReg()->next(),
	D29->as_VMReg(),
	D29->as_VMReg()->next(),
	D30->as_VMReg(),
	D30->as_VMReg()->next(),
	D31->as_VMReg(),
	D31->as_VMReg()->next(),
	VMRegImpl::Bad(),
	VMRegImpl::Bad() // no trailing comma
	};

 OptoReg::Name OptoReg::vm2opto[ConcreteRegisterImpl::number_of_registers];

// An array of the machine register encode values
const unsigned char Matcher::_regEncode[REG_COUNT] = {
  (unsigned char)'\x4',  // R_R4
  (unsigned char)'\x5',  // R_R5
  (unsigned char)'\x6',  // R_R6
  (unsigned char)'\x7',  // R_R7
  (unsigned char)'\x8',  // R_R8
  (unsigned char)'\x9',  // R_R9
  (unsigned char)'\xB',  // R_R11
  (unsigned char)'\xC',  // R_R12
  (unsigned char)'\xA',  // R_R10
  (unsigned char)'\xD',  // R_R13
  (unsigned char)'\xE',  // R_R14
  (unsigned char)'\xF',  // R_R15
  (unsigned char)'\x0',  // R_R0
  (unsigned char)'\x1',  // R_R1
  (unsigned char)'\x2',  // R_R2
  (unsigned char)'\x3',  // R_R3
  (unsigned char)'\x10',  // R_S16
  (unsigned char)'\x11',  // R_S17
  (unsigned char)'\x12',  // R_S18
  (unsigned char)'\x13',  // R_S19
  (unsigned char)'\x14',  // R_S20
  (unsigned char)'\x15',  // R_S21
  (unsigned char)'\x16',  // R_S22
  (unsigned char)'\x17',  // R_S23
  (unsigned char)'\x18',  // R_S24
  (unsigned char)'\x19',  // R_S25
  (unsigned char)'\x1A',  // R_S26
  (unsigned char)'\x1B',  // R_S27
  (unsigned char)'\x1C',  // R_S28
  (unsigned char)'\x1D',  // R_S29
  (unsigned char)'\x1E',  // R_S30
  (unsigned char)'\x1F',  // R_S31
  (unsigned char)'\x0',  // R_S0
  (unsigned char)'\x1',  // R_S1
  (unsigned char)'\x2',  // R_S2
  (unsigned char)'\x3',  // R_S3
  (unsigned char)'\x4',  // R_S4
  (unsigned char)'\x5',  // R_S5
  (unsigned char)'\x6',  // R_S6
  (unsigned char)'\x7',  // R_S7
  (unsigned char)'\x8',  // R_S8
  (unsigned char)'\x9',  // R_S9
  (unsigned char)'\xA',  // R_S10
  (unsigned char)'\xB',  // R_S11
  (unsigned char)'\xC',  // R_S12
  (unsigned char)'\xD',  // R_S13
  (unsigned char)'\xE',  // R_S14
  (unsigned char)'\xF',  // R_S15
  (unsigned char)'\x20',  // R_D16
  (unsigned char)'\xFF',  // R_D16x
  (unsigned char)'\x22',  // R_D17
  (unsigned char)'\xFF',  // R_D17x
  (unsigned char)'\x24',  // R_D18
  (unsigned char)'\xFF',  // R_D18x
  (unsigned char)'\x26',  // R_D19
  (unsigned char)'\xFF',  // R_D19x
  (unsigned char)'\x28',  // R_D20
  (unsigned char)'\xFF',  // R_D20x
  (unsigned char)'\x2A',  // R_D21
  (unsigned char)'\xFF',  // R_D21x
  (unsigned char)'\x2C',  // R_D22
  (unsigned char)'\xFF',  // R_D22x
  (unsigned char)'\x2E',  // R_D23
  (unsigned char)'\xFF',  // R_D23x
  (unsigned char)'\x30',  // R_D24
  (unsigned char)'\xFF',  // R_D24x
  (unsigned char)'\x32',  // R_D25
  (unsigned char)'\xFF',  // R_D25x
  (unsigned char)'\x34',  // R_D26
  (unsigned char)'\xFF',  // R_D26x
  (unsigned char)'\x36',  // R_D27
  (unsigned char)'\xFF',  // R_D27x
  (unsigned char)'\x38',  // R_D28
  (unsigned char)'\xFF',  // R_D28x
  (unsigned char)'\x3A',  // R_D29
  (unsigned char)'\xFF',  // R_D29x
  (unsigned char)'\x3C',  // R_D30
  (unsigned char)'\xFF',  // R_D30x
  (unsigned char)'\x3E',  // R_D31
  (unsigned char)'\xFF',  // R_D31x
  (unsigned char)'\x0',  // APSR
  (unsigned char)'\x0' // no trailing comma  // FPSCR
};


//------------------Define classes derived from MachOper---------------------
MachOper  *labelOper::clone() const {
  return  new labelOper(_label, _block_num);
}
uint labelOper::opcode() const { return LABEL; }

const RegMask *sRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

const RegMask *sRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &(Compile::current()->FIRST_STACK_mask());
}

MachOper  *methodOper::clone() const {
  return  new methodOper(_method);
}
uint methodOper::opcode() const { return METHOD; }

const RegMask *iRegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

const RegMask *iRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &PTR_REG_mask();
}

const RegMask *sp_ptr_RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *R0RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REGP_mask();
}

const RegMask *R1RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REGP_mask();
}

const RegMask *R8RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R8_REGP_mask();
}

const RegMask *R9RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R9_REGP_mask();
}

const RegMask *R12RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R12_REGP_mask();
}

const RegMask *R2RegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REGP_mask();
}

const RegMask *RExceptionRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &REXCEPTION_REGP_mask();
}

const RegMask *RthreadRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RTHREAD_REGP_mask();
}

const RegMask *IPRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &IP_REGP_mask();
}

const RegMask *SPRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_REGP_mask();
}

const RegMask *LRRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LR_REGP_mask();
}

const RegMask *R0RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0_REGI_mask();
}

const RegMask *R1RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R1_REGI_mask();
}

const RegMask *R2RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2_REGI_mask();
}

const RegMask *R3RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R3_REGI_mask();
}

const RegMask *R12RegIOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R12_REGI_mask();
}

const RegMask *iRegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_REG_mask();
}

const RegMask *iRegLdOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &LONG_REG_ALIGN_mask();
}

const RegMask *R0R1RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R0R1_REGL_mask();
}

const RegMask *R2R3RegLOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &R2R3_REGL_mask();
}

const RegMask *flagsRegOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsReg_EQNELTGEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegUOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegL_LTGEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegL_EQNEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegL_LEGTOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegUL_LTGEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegUL_EQNEOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegUL_LEGTOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_FLAGS_mask();
}

const RegMask *flagsRegFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &FLOAT_FLAGS_mask();
}

const RegMask *vecDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ACTUAL_DFLT_REG_mask();
}

const RegMask *vecXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &VECTORX_REG_mask();
}

const RegMask *regDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &ACTUAL_DFLT_REG_mask();
}

const RegMask *regFOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SFLT_REG_mask();
}

const RegMask *regD_lowOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &DFLT_LOW_REG_mask();
}

const RegMask *inline_cache_regPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &RICKLASS_REGP_mask();
}

const RegMask *indirectOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *indOffset12Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *indOffsetFPOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *indOffsetHDOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *indOffsetFPx2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *indOffset12x2Oper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &SP_PTR_REG_mask();
}

const RegMask *indIndexOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &INT_REG_mask();
  }
  ShouldNotReachHere();
  return nullptr;
}

const RegMask *indIndexScaleOper::in_RegMask(int index) const {
  assert(0 <= index && index < 2, "index out of range");
  switch (index) {
  case 0: return &PTR_REG_mask();
  case 1: return &INT_REG_mask();
  }
  ShouldNotReachHere();
  return nullptr;
}

const RegMask *shiftedXOper::in_RegMask(int index) const {
  assert(0 <= index && index < 1, "index out of range");
  return &INT_REG_mask();
}

//------------------Define members for classes derived from MachNode----------

// Copy _idx, inputs and operands to new node
void MachNode::fill_new_machnode(MachNode* node) const {
  // This architecture does not have cisc or short branch instructions
  ShouldNotCallThis();
}

void branchNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(1));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchCon_EQNELTGENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchCon_EQNELTGENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConPNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConPNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConL_LTGENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConL_LTGENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConL_EQNENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConL_EQNENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConL_LEGTNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConL_LEGTNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUL_LTGENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUL_LTGENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUL_EQNENode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUL_EQNENode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchConUL_LEGTNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchConUL_LEGTNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void branchLoopEndNode::label_set( Label* label, uint block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  oper->_label     = label;
  oper->_block_num = block_num;
}
void branchLoopEndNode::save_label( Label** label, uint* block_num ) {
  labelOper* oper  = (labelOper*)(opnd_array(3));
  *label = oper->_label;
  *block_num = oper->_block_num;
}
void CallStaticJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallStaticJavaHandleNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallDynamicJavaDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallRuntimeDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

void CallLeafNoFPDirectNode::method_set( intptr_t method ) {
  ((methodOper*)opnd_array(1))->_method = method;
}

int loadBNode::reloc() const {
  return 1;
}

int loadB2LNode::reloc() const {
  return 1;
}

int loadUBNode::reloc() const {
  return 1;
}

int loadUB2LNode::reloc() const {
  return 1;
}

int loadUB2L_limmINode::reloc() const {
  return 1;
}

int loadSNode::reloc() const {
  return 1;
}

int loadS2BNode::reloc() const {
  return 1;
}

int loadS2LNode::reloc() const {
  return 1;
}

int loadUSNode::reloc() const {
  return 1;
}

int loadUS2BNode::reloc() const {
  return 1;
}

int loadUS2LNode::reloc() const {
  return 1;
}

int loadUS2L_immI_255Node::reloc() const {
  return 1;
}

int loadUS2L_limmINode::reloc() const {
  return 1;
}

int loadINode::reloc() const {
  return 1;
}

int loadI2BNode::reloc() const {
  return 1;
}

int loadI2UBNode::reloc() const {
  return 1;
}

int loadI2SNode::reloc() const {
  return 1;
}

int loadI2USNode::reloc() const {
  return 1;
}

int loadI2LNode::reloc() const {
  return 1;
}

int loadI2L_immI_255Node::reloc() const {
  return 1;
}

int loadI2L_immI_65535Node::reloc() const {
  return 1;
}

int loadI2L_limmU31Node::reloc() const {
  return 1;
}

int loadI2L_immU31Node::reloc() const {
  return 1;
}

int loadUI2LNode::reloc() const {
  return 1;
}

int loadLNode::reloc() const {
  return 1;
}

int loadL_2instrNode::reloc() const {
  return 1;
}

int loadL_volatile_fpNode::reloc() const {
  return 1;
}

int loadL_unalignedNode::reloc() const {
  return 1;
}

int loadRangeNode::reloc() const {
  return 1;
}

int loadPNode::reloc() const {
  return 1;
}

int loadKlassNode::reloc() const {
  return 1;
}

int loadDNode::reloc() const {
  return 1;
}

int loadD_unalignedNode::reloc() const {
  return 1;
}

int loadFNode::reloc() const {
  return 1;
}

int loadConPNode::reloc() const {
  return 1;
}

int loadConF_imm8Node::reloc() const {
  return 2;
}

int loadConFNode::reloc() const {
  return 2;
}

int loadConD_imm8Node::reloc() const {
  return 2;
}

int loadConDNode::reloc() const {
  return 2;
}

int prefetchAlloc_mpNode::reloc() const {
  return 1;
}

int prefetchAlloc_spNode::reloc() const {
  return 1;
}

int storeBNode::reloc() const {
  return 2;
}

int storeCMNode::reloc() const {
  return 2;
}

int storeCNode::reloc() const {
  return 2;
}

int storeINode::reloc() const {
  return 2;
}

int storeLNode::reloc() const {
  return 2;
}

int storeL_2instrNode::reloc() const {
  return 2;
}

int storeL_volatile_fpNode::reloc() const {
  return 2;
}

int storePNode::reloc() const {
  return 2;
}

int storeDNode::reloc() const {
  return 2;
}

int storeFNode::reloc() const {
  return 2;
}

int cmovPP_immNode::reloc() const {
  return 1;
}

int cmovPI_immNode::reloc() const {
  return 1;
}

int cmovPI_imm_EQNELTGENode::reloc() const {
  return 1;
}

int cmovPIu_immNode::reloc() const {
  return 1;
}

int compareAndSwapL_boolNode::reloc() const {
  return 1;
}

int compareAndSwapI_boolNode::reloc() const {
  return 1;
}

int compareAndSwapP_boolNode::reloc() const {
  return 1;
}

int xaddI_aimmI_no_resNode::reloc() const {
  return 1;
}

int xaddI_reg_no_resNode::reloc() const {
  return 1;
}

int xaddI_aimmINode::reloc() const {
  return 1;
}

int xaddI_regNode::reloc() const {
  return 1;
}

int xaddL_reg_no_resNode::reloc() const {
  return 1;
}

int xaddL_immRot_no_resNode::reloc() const {
  return 1;
}

int xaddL_regNode::reloc() const {
  return 1;
}

int xaddL_immRotNode::reloc() const {
  return 1;
}

int xchgINode::reloc() const {
  return 1;
}

int xchgLNode::reloc() const {
  return 1;
}

int xchgPNode::reloc() const {
  return 1;
}

int compP_iRegP_immNode::reloc() const {
  return 1;
}

int cmpF0_ccNode::reloc() const {
  return 1;
}

int cmpD0_ccNode::reloc() const {
  return 1;
}

int cmpF0_regNode::reloc() const {
  return 1;
}

int cmpD0_regNode::reloc() const {
  return 1;
}

int cmovPL_imm_LTGENode::reloc() const {
  return 1;
}

int cmovPL_imm_LTGE_UNode::reloc() const {
  return 1;
}

int cmovPL_imm_EQNENode::reloc() const {
  return 1;
}

int cmovPL_imm_EQNE_UNode::reloc() const {
  return 1;
}

int cmovPL_imm_LEGTNode::reloc() const {
  return 1;
}

int cmovPL_imm_LEGT_UNode::reloc() const {
  return 1;
}

int safePoint_pollNode::reloc() const {
  return 1;
}

int CallStaticJavaDirectNode::reloc() const {
  return 1;
}

int CallStaticJavaHandleNode::reloc() const {
  return 1;
}

int CallDynamicJavaDirectNode::reloc() const {
  return 1;
}

int CallRuntimeDirectNode::reloc() const {
  return 1;
}

int CallLeafDirectNode::reloc() const {
  return 1;
}

int CallLeafNoFPDirectNode::reloc() const {
  return 1;
}

int TailCalljmpIndNode::reloc() const {
  return 1;
}

int RetNode::reloc() const {
  return 1;
}

int tailjmpIndNode::reloc() const {
  return 1;
}

int RethrowExceptionNode::reloc() const {
  return 1;
}

int loadV8Node::reloc() const {
  return 1;
}

int loadV16Node::reloc() const {
  return 1;
}

int storeV8Node::reloc() const {
  return 2;
}

int storeV16Node::reloc() const {
  return 2;
}

int Repl2F_immINode::reloc() const {
  return 1;
}


void loadBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3555 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7090 "ad_arm.cpp"
  }
}

uint loadBNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3569 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(0)->as_Register(ra_,this)/* dst */, asr, 31));
  
#line 7112 "ad_arm.cpp"
  }
}

uint loadB2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadUBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3583 "src/hotspot/cpu/arm/arm.ad"

    __ ldrb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7133 "ad_arm.cpp"
  }
}

uint loadUBNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUB2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3597 "src/hotspot/cpu/arm/arm.ad"

    __ ldrb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 7155 "ad_arm.cpp"
  }
}

uint loadUB2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadUB2L_limmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3613 "src/hotspot/cpu/arm/arm.ad"

    __ ldrb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, limmI_low(opnd_array(2)->constant(), 8));
  
#line 7179 "ad_arm.cpp"
  }
}

uint loadUB2L_limmINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3629 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7200 "ad_arm.cpp"
  }
}

uint loadSNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3643 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7222 "ad_arm.cpp"
  }
}

uint loadS2BNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3657 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(0)->as_Register(ra_,this)/* dst */, asr, 31));
  
#line 7244 "ad_arm.cpp"
  }
}

uint loadS2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadUSNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3673 "src/hotspot/cpu/arm/arm.ad"

    __ ldrh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7265 "ad_arm.cpp"
  }
}

uint loadUSNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUS2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3686 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7287 "ad_arm.cpp"
  }
}

uint loadUS2BNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadUS2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3700 "src/hotspot/cpu/arm/arm.ad"

    __ ldrh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 7309 "ad_arm.cpp"
  }
}

uint loadUS2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadUS2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3715 "src/hotspot/cpu/arm/arm.ad"

    __ ldrb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 7332 "ad_arm.cpp"
  }
}

uint loadUS2L_immI_255Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadUS2L_limmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3731 "src/hotspot/cpu/arm/arm.ad"

    __ ldrh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->constant());
  
#line 7356 "ad_arm.cpp"
  }
}

uint loadUS2L_limmINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3748 "src/hotspot/cpu/arm/arm.ad"

    __ ldr_s32(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7377 "ad_arm.cpp"
  }
}

uint loadINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2BNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// twentyfour
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3762 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7399 "ad_arm.cpp"
  }
}

uint loadI2BNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2UBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3776 "src/hotspot/cpu/arm/arm.ad"

    __ ldrb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7421 "ad_arm.cpp"
  }
}

uint loadI2UBNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2SNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// sixteen
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3789 "src/hotspot/cpu/arm/arm.ad"

    __ ldrsh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7443 "ad_arm.cpp"
  }
}

uint loadI2SNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2USNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3802 "src/hotspot/cpu/arm/arm.ad"

    __ ldrh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7465 "ad_arm.cpp"
  }
}

uint loadI2USNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3816 "src/hotspot/cpu/arm/arm.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(0)->as_Register(ra_,this)/* dst */, asr, 31));
  
#line 7487 "ad_arm.cpp"
  }
}

uint loadI2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadI2L_immI_255Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3831 "src/hotspot/cpu/arm/arm.ad"

    __ ldrb(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 7510 "ad_arm.cpp"
  }
}

uint loadI2L_immI_255Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadI2L_immI_65535Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3846 "src/hotspot/cpu/arm/arm.ad"

    __ ldrh(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 7533 "ad_arm.cpp"
  }
}

uint loadI2L_immI_65535Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadI2L_limmU31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3863 "src/hotspot/cpu/arm/arm.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->constant());
  
#line 7557 "ad_arm.cpp"
  }
}

uint loadI2L_limmU31Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void loadI2L_immU31Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3883 "src/hotspot/cpu/arm/arm.ad"

    __ ldr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0);
    __ mov_slow(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->constant());
    __ andr(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 7584 "ad_arm.cpp"
  }
}

uint loadI2L_immU31Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void loadUI2LNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3900 "src/hotspot/cpu/arm/arm.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 7607 "ad_arm.cpp"
  }
}

uint loadUI2LNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3918 "src/hotspot/cpu/arm/arm.ad"

    __ ldr_64(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7629 "ad_arm.cpp"
  }
}

uint loadLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadL_2instrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3932 "src/hotspot/cpu/arm/arm.ad"

    Address Amemlo = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), relocInfo::none);
    Address Amemhi = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, relocInfo::none);

    if (opnd_array(0)->as_Register(ra_,this)/* dst */== reg_to_register_object(opnd_array(1)->base(ra_,this,idx1))) {
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), Amemhi);
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Amemlo);
    } else {
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Amemlo);
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), Amemhi);
    }
  
#line 7659 "ad_arm.cpp"
  }
}

uint loadL_2instrNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3954 "src/hotspot/cpu/arm/arm.ad"

    // FIXME: why is ldmia considered atomic?  Should be ldrexd
    RegisterSet set(opnd_array(0)->as_Register(ra_,this)/* dst */);
    set = set | reg_to_register_object(opnd_array(0)->reg(ra_,this)/* dst */+ 1);
    __ ldmia(reg_to_register_object(opnd_array(1)->base(ra_,this,idx1)), set);
  
#line 7683 "ad_arm.cpp"
  }
}

uint loadL_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadL_volatile_fpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3971 "src/hotspot/cpu/arm/arm.ad"

    __ fldd(S14, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ fmrrd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), S14);
  
#line 7705 "ad_arm.cpp"
  }
}

uint loadL_volatile_fpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadL_unalignedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 3985 "src/hotspot/cpu/arm/arm.ad"

    Address Amemlo = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), relocInfo::none);
    Address Amemhi = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, relocInfo::none);

    if (opnd_array(0)->as_Register(ra_,this)/* dst */== reg_to_register_object(opnd_array(1)->base(ra_,this,idx1))) {
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), Amemhi);
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Amemlo);
    } else {
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Amemlo);
      __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), Amemhi);
    }
  
#line 7735 "ad_arm.cpp"
  }
}

uint loadL_unalignedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadRangeNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4007 "src/hotspot/cpu/arm/arm.ad"

    __ ldr_u32(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7756 "ad_arm.cpp"
  }
}

uint loadRangeNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4022 "src/hotspot/cpu/arm/arm.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7777 "ad_arm.cpp"
  }
}

uint loadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadKlassNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4087 "src/hotspot/cpu/arm/arm.ad"

    __ ldr(opnd_array(0)->as_Register(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7798 "ad_arm.cpp"
  }
}

uint loadKlassNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4117 "src/hotspot/cpu/arm/arm.ad"

    __ ldr_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7819 "ad_arm.cpp"
  }
}

uint loadDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadD_unalignedNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4130 "src/hotspot/cpu/arm/arm.ad"

    Address Amemlo = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), relocInfo::none);
    Address Amemhi = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, relocInfo::none);
      __ flds(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Amemlo);
      __ flds(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor(), Amemhi);
  
#line 7843 "ad_arm.cpp"
  }
}

uint loadD_unalignedNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4146 "src/hotspot/cpu/arm/arm.ad"

    __ ldr_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 7864 "ad_arm.cpp"
  }
}

uint loadFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4158 "src/hotspot/cpu/arm/arm.ad"

    __ mov_slow(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->constant());
  
#line 7885 "ad_arm.cpp"
  }
}

void loadConIMovNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4168 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->constant());
  
#line 7901 "ad_arm.cpp"
  }
}

uint loadConIMovNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConIMovnNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4178 "src/hotspot/cpu/arm/arm.ad"

    __ mvn(opnd_array(0)->as_Register(ra_,this)/* dst */, ~opnd_array(1)->constant());
  
#line 7922 "ad_arm.cpp"
  }
}

uint loadConIMovnNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConI16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4188 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->constant());
  
#line 7943 "ad_arm.cpp"
  }
}

uint loadConI16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4198 "src/hotspot/cpu/arm/arm.ad"

    relocInfo::relocType constant_reloc = _opnds[1]->constant_reloc();
    intptr_t val = opnd_array(1)->constant();
    if (constant_reloc == relocInfo::oop_type) {
      __ mov_oop(opnd_array(0)->as_Register(ra_,this)/* dst */, (jobject)val);
    } else if (constant_reloc == relocInfo::metadata_type) {
      __ mov_metadata(opnd_array(0)->as_Register(ra_,this)/* dst */, (Metadata*)val);
    } else {
      __ mov_slow(opnd_array(0)->as_Register(ra_,this)/* dst */, val);
    }
  
#line 7972 "ad_arm.cpp"
  }
}

void loadConLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4218 "src/hotspot/cpu/arm/arm.ad"

    __ mov_slow(reg_to_register_object(opnd_array(0)->reg(ra_,this)/* dst */), opnd_array(1)->constantL()& 0x0FFFFFFFFL);
    __ mov_slow(reg_to_register_object(opnd_array(0)->reg(ra_,this)/* dst */+ 1), ((julong)(opnd_array(1)->constantL())) >> 32);
  
#line 7989 "ad_arm.cpp"
  }
}

void loadConL16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4232 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->constantL());
    __ movw(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 8006 "ad_arm.cpp"
  }
}

uint loadConL16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadConF_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4246 "src/hotspot/cpu/arm/arm.ad"

    __ fconsts(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Assembler::float_num(opnd_array(1)->constantF()).imm8());
  
#line 8027 "ad_arm.cpp"
  }
}

uint loadConF_imm8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4262 "src/hotspot/cpu/arm/arm.ad"

    // FIXME revisit once 6961697 is in
    union {
      jfloat f;
      int i;
    } v;
    v.f = opnd_array(1)->constantF();
    __ mov_slow(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, v.i);
    __ fmsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 8056 "ad_arm.cpp"
  }
}

uint loadConFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 3*4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 3*4);
}

void loadConD_imm8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4282 "src/hotspot/cpu/arm/arm.ad"

    __ fconstd(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Assembler::double_num(opnd_array(1)->constantD()).imm8());
  
#line 8077 "ad_arm.cpp"
  }
}

uint loadConD_imm8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4294 "src/hotspot/cpu/arm/arm.ad"

    Register r = as_Register(ra_->get_encode(in(mach_constant_base_node_input())));
    int offset  = constant_offset();
    if (!is_memoryD(offset)) {                // can't use a predicate
                                              // in load constant instructs
      __ add_slow(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, r, offset);
      r = opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */;
      offset = 0;
    }
    __ ldr_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Address(r, offset));
  
#line 8107 "ad_arm.cpp"
  }
}

void loadConDNode::eval_constant(Compile* C) {
  {

#line 4296 "src/hotspot/cpu/arm/arm.ad"
    _constant = C->output()->constant_table().add(this, opnd_array(1));
#line 8116 "ad_arm.cpp"
  }
}
void prefetchAlloc_mpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4318 "src/hotspot/cpu/arm/arm.ad"

    __ pldw(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8131 "ad_arm.cpp"
  }
}

uint prefetchAlloc_mpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void prefetchAlloc_spNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4331 "src/hotspot/cpu/arm/arm.ad"

    __ pld(Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8152 "ad_arm.cpp"
  }
}

uint prefetchAlloc_spNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeBNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4346 "src/hotspot/cpu/arm/arm.ad"

    __ strb(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8174 "ad_arm.cpp"
  }
}

uint storeBNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeCMNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4358 "src/hotspot/cpu/arm/arm.ad"

    __ strb(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8196 "ad_arm.cpp"
  }
}

uint storeCMNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeCNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4373 "src/hotspot/cpu/arm/arm.ad"

    __ strh(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8218 "ad_arm.cpp"
  }
}

uint storeCNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4388 "src/hotspot/cpu/arm/arm.ad"

    __ str_32(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8240 "ad_arm.cpp"
  }
}

uint storeINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4405 "src/hotspot/cpu/arm/arm.ad"

    __ str_64(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8262 "ad_arm.cpp"
  }
}

uint storeLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeL_2instrNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4420 "src/hotspot/cpu/arm/arm.ad"

    Address Amemlo = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), relocInfo::none);
    Address Amemhi = Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1)+ 4, relocInfo::none);
    __ str(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Amemlo);
    __ str(opnd_array(2)->as_Register(ra_,this,idx2)/* src */->successor(), Amemhi);
  
#line 8287 "ad_arm.cpp"
  }
}

uint storeL_2instrNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void storeL_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4435 "src/hotspot/cpu/arm/arm.ad"

    // FIXME: why is stmia considered atomic?  Should be strexd
    RegisterSet set(opnd_array(2)->as_Register(ra_,this,idx2)/* src */);
    set = set | reg_to_register_object(opnd_array(2)->reg(ra_,this,idx2)/* src */+ 1);
    __ stmia(reg_to_register_object(opnd_array(1)->base(ra_,this,idx1)), set);
  
#line 8312 "ad_arm.cpp"
  }
}

uint storeL_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeL_volatile_fpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4451 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(S14, opnd_array(2)->as_Register(ra_,this,idx2)/* src */, opnd_array(2)->as_Register(ra_,this,idx2)/* src */->successor());
    __ fstd(S14, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8335 "ad_arm.cpp"
  }
}

uint storeL_volatile_fpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void storePNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4488 "src/hotspot/cpu/arm/arm.ad"

    __ str(opnd_array(2)->as_Register(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8357 "ad_arm.cpp"
  }
}

uint storePNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4537 "src/hotspot/cpu/arm/arm.ad"

    __ str_double(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8379 "ad_arm.cpp"
  }
}

uint storeDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4553 "src/hotspot/cpu/arm/arm.ad"

    __ str_float(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 8401 "ad_arm.cpp"
  }
}

uint storeFNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_storestoreNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4571 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::Membar_mask_bits(MacroAssembler::StoreStore), noreg);
  
#line 8422 "ad_arm.cpp"
  }
}

uint membar_storestoreNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_storestore_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4571 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::Membar_mask_bits(MacroAssembler::StoreStore), noreg);
  
#line 8443 "ad_arm.cpp"
  }
}

uint membar_storestore_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_acquireNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4584 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::Membar_mask_bits(MacroAssembler::LoadLoad | MacroAssembler::LoadStore), noreg);
  
#line 8464 "ad_arm.cpp"
  }
}

uint membar_acquireNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_acquire_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4584 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::Membar_mask_bits(MacroAssembler::LoadLoad | MacroAssembler::LoadStore), noreg);
  
#line 8485 "ad_arm.cpp"
  }
}

uint membar_acquire_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_acquire_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_acquire_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_releaseNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4607 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::Membar_mask_bits(MacroAssembler::StoreStore | MacroAssembler::LoadStore), noreg);
  
#line 8519 "ad_arm.cpp"
  }
}

uint membar_releaseNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_release_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4607 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::Membar_mask_bits(MacroAssembler::StoreStore | MacroAssembler::LoadStore), noreg);
  
#line 8540 "ad_arm.cpp"
  }
}

uint membar_release_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void membar_release_lockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint membar_release_lockNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4629 "src/hotspot/cpu/arm/arm.ad"

    __ membar(MacroAssembler::StoreLoad, noreg);
  
#line 8574 "ad_arm.cpp"
  }
}

uint membar_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void unnecessary_membar_volatileNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint unnecessary_membar_volatileNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castX2PNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4665 "src/hotspot/cpu/arm/arm.ad"

    if (opnd_array(0)->as_Register(ra_,this)/* dst */!=  opnd_array(1)->as_Register(ra_,this,idx1)/* src */) {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 8610 "ad_arm.cpp"
  }
}

void castP2XNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4678 "src/hotspot/cpu/arm/arm.ad"

    if (opnd_array(0)->as_Register(ra_,this)/* dst */!=  opnd_array(1)->as_Register(ra_,this,idx1)/* src */) {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    }
  
#line 8628 "ad_arm.cpp"
  }
}

void cmovIP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4693 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8647 "ad_arm.cpp"
  }
}

uint cmovIP_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIP_immMovNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4705 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8671 "ad_arm.cpp"
  }
}

uint cmovIP_immMovNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIP_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4716 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8695 "ad_arm.cpp"
  }
}

uint cmovIP_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4727 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8719 "ad_arm.cpp"
  }
}

uint cmovI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_immMovNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4739 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8743 "ad_arm.cpp"
  }
}

uint cmovI_immMovNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovII_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4750 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8767 "ad_arm.cpp"
  }
}

uint cmovII_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovII_reg_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4765 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8791 "ad_arm.cpp"
  }
}

uint cmovII_reg_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovII_immMov_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4780 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8815 "ad_arm.cpp"
  }
}

uint cmovII_immMov_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovII_imm16_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4795 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8839 "ad_arm.cpp"
  }
}

uint cmovII_imm16_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIIu_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4806 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8863 "ad_arm.cpp"
  }
}

uint cmovIIu_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIIu_immMovNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4817 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8887 "ad_arm.cpp"
  }
}

uint cmovIIu_immMovNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIIu_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4828 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8911 "ad_arm.cpp"
  }
}

uint cmovIIu_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4840 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8935 "ad_arm.cpp"
  }
}

uint cmovPP_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPP_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4851 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8959 "ad_arm.cpp"
  }
}

uint cmovPP_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4864 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 8983 "ad_arm.cpp"
  }
}

uint cmovPI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPI_reg_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4880 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9007 "ad_arm.cpp"
  }
}

uint cmovPI_reg_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPIu_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4892 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9031 "ad_arm.cpp"
  }
}

uint cmovPIu_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPI_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4904 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9055 "ad_arm.cpp"
  }
}

uint cmovPI_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPI_imm_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4920 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9079 "ad_arm.cpp"
  }
}

uint cmovPI_imm_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPIu_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4932 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9103 "ad_arm.cpp"
  }
}

uint cmovPIu_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4945 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9127 "ad_arm.cpp"
  }
}

uint cmovFP_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4957 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9151 "ad_arm.cpp"
  }
}

uint cmovFI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFI_reg_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4973 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9175 "ad_arm.cpp"
  }
}

uint cmovFI_reg_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFIu_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4985 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9199 "ad_arm.cpp"
  }
}

uint cmovFIu_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 4997 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9223 "ad_arm.cpp"
  }
}

uint cmovDP_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5009 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9247 "ad_arm.cpp"
  }
}

uint cmovDI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDI_reg_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5022 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9271 "ad_arm.cpp"
  }
}

uint cmovDI_reg_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDIu_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5034 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9295 "ad_arm.cpp"
  }
}

uint cmovDIu_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovLP_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5048 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9320 "ad_arm.cpp"
  }
}

uint cmovLP_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLP_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5064 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL(), (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9345 "ad_arm.cpp"
  }
}

uint cmovLP_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLP_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// pcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5078 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL(), (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9370 "ad_arm.cpp"
  }
}

uint cmovLP_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5092 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9395 "ad_arm.cpp"
  }
}

uint cmovLI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLI_reg_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5110 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9420 "ad_arm.cpp"
  }
}

uint cmovLI_reg_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLI_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5126 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL(), (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9445 "ad_arm.cpp"
  }
}

uint cmovLI_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLI_immRot_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5146 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL(), (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9470 "ad_arm.cpp"
  }
}

uint cmovLI_immRot_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLI_imm16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5160 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL(), (AsmCondition)(opnd_array(1)->ccode()));
    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9495 "ad_arm.cpp"
  }
}

uint cmovLI_imm16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLI_imm16_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5178 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constantL(), (AsmCondition)(opnd_array(1)->ccode()));
    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9520 "ad_arm.cpp"
  }
}

uint cmovLI_imm16_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLIu_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5192 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 9545 "ad_arm.cpp"
  }
}

uint cmovLIu_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void tlsLoadPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint tlsLoadPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void checkCastPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

uint checkCastPPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void castPPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castIINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castLLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castFFNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castDDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castVVDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void castVVXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// dst
  // User did not define which encode class to use.
}

void addI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5289 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 9649 "ad_arm.cpp"
  }
}

uint addI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5300 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 9672 "ad_arm.cpp"
  }
}

uint addshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshlI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5300 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 9695 "ad_arm.cpp"
  }
}

uint addshlI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshlI_reg_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5312 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->constant()));
  
#line 9718 "ad_arm.cpp"
  }
}

uint addshlI_reg_imm_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshlI_reg_imm_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5312 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsl, opnd_array(3)->constant()));
  
#line 9741 "ad_arm.cpp"
  }
}

uint addshlI_reg_imm_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5323 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 9764 "ad_arm.cpp"
  }
}

uint addsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addsarI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5323 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, asr, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 9787 "ad_arm.cpp"
  }
}

uint addsarI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addsarI_reg_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5334 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, asr, opnd_array(2)->constant()));
  
#line 9810 "ad_arm.cpp"
  }
}

uint addsarI_reg_imm_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addsarI_reg_imm_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5334 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, asr, opnd_array(3)->constant()));
  
#line 9833 "ad_arm.cpp"
  }
}

uint addsarI_reg_imm_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5345 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 9856 "ad_arm.cpp"
  }
}

uint addshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshrI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5345 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 9879 "ad_arm.cpp"
  }
}

uint addshrI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshrI_reg_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5356 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->constant()));
  
#line 9902 "ad_arm.cpp"
  }
}

uint addshrI_reg_imm_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshrI_reg_imm_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src3
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src1
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5356 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src3 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsr, opnd_array(3)->constant()));
  
#line 9925 "ad_arm.cpp"
  }
}

uint addshrI_reg_imm_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addI_reg_aimmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5368 "src/hotspot/cpu/arm/arm.ad"

    __ add_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 9947 "ad_arm.cpp"
  }
}

uint addI_reg_aimmINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addP_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5380 "src/hotspot/cpu/arm/arm.ad"

    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 9969 "ad_arm.cpp"
  }
}

uint addP_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addshlP_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5408 "src/hotspot/cpu/arm/arm.ad"

    Register base = reg_to_register_object(opnd_array(2)->base(ra_,this,idx2));
    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(base, lsl, opnd_array(2)->scale()));
  
#line 9992 "ad_arm.cpp"
  }
}

uint addshlP_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addP_reg_aimmXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5421 "src/hotspot/cpu/arm/arm.ad"

    __ add(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 10014 "ad_arm.cpp"
  }
}

uint addP_reg_aimmXNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5434 "src/hotspot/cpu/arm/arm.ad"

    __ adds(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ adc(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
  
#line 10037 "ad_arm.cpp"
  }
}

uint addL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void addL_reg_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5451 "src/hotspot/cpu/arm/arm.ad"

    __ adds(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
    __ adc(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), 0);
  
#line 10060 "ad_arm.cpp"
  }
}

uint addL_reg_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compareAndSwapL_boolNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5473 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrexd(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */);
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */->successor(), eq);
    __ strexd(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), eq);
    __ mov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 0, ne);
    __ eors(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 1, eq);
    __ b(loop, eq);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 10093 "ad_arm.cpp"
  }
}

uint compareAndSwapL_boolNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 32, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 32);
}

void compareAndSwapI_boolNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5502 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */);
    __ strex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), eq);
    __ mov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 0, ne);
    __ eors(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 1, eq);
    __ b(loop, eq);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 10125 "ad_arm.cpp"
  }
}

uint compareAndSwapI_boolNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 28, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 28);
}

void compareAndSwapP_boolNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// oldval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// newval
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5529 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* oldval */);
    __ strex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), eq);
    __ mov(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 0, ne);
    __ eors(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 1, eq);
    __ b(loop, eq);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* res */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */);
  
#line 10157 "ad_arm.cpp"
  }
}

uint compareAndSwapP_boolNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 28, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 28);
}

void xaddI_aimmI_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5555 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(2)->constant());
    __ strex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10187 "ad_arm.cpp"
  }
}

uint xaddI_aimmI_no_resNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void xaddI_reg_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5579 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ add(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* add */);
    __ strex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10217 "ad_arm.cpp"
  }
}

uint xaddI_reg_no_resNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void xaddI_aimmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5602 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(3)->as_Register(ra_,this,idx3)/* res */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ add(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* res */, opnd_array(2)->constant());
    __ strex(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10248 "ad_arm.cpp"
  }
}

uint xaddI_aimmINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void xaddI_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5625 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(3)->as_Register(ra_,this,idx3)/* res */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ add(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* res */, opnd_array(2)->as_Register(ra_,this,idx2)/* add */);
    __ strex(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10279 "ad_arm.cpp"
  }
}

uint xaddI_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void xaddL_reg_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5650 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrexd(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ adds(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* add */);
    __ adc(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */->successor(), opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* add */->successor());
    __ strexd(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10310 "ad_arm.cpp"
  }
}

uint xaddL_reg_no_resNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 24, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 24);
}

void xaddL_immRot_no_resNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5678 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrexd(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ adds(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, opnd_array(2)->constantL());
    __ adc(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */->successor(), opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */->successor(), 0);
    __ strexd(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10341 "ad_arm.cpp"
  }
}

uint xaddL_immRot_no_resNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 24, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 24);
}

void xaddL_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5703 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrexd(opnd_array(3)->as_Register(ra_,this,idx3)/* res */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ adds(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* res */, opnd_array(2)->as_Register(ra_,this,idx2)/* add */);
    __ adc(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */->successor(), opnd_array(3)->as_Register(ra_,this,idx3)/* res */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* add */->successor());
    __ strexd(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10373 "ad_arm.cpp"
  }
}

uint xaddL_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 24, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 24);
}

void xaddL_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// add
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp1
  unsigned idx5 = idx4 + opnd_array(4)->num_edges(); 	// tmp2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5730 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrexd(opnd_array(3)->as_Register(ra_,this,idx3)/* res */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ adds(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* res */, opnd_array(2)->constantL());
    __ adc(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */->successor(), opnd_array(3)->as_Register(ra_,this,idx3)/* res */->successor(), 0);
    __ strexd(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, opnd_array(4)->as_Register(ra_,this,idx4)/* tmp1 */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(5)->as_Register(ra_,this,idx5)/* tmp2 */, 0);
    __ b(loop, ne);
  
#line 10405 "ad_arm.cpp"
  }
}

uint xaddL_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 24, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 24);
}

void xchgINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5753 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(3)->as_Register(ra_,this,idx3)/* res */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ strex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 0);
    __ b(loop, ne);
  
#line 10434 "ad_arm.cpp"
  }
}

uint xchgINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void xchgLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5774 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrexd(opnd_array(3)->as_Register(ra_,this,idx3)/* res */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ strexd(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 0);
    __ b(loop, ne);
  
#line 10463 "ad_arm.cpp"
  }
}

uint xchgLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void xchgPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// newval
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// res
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5795 "src/hotspot/cpu/arm/arm.ad"

    Label loop;
    __ bind(loop);
    __ ldrex(opnd_array(3)->as_Register(ra_,this,idx3)/* res */,Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ strex(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* newval */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
    __ cmp(opnd_array(4)->as_Register(ra_,this,idx4)/* tmp */, 0);
    __ b(loop, ne);
  
#line 10492 "ad_arm.cpp"
  }
}

uint xchgPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void subI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5814 "src/hotspot/cpu/arm/arm.ad"

    __ sub_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 10514 "ad_arm.cpp"
  }
}

uint subI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5825 "src/hotspot/cpu/arm/arm.ad"

    __ sub(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 10537 "ad_arm.cpp"
  }
}

uint subshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subshlI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5836 "src/hotspot/cpu/arm/arm.ad"

    __ sub_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->constant()));
  
#line 10560 "ad_arm.cpp"
  }
}

uint subshlI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5847 "src/hotspot/cpu/arm/arm.ad"

    __ sub(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 10583 "ad_arm.cpp"
  }
}

uint subsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subsarI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5858 "src/hotspot/cpu/arm/arm.ad"

    __ sub_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->constant()));
  
#line 10606 "ad_arm.cpp"
  }
}

uint subsarI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5869 "src/hotspot/cpu/arm/arm.ad"

    __ sub(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 10629 "ad_arm.cpp"
  }
}

uint subshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subshrI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5880 "src/hotspot/cpu/arm/arm.ad"

    __ sub_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->constant()));
  
#line 10652 "ad_arm.cpp"
  }
}

uint subshrI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rsbshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5891 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 10675 "ad_arm.cpp"
  }
}

uint rsbshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rsbshlI_reg_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5902 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->constant()));
  
#line 10698 "ad_arm.cpp"
  }
}

uint rsbshlI_reg_imm_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rsbsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5913 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 10721 "ad_arm.cpp"
  }
}

uint rsbsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rsbsarI_reg_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5924 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, asr, opnd_array(2)->constant()));
  
#line 10744 "ad_arm.cpp"
  }
}

uint rsbsarI_reg_imm_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rsbshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5935 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 10767 "ad_arm.cpp"
  }
}

uint rsbshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void rsbshrI_reg_imm_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5946 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->constant()));
  
#line 10790 "ad_arm.cpp"
  }
}

uint rsbshrI_reg_imm_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_reg_aimmINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5958 "src/hotspot/cpu/arm/arm.ad"

    __ sub_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 10812 "ad_arm.cpp"
  }
}

uint subI_reg_aimmINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_reg_immRotnegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5969 "src/hotspot/cpu/arm/arm.ad"

    __ sub_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, -opnd_array(2)->constant());
  
#line 10834 "ad_arm.cpp"
  }
}

uint subI_reg_immRotnegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subI_immRot_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5980 "src/hotspot/cpu/arm/arm.ad"

    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, opnd_array(1)->constant());
  
#line 10856 "ad_arm.cpp"
  }
}

uint subI_immRot_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 5994 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ sbc(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
  
#line 10879 "ad_arm.cpp"
  }
}

uint subL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void subL_reg_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6013 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
    __ sbc(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), 0);
  
#line 10902 "ad_arm.cpp"
  }
}

uint subL_reg_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void negL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// zero
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6028 "src/hotspot/cpu/arm/arm.ad"

    __ rsbs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, 0);
    __ rsc(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor(), 0);
  
#line 10925 "ad_arm.cpp"
  }
}

uint negL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void mulI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6043 "src/hotspot/cpu/arm/arm.ad"

    __ mul_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 10947 "ad_arm.cpp"
  }
}

uint mulI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulL_lo1_hi2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6053 "src/hotspot/cpu/arm/arm.ad"

    __ mul(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
  
#line 10969 "ad_arm.cpp"
  }
}

uint mulL_lo1_hi2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulL_hi1_lo2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6064 "src/hotspot/cpu/arm/arm.ad"

    __ mla(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */->successor(), opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor());
    __ mov(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, 0);
  
#line 10993 "ad_arm.cpp"
  }
}

uint mulL_hi1_lo2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void mulL_lo1_lo2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6075 "src/hotspot/cpu/arm/arm.ad"

    __ umlal(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */);
  
#line 11016 "ad_arm.cpp"
  }
}

uint mulL_lo1_lo2Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6099 "src/hotspot/cpu/arm/arm.ad"

    __ call(StubRoutines::Arm::idiv_irem_entry(), relocInfo::runtime_call_type);
  
#line 11038 "ad_arm.cpp"
  }
}

void divL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6111 "src/hotspot/cpu/arm/arm.ad"

    address target = CAST_FROM_FN_PTR(address, SharedRuntime::ldiv);
    __ call(target, relocInfo::runtime_call_type);
  
#line 11056 "ad_arm.cpp"
  }
}

void modI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6125 "src/hotspot/cpu/arm/arm.ad"

    __ call(StubRoutines::Arm::idiv_irem_entry(), relocInfo::runtime_call_type);
  
#line 11073 "ad_arm.cpp"
  }
}

void modL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6137 "src/hotspot/cpu/arm/arm.ad"

    address target = CAST_FROM_FN_PTR(address, SharedRuntime::lrem);
    __ call(target, relocInfo::runtime_call_type);
  
#line 11091 "ad_arm.cpp"
  }
}

void shlI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6152 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 11108 "ad_arm.cpp"
  }
}

uint shlI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shlI_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6164 "src/hotspot/cpu/arm/arm.ad"

    __ logical_shift_left(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 11130 "ad_arm.cpp"
  }
}

uint shlI_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shlL_reg_reg_merge_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6174 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor(), AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */->successor(), lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 11153 "ad_arm.cpp"
  }
}

uint shlL_reg_reg_merge_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shlL_reg_reg_merge_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6184 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 11176 "ad_arm.cpp"
  }
}

uint shlL_reg_reg_merge_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shlL_reg_reg_overlapNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6198 "src/hotspot/cpu/arm/arm.ad"

    // $src1$$Register and $dst$$Register->successor() can't be the same
    __ subs(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, 32);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(0)->as_Register(ra_,this)/* dst */->successor()), pl);
    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0, mi);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(0)->as_Register(ra_,this)/* dst */->successor()), mi);
  
#line 11202 "ad_arm.cpp"
  }
}

uint shlL_reg_reg_overlapNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void shlL_reg_imm6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6226 "src/hotspot/cpu/arm/arm.ad"

    if (opnd_array(2)->constant()== 32) {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */);
    } else {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->constant()-32));
    }
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, 0);
  
#line 11229 "ad_arm.cpp"
  }
}

uint shlL_reg_imm6Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void shlL_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6244 "src/hotspot/cpu/arm/arm.ad"

    // The order of the following 3 instructions matters: src1.lo and
    // dst.hi can't overlap but src.hi and dst.hi can.
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsl, opnd_array(2)->constant()));
    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, 32-opnd_array(2)->constant()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsl, opnd_array(2)->constant()));
  
#line 11255 "ad_arm.cpp"
  }
}

uint shlL_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void sarI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6259 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 11277 "ad_arm.cpp"
  }
}

uint sarI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sarI_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6271 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, asr, opnd_array(2)->constant()));
  
#line 11299 "ad_arm.cpp"
  }
}

uint sarI_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sarL_reg_reg_merge_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6282 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 11322 "ad_arm.cpp"
  }
}

uint sarL_reg_reg_merge_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sarL_reg_reg_merge_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6292 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor(), AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */->successor(), asr, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 11345 "ad_arm.cpp"
  }
}

uint sarL_reg_reg_merge_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sarL_reg_reg_overlapNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6306 "src/hotspot/cpu/arm/arm.ad"

    // $src1$$Register->successor() and $dst$$Register can't be the same
    __ subs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, 32);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), asr, opnd_array(0)->as_Register(ra_,this)/* dst */), pl);
    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 0, mi);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsl, opnd_array(0)->as_Register(ra_,this)/* dst */), mi);
  
#line 11371 "ad_arm.cpp"
  }
}

uint sarL_reg_reg_overlapNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void sarL_reg_imm6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6334 "src/hotspot/cpu/arm/arm.ad"

    if (opnd_array(2)->constant()== 32) {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor());
    } else{
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), asr, opnd_array(2)->constant()-32));
    }
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), asr, 0));
  
#line 11398 "ad_arm.cpp"
  }
}

uint sarL_reg_imm6Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void sarL_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6352 "src/hotspot/cpu/arm/arm.ad"

    // The order of the following 3 instructions matters: src1.lo and
    // dst.hi can't overlap but src.hi and dst.hi can.
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->constant()));
    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsl, 32-opnd_array(2)->constant()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), asr, opnd_array(2)->constant()));
  
#line 11424 "ad_arm.cpp"
  }
}

uint sarL_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void shrI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6367 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */));
  
#line 11446 "ad_arm.cpp"
  }
}

uint shrI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shrI_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6379 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->constant()));
  
#line 11468 "ad_arm.cpp"
  }
}

uint shrI_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shrL_reg_reg_merge_loNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6390 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* dst */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 11491 "ad_arm.cpp"
  }
}

uint shrL_reg_reg_merge_loNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shrL_reg_reg_merge_hiNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6400 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(1)->as_Register(ra_,this,idx1)/* dst */->successor(), AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src1 */->successor(), lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src2 */));
  
#line 11514 "ad_arm.cpp"
  }
}

uint shrL_reg_reg_merge_hiNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shrL_reg_reg_overlapNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6414 "src/hotspot/cpu/arm/arm.ad"

    // $src1$$Register->successor() and $dst$$Register can't be the same
    __ subs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, 32);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsr, opnd_array(0)->as_Register(ra_,this)/* dst */), pl);
    __ rsb(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, 0, mi);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsl, opnd_array(0)->as_Register(ra_,this)/* dst */), mi);
  
#line 11540 "ad_arm.cpp"
  }
}

uint shrL_reg_reg_overlapNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void shrL_reg_imm6Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6442 "src/hotspot/cpu/arm/arm.ad"

    if (opnd_array(2)->constant()== 32) {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor());
    } else {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsr, opnd_array(2)->constant()-32));
    }
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 11567 "ad_arm.cpp"
  }
}

uint shrL_reg_imm6Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void shrL_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6461 "src/hotspot/cpu/arm/arm.ad"

    // The order of the following 3 instructions matters: src1.lo and
    // dst.hi can't overlap but src.hi and dst.hi can.
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, lsr, opnd_array(2)->constant()));
    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsl, 32-opnd_array(2)->constant()));
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), lsr, opnd_array(2)->constant()));
  
#line 11593 "ad_arm.cpp"
  }
}

uint shrL_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void shrP_reg_imm5Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6476 "src/hotspot/cpu/arm/arm.ad"

    __ logical_shift_right(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 11615 "ad_arm.cpp"
  }
}

uint shrP_reg_imm5Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6490 "src/hotspot/cpu/arm/arm.ad"

    __ add_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11637 "ad_arm.cpp"
  }
}

uint addF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6503 "src/hotspot/cpu/arm/arm.ad"

    __ add_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11659 "ad_arm.cpp"
  }
}

uint addD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6516 "src/hotspot/cpu/arm/arm.ad"

    __ sub_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11681 "ad_arm.cpp"
  }
}

uint subF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6528 "src/hotspot/cpu/arm/arm.ad"

    __ sub_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11703 "ad_arm.cpp"
  }
}

uint subD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6540 "src/hotspot/cpu/arm/arm.ad"

    __ mul_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11725 "ad_arm.cpp"
  }
}

uint mulF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6553 "src/hotspot/cpu/arm/arm.ad"

    __ mul_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11747 "ad_arm.cpp"
  }
}

uint mulD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6566 "src/hotspot/cpu/arm/arm.ad"

    __ div_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11769 "ad_arm.cpp"
  }
}

uint divF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void divD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6579 "src/hotspot/cpu/arm/arm.ad"

    __ div_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 11791 "ad_arm.cpp"
  }
}

uint divD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void absD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6592 "src/hotspot/cpu/arm/arm.ad"

    __ abs_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 11812 "ad_arm.cpp"
  }
}

uint absD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void absF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6602 "src/hotspot/cpu/arm/arm.ad"

    __ abs_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 11833 "ad_arm.cpp"
  }
}

void negF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6613 "src/hotspot/cpu/arm/arm.ad"

    __ neg_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 11849 "ad_arm.cpp"
  }
}

uint negF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void negD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6623 "src/hotspot/cpu/arm/arm.ad"

    __ neg_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 11870 "ad_arm.cpp"
  }
}

void sqrtF_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6635 "src/hotspot/cpu/arm/arm.ad"

    __ sqrt_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 11886 "ad_arm.cpp"
  }
}

uint sqrtF_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void sqrtD_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6647 "src/hotspot/cpu/arm/arm.ad"

    __ sqrt_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 11907 "ad_arm.cpp"
  }
}

uint sqrtD_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6661 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 11929 "ad_arm.cpp"
  }
}

uint andI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6672 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 11952 "ad_arm.cpp"
  }
}

uint andshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshlI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6672 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 11975 "ad_arm.cpp"
  }
}

uint andshlI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshlI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6683 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->constant()));
  
#line 11998 "ad_arm.cpp"
  }
}

uint andshlI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshlI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6683 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsl, opnd_array(2)->constant()));
  
#line 12021 "ad_arm.cpp"
  }
}

uint andshlI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6694 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12044 "ad_arm.cpp"
  }
}

uint andsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andsarI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6694 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12067 "ad_arm.cpp"
  }
}

uint andsarI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andsarI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6705 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->constant()));
  
#line 12090 "ad_arm.cpp"
  }
}

uint andsarI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andsarI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6705 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, asr, opnd_array(2)->constant()));
  
#line 12113 "ad_arm.cpp"
  }
}

uint andsarI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6716 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12136 "ad_arm.cpp"
  }
}

uint andshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshrI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6716 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12159 "ad_arm.cpp"
  }
}

uint andshrI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshrI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6727 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->constant()));
  
#line 12182 "ad_arm.cpp"
  }
}

uint andshrI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andshrI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6727 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsr, opnd_array(2)->constant()));
  
#line 12205 "ad_arm.cpp"
  }
}

uint andshrI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_limmNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6739 "src/hotspot/cpu/arm/arm.ad"

    __ and_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 12227 "ad_arm.cpp"
  }
}

uint andI_reg_limmNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andI_reg_limmnNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6750 "src/hotspot/cpu/arm/arm.ad"

    __ bic(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, ~opnd_array(2)->constant());
  
#line 12249 "ad_arm.cpp"
  }
}

uint andI_reg_limmnNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void andL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6763 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
  
#line 12272 "ad_arm.cpp"
  }
}

uint andL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void andL_reg_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6777 "src/hotspot/cpu/arm/arm.ad"

    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
    __ andr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), 0);
  
#line 12295 "ad_arm.cpp"
  }
}

uint andL_reg_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void orI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6791 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12317 "ad_arm.cpp"
  }
}

uint orI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6802 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12340 "ad_arm.cpp"
  }
}

uint orshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshlI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6802 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12363 "ad_arm.cpp"
  }
}

uint orshlI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshlI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6813 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->constant()));
  
#line 12386 "ad_arm.cpp"
  }
}

uint orshlI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshlI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6813 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsl, opnd_array(2)->constant()));
  
#line 12409 "ad_arm.cpp"
  }
}

uint orshlI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6824 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12432 "ad_arm.cpp"
  }
}

uint orsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orsarI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6824 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12455 "ad_arm.cpp"
  }
}

uint orsarI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orsarI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6835 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->constant()));
  
#line 12478 "ad_arm.cpp"
  }
}

uint orsarI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orsarI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6835 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, asr, opnd_array(2)->constant()));
  
#line 12501 "ad_arm.cpp"
  }
}

uint orsarI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6846 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12524 "ad_arm.cpp"
  }
}

uint orshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshrI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6846 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12547 "ad_arm.cpp"
  }
}

uint orshrI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshrI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6857 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->constant()));
  
#line 12570 "ad_arm.cpp"
  }
}

uint orshrI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orshrI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6857 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsr, opnd_array(2)->constant()));
  
#line 12593 "ad_arm.cpp"
  }
}

uint orshrI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orI_reg_limmNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6869 "src/hotspot/cpu/arm/arm.ad"

    __ orr_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 12615 "ad_arm.cpp"
  }
}

uint orI_reg_limmNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void orL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6884 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
  
#line 12638 "ad_arm.cpp"
  }
}

uint orL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void orL_reg_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6899 "src/hotspot/cpu/arm/arm.ad"

    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
    __ orr(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), 0);
  
#line 12661 "ad_arm.cpp"
  }
}

uint orL_reg_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void xorI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6928 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 12683 "ad_arm.cpp"
  }
}

uint xorI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6939 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12706 "ad_arm.cpp"
  }
}

uint xorshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshlI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6939 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12729 "ad_arm.cpp"
  }
}

uint xorshlI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshlI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6950 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsl, opnd_array(3)->constant()));
  
#line 12752 "ad_arm.cpp"
  }
}

uint xorshlI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshlI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6950 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsl, opnd_array(2)->constant()));
  
#line 12775 "ad_arm.cpp"
  }
}

uint xorshlI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6961 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12798 "ad_arm.cpp"
  }
}

uint xorsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorsarI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6961 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12821 "ad_arm.cpp"
  }
}

uint xorsarI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorsarI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6972 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, asr, opnd_array(3)->constant()));
  
#line 12844 "ad_arm.cpp"
  }
}

uint xorsarI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorsarI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6972 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, asr, opnd_array(2)->constant()));
  
#line 12867 "ad_arm.cpp"
  }
}

uint xorsarI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6983 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* src3 */));
  
#line 12890 "ad_arm.cpp"
  }
}

uint xorshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshrI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6983 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* src3 */));
  
#line 12913 "ad_arm.cpp"
  }
}

uint xorshrI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshrI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src3
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6994 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */, lsr, opnd_array(3)->constant()));
  
#line 12936 "ad_arm.cpp"
  }
}

uint xorshrI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorshrI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// src1
  {
    C2_MacroAssembler _masm(&cbuf);

#line 6994 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* src1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src2 */, lsr, opnd_array(2)->constant()));
  
#line 12959 "ad_arm.cpp"
  }
}

uint xorshrI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7006 "src/hotspot/cpu/arm/arm.ad"

    __ eor_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constant());
  
#line 12981 "ad_arm.cpp"
  }
}

uint xorI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void xorL_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7019 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
  
#line 13004 "ad_arm.cpp"
  }
}

uint xorL_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void xorL_reg_immRotNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7034 "src/hotspot/cpu/arm/arm.ad"

    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->constantL());
    __ eor(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), 0);
  
#line 13027 "ad_arm.cpp"
  }
}

uint xorL_reg_immRotNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmpLTMask_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7048 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->as_Register(ra_,this,idx2)/* q */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, 0);
    __ mvn(opnd_array(0)->as_Register(ra_,this)/* dst */, 0, lt);
  
#line 13051 "ad_arm.cpp"
  }
}

void cmpLTMask_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7063 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->constant());
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, 0);
    __ mvn(opnd_array(0)->as_Register(ra_,this)/* dst */, 0, lt);
  
#line 13070 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask3Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// z
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7077 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->as_Register(ra_,this,idx2)/* q */);
    __ add(opnd_array(4)->as_Register(ra_,this,idx4)/* z */, opnd_array(3)->as_Register(ra_,this,idx3)/* y */, opnd_array(4)->as_Register(ra_,this,idx4)/* z */, lt);
  
#line 13090 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask3_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// z
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// y
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7077 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(3)->as_Register(ra_,this,idx3)/* q */);
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* z */, opnd_array(4)->as_Register(ra_,this,idx4)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* z */, lt);
  
#line 13110 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask3_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// z
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7077 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(3)->as_Register(ra_,this,idx3)/* q */);
    __ add(opnd_array(4)->as_Register(ra_,this,idx4)/* z */, opnd_array(1)->as_Register(ra_,this,idx1)/* y */, opnd_array(4)->as_Register(ra_,this,idx4)/* z */, lt);
  
#line 13130 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask3_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// z
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// y
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// p
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7077 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(3)->as_Register(ra_,this,idx3)/* p */, opnd_array(4)->as_Register(ra_,this,idx4)/* q */);
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* z */, opnd_array(2)->as_Register(ra_,this,idx2)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* z */, lt);
  
#line 13150 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask4Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// z
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7091 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->constant());
    __ add(opnd_array(4)->as_Register(ra_,this,idx4)/* z */, opnd_array(3)->as_Register(ra_,this,idx3)/* y */, opnd_array(4)->as_Register(ra_,this,idx4)/* z */, lt);
  
#line 13170 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask4_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// z
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// y
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7091 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(3)->constant());
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* z */, opnd_array(4)->as_Register(ra_,this,idx4)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* z */, lt);
  
#line 13190 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask4_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// z
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7091 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(3)->constant());
    __ add(opnd_array(4)->as_Register(ra_,this,idx4)/* z */, opnd_array(1)->as_Register(ra_,this,idx1)/* y */, opnd_array(4)->as_Register(ra_,this,idx4)/* z */, lt);
  
#line 13210 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask4_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// z
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// y
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// p
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7091 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(3)->as_Register(ra_,this,idx3)/* p */, opnd_array(4)->constant());
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* z */, opnd_array(2)->as_Register(ra_,this,idx2)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* z */, lt);
  
#line 13230 "ad_arm.cpp"
  }
}

void cadd_cmpLTMaskNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7104 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->as_Register(ra_,this,idx2)/* q */);
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(3)->as_Register(ra_,this,idx3)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* p */, lt);
  
#line 13249 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask_1Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7104 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->as_Register(ra_,this,idx2)/* q */);
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(3)->as_Register(ra_,this,idx3)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* p */, lt);
  
#line 13268 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// y
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// p
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// q
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7104 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(3)->as_Register(ra_,this,idx3)/* q */);
    __ add(opnd_array(2)->as_Register(ra_,this,idx2)/* p */, opnd_array(1)->as_Register(ra_,this,idx1)/* y */, opnd_array(2)->as_Register(ra_,this,idx2)/* p */, lt);
  
#line 13287 "ad_arm.cpp"
  }
}

void cadd_cmpLTMask_2Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// p
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// q
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// y
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7104 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(2)->as_Register(ra_,this,idx2)/* q */);
    __ add(opnd_array(1)->as_Register(ra_,this,idx1)/* p */, opnd_array(3)->as_Register(ra_,this,idx3)/* y */, opnd_array(1)->as_Register(ra_,this,idx1)/* p */, lt);
  
#line 13306 "ad_arm.cpp"
  }
}

void convD2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7118 "src/hotspot/cpu/arm/arm.ad"

    __ convert_d2f(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13322 "ad_arm.cpp"
  }
}

uint convD2F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convD2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7133 "src/hotspot/cpu/arm/arm.ad"

    __ ftosizd(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ fmrs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
  
#line 13345 "ad_arm.cpp"
  }
}

void convD2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7149 "src/hotspot/cpu/arm/arm.ad"

#ifndef __ABI_HARD__
    __ fmrrd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
#else
    if (opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */!= D0) {
      __ mov_double(D0, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
#endif
    address target = CAST_FROM_FN_PTR(address, SharedRuntime::d2l);
    __ call(target, relocInfo::runtime_call_type);
  
#line 13369 "ad_arm.cpp"
  }
}

void convF2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7167 "src/hotspot/cpu/arm/arm.ad"

    __ convert_f2d(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13385 "ad_arm.cpp"
  }
}

uint convF2D_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7180 "src/hotspot/cpu/arm/arm.ad"

    __ ftosizs(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ fmrs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
  
#line 13408 "ad_arm.cpp"
  }
}

uint convF2I_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void convF2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7193 "src/hotspot/cpu/arm/arm.ad"

#ifndef __ABI_HARD__
    __ fmrs(as_Register(R_R0_enc), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
#else
    if(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */!= S0) {
      __ mov_float(S0, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    }
#endif
    address target = CAST_FROM_FN_PTR(address, SharedRuntime::f2l);
    __ call(target, relocInfo::runtime_call_type);
  
#line 13437 "ad_arm.cpp"
  }
}

void convI2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7213 "src/hotspot/cpu/arm/arm.ad"

      __ fmsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
      __ fsitod(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
  
#line 13454 "ad_arm.cpp"
  }
}

uint convI2D_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void convI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7226 "src/hotspot/cpu/arm/arm.ad"

      __ fmsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
      __ fsitos(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */);
  
#line 13476 "ad_arm.cpp"
  }
}

uint convI2F_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void convI2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7238 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, asr, 31));
  
#line 13498 "ad_arm.cpp"
  }
}

uint convI2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void convI2L_reg_zexNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7251 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 13521 "ad_arm.cpp"
  }
}

uint convI2L_reg_zexNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void zerox_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// mask
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7264 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), 0);
  
#line 13544 "ad_arm.cpp"
  }
}

uint zerox_longNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void MoveF2I_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7278 "src/hotspot/cpu/arm/arm.ad"

    __ fmrs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13565 "ad_arm.cpp"
  }
}

uint MoveF2I_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void MoveI2F_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7290 "src/hotspot/cpu/arm/arm.ad"

    __ fmsr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 13586 "ad_arm.cpp"
  }
}

uint MoveI2F_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void MoveD2L_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7303 "src/hotspot/cpu/arm/arm.ad"

    __ fmrrd(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(0)->as_Register(ra_,this)/* dst */->successor(), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
  
#line 13607 "ad_arm.cpp"
  }
}

uint MoveD2L_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void MoveL2D_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7316 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
  
#line 13628 "ad_arm.cpp"
  }
}

uint MoveL2D_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadConI_x43300000Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7330 "src/hotspot/cpu/arm/arm.ad"

    __ mov_slow(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x43300000);
  
#line 13649 "ad_arm.cpp"
  }
}

uint loadConI_x43300000Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadConI_x41f00000Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7341 "src/hotspot/cpu/arm/arm.ad"

    __ mov_slow(opnd_array(0)->as_Register(ra_,this)/* dst */, 0x41f00000);
  
#line 13670 "ad_arm.cpp"
  }
}

uint loadConI_x41f00000Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void loadConI_x0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7351 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, 0);
  
#line 13691 "ad_arm.cpp"
  }
}

uint loadConI_x0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void regDHi_regDLo_to_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7363 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor(), opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */->successor());
    __ fcpys(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 13714 "ad_arm.cpp"
  }
}

uint regDHi_regDLo_to_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void convI2D_regDHi_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7376 "src/hotspot/cpu/arm/arm.ad"

    __ fsitod(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */->successor());
  
#line 13735 "ad_arm.cpp"
  }
}

uint convI2D_regDHi_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void addD_regD_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7387 "src/hotspot/cpu/arm/arm.ad"

    __ add_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 13757 "ad_arm.cpp"
  }
}

uint addD_regD_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void subD_regD_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7398 "src/hotspot/cpu/arm/arm.ad"

    __ sub_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 13779 "ad_arm.cpp"
  }
}

uint subD_regD_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void mulD_regD_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7409 "src/hotspot/cpu/arm/arm.ad"

    __ mul_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
  
#line 13801 "ad_arm.cpp"
  }
}

uint mulD_regD_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void regL_to_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7421 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
  
#line 13822 "ad_arm.cpp"
  }
}

uint regL_to_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void regI_regI_to_regDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7433 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
  
#line 13844 "ad_arm.cpp"
  }
}

uint regI_regI_to_regDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void convL2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7476 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 13865 "ad_arm.cpp"
  }
}

uint convL2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void shrL_reg_imm6_L2INode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7487 "src/hotspot/cpu/arm/arm.ad"

    if (opnd_array(2)->constant()== 32) {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
    } else {
      __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor(), asr, opnd_array(2)->constant()- 32));
    }
  
#line 13891 "ad_arm.cpp"
  }
}

uint shrL_reg_imm6_L2INode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compI_iRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7507 "src/hotspot/cpu/arm/arm.ad"

    __ cmp_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 13913 "ad_arm.cpp"
  }
}

uint compI_iRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compU_iRegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7533 "src/hotspot/cpu/arm/arm.ad"

    __ cmp_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 13935 "ad_arm.cpp"
  }
}

uint compU_iRegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compI_iReg_immnegNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7545 "src/hotspot/cpu/arm/arm.ad"

    __ cmn_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, -opnd_array(2)->constant());
  
#line 13957 "ad_arm.cpp"
  }
}

uint compI_iReg_immnegNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compI_iReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7557 "src/hotspot/cpu/arm/arm.ad"

    __ cmp_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 13979 "ad_arm.cpp"
  }
}

uint compI_iReg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testI_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7568 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 14002 "ad_arm.cpp"
  }
}

uint testI_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshlI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7579 "src/hotspot/cpu/arm/arm.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, lsl, opnd_array(3)->as_Register(ra_,this,idx3)/* op3 */));
  
#line 14026 "ad_arm.cpp"
  }
}

uint testshlI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshlI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7579 "src/hotspot/cpu/arm/arm.ad"

    __ tst(opnd_array(3)->as_Register(ra_,this,idx3)/* op1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, lsl, opnd_array(2)->as_Register(ra_,this,idx2)/* op3 */));
  
#line 14050 "ad_arm.cpp"
  }
}

uint testshlI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshlI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7590 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, lsl, opnd_array(3)->constant()));
  
#line 14074 "ad_arm.cpp"
  }
}

uint testshlI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshlI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7590 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(3)->as_Register(ra_,this,idx3)/* op1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, lsl, opnd_array(2)->constant()));
  
#line 14098 "ad_arm.cpp"
  }
}

uint testshlI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testsarI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7601 "src/hotspot/cpu/arm/arm.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, asr, opnd_array(3)->as_Register(ra_,this,idx3)/* op3 */));
  
#line 14122 "ad_arm.cpp"
  }
}

uint testsarI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testsarI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7601 "src/hotspot/cpu/arm/arm.ad"

    __ tst(opnd_array(3)->as_Register(ra_,this,idx3)/* op1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, asr, opnd_array(2)->as_Register(ra_,this,idx2)/* op3 */));
  
#line 14146 "ad_arm.cpp"
  }
}

uint testsarI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testsarI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7612 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, asr, opnd_array(3)->constant()));
  
#line 14170 "ad_arm.cpp"
  }
}

uint testsarI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testsarI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7612 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(3)->as_Register(ra_,this,idx3)/* op1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, asr, opnd_array(2)->constant()));
  
#line 14194 "ad_arm.cpp"
  }
}

uint testsarI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshrI_reg_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7623 "src/hotspot/cpu/arm/arm.ad"

    __ tst(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, lsr, opnd_array(3)->as_Register(ra_,this,idx3)/* op3 */));
  
#line 14218 "ad_arm.cpp"
  }
}

uint testshrI_reg_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshrI_reg_reg_reg_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7623 "src/hotspot/cpu/arm/arm.ad"

    __ tst(opnd_array(3)->as_Register(ra_,this,idx3)/* op1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, lsr, opnd_array(2)->as_Register(ra_,this,idx2)/* op3 */));
  
#line 14242 "ad_arm.cpp"
  }
}

uint testshrI_reg_reg_reg_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshrI_reg_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op3
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7634 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, lsr, opnd_array(3)->constant()));
  
#line 14266 "ad_arm.cpp"
  }
}

uint testshrI_reg_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testshrI_reg_reg_imm_0Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op2
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op3
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// op1
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7634 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(3)->as_Register(ra_,this,idx3)/* op1 */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, lsr, opnd_array(2)->constant()));
  
#line 14290 "ad_arm.cpp"
  }
}

uint testshrI_reg_reg_imm_0Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void testI_reg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7645 "src/hotspot/cpu/arm/arm.ad"

    __ tst_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 14313 "ad_arm.cpp"
  }
}

uint testI_reg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compL_reg_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7658 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ sbcs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */->successor());
  
#line 14337 "ad_arm.cpp"
  }
}

uint compL_reg_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compUL_reg_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7672 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
    __ sbcs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */->successor());
  
#line 14361 "ad_arm.cpp"
  }
}

uint compUL_reg_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compL_reg_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7686 "src/hotspot/cpu/arm/arm.ad"

    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */->successor());
    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, eq);
  
#line 14384 "ad_arm.cpp"
  }
}

uint compL_reg_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compL_reg_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7700 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */);
    __ sbcs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor());
  
#line 14408 "ad_arm.cpp"
  }
}

uint compL_reg_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compL_reg_con_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7716 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
    __ sbcs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), 0);
  
#line 14432 "ad_arm.cpp"
  }
}

uint compL_reg_con_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compL_reg_con_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7733 "src/hotspot/cpu/arm/arm.ad"

    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), 0);
    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL(), eq);
  
#line 14455 "ad_arm.cpp"
  }
}

uint compL_reg_con_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compL_reg_con_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7750 "src/hotspot/cpu/arm/arm.ad"

    __ rsbs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
    __ rscs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), 0);
  
#line 14479 "ad_arm.cpp"
  }
}

uint compL_reg_con_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compUL_reg_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7765 "src/hotspot/cpu/arm/arm.ad"

    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */->successor());
    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, eq);
  
#line 14502 "ad_arm.cpp"
  }
}

uint compUL_reg_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compUL_reg_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7779 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */);
    __ sbcs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor());
  
#line 14526 "ad_arm.cpp"
  }
}

uint compUL_reg_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compUL_reg_con_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7795 "src/hotspot/cpu/arm/arm.ad"

    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
    __ sbcs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), 0);
  
#line 14550 "ad_arm.cpp"
  }
}

uint compUL_reg_con_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compUL_reg_con_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7812 "src/hotspot/cpu/arm/arm.ad"

    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), 0);
    __ teq(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL(), eq);
  
#line 14573 "ad_arm.cpp"
  }
}

uint compUL_reg_con_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compUL_reg_con_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// con
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7829 "src/hotspot/cpu/arm/arm.ad"

    __ rsbs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constantL());
    __ rscs(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */->successor(), 0);
  
#line 14597 "ad_arm.cpp"
  }
}

uint compUL_reg_con_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void compU_iReg_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7859 "src/hotspot/cpu/arm/arm.ad"

    __ cmp_32(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 14619 "ad_arm.cpp"
  }
}

uint compU_iReg_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compP_iRegPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7871 "src/hotspot/cpu/arm/arm.ad"

    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op2 */);
  
#line 14641 "ad_arm.cpp"
  }
}

uint compP_iRegPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void compP_iRegP_immNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// op2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7882 "src/hotspot/cpu/arm/arm.ad"

    assert(opnd_array(2)->constant()== 0 || _opnds[2]->constant_reloc() == relocInfo::none, "reloc in cmp?");
    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* op1 */, opnd_array(2)->constant());
  
#line 14664 "ad_arm.cpp"
  }
}

uint compP_iRegP_immNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_reg_ltNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7897 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, lt);
  
#line 14687 "ad_arm.cpp"
  }
}

uint cmovI_reg_ltNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovI_reg_gtNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// op1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// icc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7919 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(1)->as_Register(ra_,this,idx1)/* op2 */, opnd_array(2)->as_Register(ra_,this,idx2)/* op1 */, gt);
  
#line 14710 "ad_arm.cpp"
  }
}

void cmpF_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7946 "src/hotspot/cpu/arm/arm.ad"

    __ fcmps(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ fmstat();
  
#line 14728 "ad_arm.cpp"
  }
}

uint cmpF_ccNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmpF0_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7960 "src/hotspot/cpu/arm/arm.ad"

    __ fcmpzs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
    __ fmstat();
  
#line 14751 "ad_arm.cpp"
  }
}

uint cmpF0_ccNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmpD_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7974 "src/hotspot/cpu/arm/arm.ad"

    __ fcmpd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ fmstat();
  
#line 14774 "ad_arm.cpp"
  }
}

uint cmpD_ccNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmpD0_ccNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 7988 "src/hotspot/cpu/arm/arm.ad"

    __ fcmpzd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
    __ fmstat();
  
#line 14797 "ad_arm.cpp"
  }
}

uint cmpD0_ccNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmpF_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8008 "src/hotspot/cpu/arm/arm.ad"

    __ fcmps(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ floating_cmp(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 14820 "ad_arm.cpp"
  }
}

uint cmpF_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void cmpF0_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8027 "src/hotspot/cpu/arm/arm.ad"

    __ fcmpzs(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
    __ floating_cmp(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 14843 "ad_arm.cpp"
  }
}

uint cmpF0_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void cmpD_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8046 "src/hotspot/cpu/arm/arm.ad"

    __ fcmpd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ floating_cmp(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 14866 "ad_arm.cpp"
  }
}

uint cmpD_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void cmpD0_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8065 "src/hotspot/cpu/arm/arm.ad"

    __ fcmpzd(opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */);
    __ floating_cmp(opnd_array(0)->as_Register(ra_,this)/* dst */);
  
#line 14889 "ad_arm.cpp"
  }
}

uint cmpD0_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void jumpXtndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  ra_->C->output()->constant_table().fill_jump_table(cbuf, (MachConstantNode*) this, _index2label);
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// tmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8084 "src/hotspot/cpu/arm/arm.ad"

    Register table_reg;
    Register label_reg = opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */;
    if (constant_offset() == 0) {
      table_reg = as_Register(ra_->get_encode(in(mach_constant_base_node_input())));
      __ ldr(label_reg, Address(table_reg, opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */));
    } else {
      table_reg = opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */;
      int offset = constant_offset();
      if (is_memoryP(offset)) {
        __ add(table_reg, as_Register(ra_->get_encode(in(mach_constant_base_node_input()))), opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */);
        __ ldr(label_reg, Address(table_reg, offset));
      } else {
        __ mov_slow(table_reg, constant_offset());
        __ add(table_reg, as_Register(ra_->get_encode(in(mach_constant_base_node_input()))), table_reg);
        __ ldr(label_reg, Address(table_reg, opnd_array(1)->as_Register(ra_,this,idx1)/* switch_val */));
      }
    }
    __ jump(label_reg); // ldr + b better than ldr to PC for branch predictor?
    //    __ ldr(PC, Address($table$$Register, $switch_val$$Register));
  
#line 14930 "ad_arm.cpp"
  }
}

void jumpXtndNode::eval_constant(Compile* C) {
  _constant = C->output()->constant_table().add_jump_table(this);
  // User did not define an encode section.
}
uint jumpXtndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void branchNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8116 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(1)->label()));
  
#line 14955 "ad_arm.cpp"
  }
}

uint branchNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// icc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8130 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 14978 "ad_arm.cpp"
  }
}

uint branchConNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchCon_EQNELTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// icc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8145 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15001 "ad_arm.cpp"
  }
}

uint branchCon_EQNELTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConUNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// icc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8160 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15024 "ad_arm.cpp"
  }
}

uint branchConUNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConPNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// pcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8173 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15047 "ad_arm.cpp"
  }
}

uint branchConPNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConL_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// xcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8187 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15070 "ad_arm.cpp"
  }
}

uint branchConL_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConL_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// xcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8201 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15093 "ad_arm.cpp"
  }
}

uint branchConL_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConL_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// xcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8215 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15116 "ad_arm.cpp"
  }
}

uint branchConL_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConUL_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// xcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8229 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15139 "ad_arm.cpp"
  }
}

uint branchConUL_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConUL_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// xcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8243 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15162 "ad_arm.cpp"
  }
}

uint branchConUL_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchConUL_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// xcc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8257 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15185 "ad_arm.cpp"
  }
}

uint branchConUL_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void branchLoopEndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// icc
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// labl
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8270 "src/hotspot/cpu/arm/arm.ad"

    __ b(*(opnd_array(3)->label()), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15208 "ad_arm.cpp"
  }
}

uint branchLoopEndNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmpL3_reg_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8323 "src/hotspot/cpu/arm/arm.ad"

    Label done;
    __ cmp(opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */->successor(), opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */->successor());
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, 1, gt);
    __ mvn(opnd_array(0)->as_Register(ra_,this)/* dst */, 0, lt);
    __ b(done, ne);
    __ subs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src1 */, opnd_array(2)->as_Register(ra_,this,idx2)/* src2 */);
    __ mov(opnd_array(0)->as_Register(ra_,this)/* dst */, 1, hi);
    __ mvn(opnd_array(0)->as_Register(ra_,this)/* dst */, 0, lo);
    __ bind(done);
  
#line 15238 "ad_arm.cpp"
  }
}

uint cmpL3_reg_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 32, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 32);
}

void cmovLL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8346 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15263 "ad_arm.cpp"
  }
}

uint cmovLL_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_reg_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8361 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15288 "ad_arm.cpp"
  }
}

uint cmovLL_reg_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8376 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15313 "ad_arm.cpp"
  }
}

uint cmovLL_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8391 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15338 "ad_arm.cpp"
  }
}

uint cmovLL_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_reg_LEGT_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8406 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), opnd_array(4)->as_Register(ra_,this,idx4)/* src */->successor(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15363 "ad_arm.cpp"
  }
}

uint cmovLL_reg_LEGT_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_imm_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8420 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, 0, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15388 "ad_arm.cpp"
  }
}

uint cmovLL_imm_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_imm_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8434 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, 0, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15413 "ad_arm.cpp"
  }
}

uint cmovLL_imm_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_imm_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8448 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, 0, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15438 "ad_arm.cpp"
  }
}

uint cmovLL_imm_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovLL_imm_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8462 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, 0, (AsmCondition)(opnd_array(1)->ccode()));
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */->successor(), 0, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15463 "ad_arm.cpp"
  }
}

uint cmovLL_imm_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void cmovIL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8476 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15487 "ad_arm.cpp"
  }
}

uint cmovIL_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_reg_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8489 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15511 "ad_arm.cpp"
  }
}

uint cmovIL_reg_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8502 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15535 "ad_arm.cpp"
  }
}

uint cmovIL_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_reg_EQNE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8515 "src/hotspot/cpu/arm/arm.ad"

   __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15559 "ad_arm.cpp"
  }
}

uint cmovIL_reg_EQNE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8528 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15583 "ad_arm.cpp"
  }
}

uint cmovIL_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_reg_LEGT_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8541 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15607 "ad_arm.cpp"
  }
}

uint cmovIL_reg_LEGT_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_imm16_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8554 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15631 "ad_arm.cpp"
  }
}

uint cmovIL_imm16_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_imm16_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8567 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15655 "ad_arm.cpp"
  }
}

uint cmovIL_imm16_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_imm16_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8580 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15679 "ad_arm.cpp"
  }
}

uint cmovIL_imm16_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_imm16_EQNE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8593 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15703 "ad_arm.cpp"
  }
}

uint cmovIL_imm16_EQNE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_imm16_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8606 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15727 "ad_arm.cpp"
  }
}

uint cmovIL_imm16_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_imm16_LEGT_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8619 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15751 "ad_arm.cpp"
  }
}

uint cmovIL_imm16_LEGT_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_immMov_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8632 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15775 "ad_arm.cpp"
  }
}

uint cmovIL_immMov_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_immMov_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8645 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15799 "ad_arm.cpp"
  }
}

uint cmovIL_immMov_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_immMov_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8658 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15823 "ad_arm.cpp"
  }
}

uint cmovIL_immMov_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_immMov_EQNE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8671 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15847 "ad_arm.cpp"
  }
}

uint cmovIL_immMov_EQNE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_immMov_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8684 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15871 "ad_arm.cpp"
  }
}

uint cmovIL_immMov_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovIL_immMov_LEGT_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8697 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15895 "ad_arm.cpp"
  }
}

uint cmovIL_immMov_LEGT_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8710 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15919 "ad_arm.cpp"
  }
}

uint cmovPL_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_reg_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8723 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15943 "ad_arm.cpp"
  }
}

uint cmovPL_reg_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8736 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15967 "ad_arm.cpp"
  }
}

uint cmovPL_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_reg_EQNE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8749 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 15991 "ad_arm.cpp"
  }
}

uint cmovPL_reg_EQNE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8762 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16015 "ad_arm.cpp"
  }
}

uint cmovPL_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_reg_LEGT_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8775 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->as_Register(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16039 "ad_arm.cpp"
  }
}

uint cmovPL_reg_LEGT_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_imm_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8788 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16063 "ad_arm.cpp"
  }
}

uint cmovPL_imm_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_imm_LTGE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8801 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16087 "ad_arm.cpp"
  }
}

uint cmovPL_imm_LTGE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_imm_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8814 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16111 "ad_arm.cpp"
  }
}

uint cmovPL_imm_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_imm_EQNE_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8827 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16135 "ad_arm.cpp"
  }
}

uint cmovPL_imm_EQNE_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_imm_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8840 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16159 "ad_arm.cpp"
  }
}

uint cmovPL_imm_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovPL_imm_LEGT_UNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8853 "src/hotspot/cpu/arm/arm.ad"

    __ movw(opnd_array(3)->as_Register(ra_,this,idx3)/* dst */, opnd_array(4)->constant(), (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16183 "ad_arm.cpp"
  }
}

uint cmovPL_imm_LEGT_UNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8865 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16207 "ad_arm.cpp"
  }
}

uint cmovFL_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8877 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16231 "ad_arm.cpp"
  }
}

uint cmovFL_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovFL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8889 "src/hotspot/cpu/arm/arm.ad"

    __ fcpys(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16255 "ad_arm.cpp"
  }
}

uint cmovFL_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDL_reg_LTGENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8902 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16279 "ad_arm.cpp"
  }
}

uint cmovDL_reg_LTGENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDL_reg_EQNENode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8915 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16303 "ad_arm.cpp"
  }
}

uint cmovDL_reg_EQNENode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void cmovDL_reg_LEGTNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cmp
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// xcc
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// dst
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8928 "src/hotspot/cpu/arm/arm.ad"

    __ fcpyd(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* dst */, opnd_array(4)->as_FloatRegister(ra_,this,idx4)/* src */, (AsmCondition)(opnd_array(1)->ccode()));
  
#line 16327 "ad_arm.cpp"
  }
}

uint cmovDL_reg_LEGTNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void safePoint_pollNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 8944 "src/hotspot/cpu/arm/arm.ad"

    __ relocate(relocInfo::poll_type);
    __ ldr(as_Register(R_R12_enc), Address(opnd_array(1)->as_Register(ra_,this,idx1)/* poll */));
  
#line 16349 "ad_arm.cpp"
  }
}

uint safePoint_pollNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void CallStaticJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1231 "src/hotspot/cpu/arm/arm.ad"

    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.

    if ( !_method) {
      emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), runtime_call_Relocation::spec());
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), rspec);

      // Emit stubs for static call.
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    }
  
#line 16386 "ad_arm.cpp"
  }
  {

#line 1222 "src/hotspot/cpu/arm/arm.ad"

    // nothing
  
#line 16394 "ad_arm.cpp"
  }
}

void CallStaticJavaHandleNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1266 "src/hotspot/cpu/arm/arm.ad"

    // preserve mark
    address mark = cbuf.insts()->mark();
    debug_only(int off0 = cbuf.insts_size());
    C2_MacroAssembler _masm(&cbuf);
    // FP is preserved across all calls, even compiled calls.
    // Use it to preserve SP in places where the callee might change the SP.
    __ mov(Rmh_SP_save, SP);
    debug_only(int off1 = cbuf.insts_size());
    assert(off1 - off0 == 4, "correct size prediction");
    // restore mark
    cbuf.insts()->set_mark(mark);
  
#line 16419 "ad_arm.cpp"
  }
  {

#line 1231 "src/hotspot/cpu/arm/arm.ad"

    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.

    if ( !_method) {
      emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), runtime_call_Relocation::spec());
    } else {
      int method_index = resolved_method_index(cbuf);
      RelocationHolder rspec = _optimized_virtual ? opt_virtual_call_Relocation::spec(method_index)
                                                  : static_call_Relocation::spec(method_index);
      emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), rspec);

      // Emit stubs for static call.
      address stub = CompiledStaticCall::emit_to_interp_stub(cbuf);
      if (stub == NULL) {
        ciEnv::current()->record_failure("CodeCache is full");
        return;
      }
    }
  
#line 16444 "ad_arm.cpp"
  }
  {

#line 1280 "src/hotspot/cpu/arm/arm.ad"

    C2_MacroAssembler _masm(&cbuf);
    __ mov(SP, Rmh_SP_save);
  
#line 16453 "ad_arm.cpp"
  }
  {

#line 1222 "src/hotspot/cpu/arm/arm.ad"

    // nothing
  
#line 16461 "ad_arm.cpp"
  }
}

void CallDynamicJavaDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1285 "src/hotspot/cpu/arm/arm.ad"

    C2_MacroAssembler _masm(&cbuf);
    Register R8_ic_reg = reg_to_register_object(Matcher::inline_cache_reg_encode());
    assert(R8_ic_reg == Ricklass, "should be");
    __ set_inst_mark();
    __ movw(R8_ic_reg, ((unsigned int)Universe::non_oop_word()) & 0xffff);
    __ movt(R8_ic_reg, ((unsigned int)Universe::non_oop_word()) >> 16);
    address  virtual_call_oop_addr = __ inst_mark();
    // CALL to fixup routine.  Fixup routine uses ScopeDesc info to determine
    // who we intended to call.
    int method_index = resolved_method_index(cbuf);
    __ relocate(virtual_call_Relocation::spec(virtual_call_oop_addr, method_index));
    emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), RelocationHolder::none);
  
#line 16487 "ad_arm.cpp"
  }
  {

#line 1222 "src/hotspot/cpu/arm/arm.ad"

    // nothing
  
#line 16495 "ad_arm.cpp"
  }
}

void CallRuntimeDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1226 "src/hotspot/cpu/arm/arm.ad"

    // CALL directly to the runtime
    emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), runtime_call_Relocation::spec());
  
#line 16511 "ad_arm.cpp"
  }
  {

#line 1222 "src/hotspot/cpu/arm/arm.ad"

    // nothing
  
#line 16519 "ad_arm.cpp"
  }
}

void CallLeafDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1226 "src/hotspot/cpu/arm/arm.ad"

    // CALL directly to the runtime
    emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), runtime_call_Relocation::spec());
  
#line 16535 "ad_arm.cpp"
  }
  {

#line 1222 "src/hotspot/cpu/arm/arm.ad"

    // nothing
  
#line 16543 "ad_arm.cpp"
  }
}

void CallLeafNoFPDirectNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  {

#line 1226 "src/hotspot/cpu/arm/arm.ad"

    // CALL directly to the runtime
    emit_call_reloc(cbuf, as_MachCall(), opnd_array(1), runtime_call_Relocation::spec());
  
#line 16559 "ad_arm.cpp"
  }
  {

#line 1222 "src/hotspot/cpu/arm/arm.ad"

    // nothing
  
#line 16567 "ad_arm.cpp"
  }
}

void TailCalljmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// method_ptr
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9037 "src/hotspot/cpu/arm/arm.ad"

    __ mov(Rexception_pc, LR);   // this is used only to call
                                 // StubRoutines::forward_exception_entry()
                                 // which expects PC of exception in
                                 // R5. FIXME?
    __ jump(opnd_array(1)->as_Register(ra_,this,idx1)/* jump_target */);
  
#line 16588 "ad_arm.cpp"
  }
}

void RetNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9054 "src/hotspot/cpu/arm/arm.ad"

    __ ret(LR);
  
#line 16604 "ad_arm.cpp"
  }
}

void tailjmpIndNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// ex_oop
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9073 "src/hotspot/cpu/arm/arm.ad"

    __ mov(Rexception_pc, LR);
    __ jump(opnd_array(1)->as_Register(ra_,this,idx1)/* jump_target */);
  
#line 16622 "ad_arm.cpp"
  }
}

void CreateExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// 
  // User did not define which encode class to use.
}

uint CreateExceptionNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 0, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 0);
}

void RethrowExceptionNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9106 "src/hotspot/cpu/arm/arm.ad"

    Register scratch = R1_tmp;
    assert_different_registers(scratch, c_rarg0, LR);
    __ jump(OptoRuntime::rethrow_stub(), relocInfo::runtime_call_type, scratch);
  
#line 16653 "ad_arm.cpp"
  }
}

void ShouldNotReachHereNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 5;
  unsigned idx1 = 5; 	// 
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9123 "src/hotspot/cpu/arm/arm.ad"

    if (is_reachable()) {
      __ stop(_halt_reason);
    }
  
#line 16671 "ad_arm.cpp"
  }
}

void partialSubtypeCheckNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// sub
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// super
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9141 "src/hotspot/cpu/arm/arm.ad"

    __ call(StubRoutines::Arm::partial_subtype_check(), relocInfo::runtime_call_type);
  
#line 16688 "ad_arm.cpp"
  }
}

void cmpFastLockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scratch2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// scratch
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9164 "src/hotspot/cpu/arm/arm.ad"

    __ fast_lock(opnd_array(1)->as_Register(ra_,this,idx1)/* object */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */, opnd_array(4)->as_Register(ra_,this,idx4)/* scratch */, opnd_array(3)->as_Register(ra_,this,idx3)/* scratch2 */);
  
#line 16707 "ad_arm.cpp"
  }
}

void cmpFastUnlockNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// object
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// box
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// scratch2
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// scratch
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9176 "src/hotspot/cpu/arm/arm.ad"

    __ fast_unlock(opnd_array(1)->as_Register(ra_,this,idx1)/* object */, opnd_array(2)->as_Register(ra_,this,idx2)/* box */, opnd_array(4)->as_Register(ra_,this,idx4)/* scratch */, opnd_array(3)->as_Register(ra_,this,idx3)/* scratch2 */);
  
#line 16726 "ad_arm.cpp"
  }
}

void clear_arrayNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// cnt
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// base
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// temp
  unsigned idx4 = idx3 + opnd_array(3)->num_edges(); 	// zero
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9193 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(4)->as_Register(ra_,this,idx4)/* zero */, 0);
    __ mov(opnd_array(3)->as_Register(ra_,this,idx3)/* temp */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */);
    Label(loop);
    __ bind(loop);
    __ subs(opnd_array(3)->as_Register(ra_,this,idx3)/* temp */, opnd_array(3)->as_Register(ra_,this,idx3)/* temp */, 4);
    __ str(opnd_array(4)->as_Register(ra_,this,idx4)/* zero */, Address(opnd_array(2)->as_Register(ra_,this,idx2)/* base */, opnd_array(3)->as_Register(ra_,this,idx3)/* temp */), ge);
    __ b(loop, gt);
  
#line 16751 "ad_arm.cpp"
  }
}

void countLeadingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9252 "src/hotspot/cpu/arm/arm.ad"

    __ clz_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16767 "ad_arm.cpp"
  }
}

uint countLeadingZerosINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void countLeadingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9266 "src/hotspot/cpu/arm/arm.ad"

    __ clz(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
    __ teq(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, 32);
    __ clz(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, eq);
    __ add(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, eq);
  
#line 16793 "ad_arm.cpp"
  }
}

uint countLeadingZerosLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void countTrailingZerosINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9281 "src/hotspot/cpu/arm/arm.ad"

    __ rbit_32(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ clz_32(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 16816 "ad_arm.cpp"
  }
}

uint countTrailingZerosINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void countTrailingZerosLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9298 "src/hotspot/cpu/arm/arm.ad"

    __ rbit(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ clz(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */);
    __ teq(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, 32);
    __ rbit(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
    __ clz(opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, eq);
    __ add(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(3)->as_Register(ra_,this,idx3)/* tmp */, eq);
  
#line 16844 "ad_arm.cpp"
  }
}

uint countTrailingZerosLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 24, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 24);
}

void popCountINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9324 "src/hotspot/cpu/arm/arm.ad"

    __ fmsr(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ vcnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ vpaddl(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 8, 0);
    __ vpaddl(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 16, 0);
    __ fmrs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
  
#line 16870 "ad_arm.cpp"
  }
}

uint popCountINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 20, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 20);
}

void popCountLNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9349 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
    __ vcnt(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
    __ vpaddl(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 8, 0);
    __ vpaddl(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 16, 0);
    __ vpaddl(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */, 32, 0);
    __ fmrs(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* tmp */);
  
#line 16897 "ad_arm.cpp"
  }
}

uint popCountLNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 32, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 32);
}

void bytes_reverse_intNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9369 "src/hotspot/cpu/arm/arm.ad"

    __ rev(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16918 "ad_arm.cpp"
  }
}

uint bytes_reverse_intNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void bytes_reverse_longNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// dst
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9381 "src/hotspot/cpu/arm/arm.ad"

    __ rev(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
    __ rev(opnd_array(2)->as_Register(ra_,this,idx2)/* dst */->successor(), opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16941 "ad_arm.cpp"
  }
}

uint bytes_reverse_longNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void bytes_reverse_unsigned_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9392 "src/hotspot/cpu/arm/arm.ad"

    __ rev16(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16962 "ad_arm.cpp"
  }
}

uint bytes_reverse_unsigned_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void bytes_reverse_shortNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9402 "src/hotspot/cpu/arm/arm.ad"

    __ revsh(opnd_array(0)->as_Register(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 16983 "ad_arm.cpp"
  }
}

uint bytes_reverse_shortNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9418 "src/hotspot/cpu/arm/arm.ad"

    __ ldr_double(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 17004 "ad_arm.cpp"
  }
}

uint loadV8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void loadV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9431 "src/hotspot/cpu/arm/arm.ad"

    __ vld1(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), MacroAssembler::VELEM_SIZE_16, 128);
  
#line 17025 "ad_arm.cpp"
  }
}

uint loadV16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeV8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9444 "src/hotspot/cpu/arm/arm.ad"

    __ str_double(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()));
  
#line 17047 "ad_arm.cpp"
  }
}

uint storeV8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void storeV16Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 2;
  unsigned idx1 = 2; 	// mem
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9457 "src/hotspot/cpu/arm/arm.ad"

    __ vst1(opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src */, Address::make_raw(opnd_array(1)->base(ra_,this,idx1), opnd_array(1)->index(ra_,this,idx1), opnd_array(1)->scale(), opnd_array(1)->disp(ra_,this,idx1), opnd_array(1)->disp_reloc()), MacroAssembler::VELEM_SIZE_16, 128);
  
#line 17069 "ad_arm.cpp"
  }
}

uint storeV16Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9476 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, lsl, 24));
    __ orr(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, lsr, 8));
    __ orr(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, lsr, 16));
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17094 "ad_arm.cpp"
  }
}

uint Repl8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 16, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 16);
}

void Repl8B_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9492 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 17117 "ad_arm.cpp"
  }
}

uint Repl8B_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9507 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 17140 "ad_arm.cpp"
  }
}

uint Repl16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl8B_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {

#line 1300 "src/hotspot/cpu/arm/arm.ad"

    // FIXME: load from constant table?
    // Load a constant replicated "count" times with width "width"
    int count = ((4));
    int width = ((1));
    assert(count*width == 4, "sanity");
    int val = opnd_array(1)->constant();
    if (width < 4) {
      int bit_width = width * 8;
      val &= (((int)1) << bit_width) - 1; // mask off sign bits
      for (int i = 0; i < count - 1; i++) {
        val |= (val << bit_width);
      }
    }
    C2_MacroAssembler _masm(&cbuf);

    if (val == -1) {
      __ mvn(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else if (val == 0) {
      __ mov(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else {
      __ movw(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, val & 0xffff);
      __ movt(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, (unsigned int)val >> 16);
    }
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17184 "ad_arm.cpp"
  }
}

uint Repl8B_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void Repl8B_immU8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9537 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vmovI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->constant(),
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 17207 "ad_arm.cpp"
  }
}

uint Repl8B_immU8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl16B_immU8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9552 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vmovI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->constant(),
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 17230 "ad_arm.cpp"
  }
}

uint Repl16B_immU8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9572 "src/hotspot/cpu/arm/arm.ad"

    __ mov(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, AsmOperand(opnd_array(1)->as_Register(ra_,this,idx1)/* src */, lsl, 16));
    __ orr(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, AsmOperand(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, lsr, 16));
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17254 "ad_arm.cpp"
  }
}

uint Repl4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void Repl4S_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9587 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 17277 "ad_arm.cpp"
  }
}

uint Repl4S_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9602 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 17300 "ad_arm.cpp"
  }
}

uint Repl8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl4S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {

#line 1300 "src/hotspot/cpu/arm/arm.ad"

    // FIXME: load from constant table?
    // Load a constant replicated "count" times with width "width"
    int count = ((2));
    int width = ((2));
    assert(count*width == 4, "sanity");
    int val = opnd_array(1)->constant();
    if (width < 4) {
      int bit_width = width * 8;
      val &= (((int)1) << bit_width) - 1; // mask off sign bits
      for (int i = 0; i < count - 1; i++) {
        val |= (val << bit_width);
      }
    }
    C2_MacroAssembler _masm(&cbuf);

    if (val == -1) {
      __ mvn(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else if (val == 0) {
      __ mov(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else {
      __ movw(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, val & 0xffff);
      __ movt(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, (unsigned int)val >> 16);
    }
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17344 "ad_arm.cpp"
  }
}

uint Repl4S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void Repl4S_immU8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9632 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vmovI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->constant(),
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 17367 "ad_arm.cpp"
  }
}

uint Repl4S_immU8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl8S_immU8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9647 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vmovI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->constant(),
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 17390 "ad_arm.cpp"
  }
}

uint Repl8S_immU8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9662 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 17411 "ad_arm.cpp"
  }
}

uint Repl2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9678 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor()->successor(),
             opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 17434 "ad_arm.cpp"
  }
}

uint Repl4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void Repl2I_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9693 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 17457 "ad_arm.cpp"
  }
}

uint Repl2I_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl4I_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9708 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */,
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 17480 "ad_arm.cpp"
  }
}

uint Repl4I_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl2I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {

#line 1300 "src/hotspot/cpu/arm/arm.ad"

    // FIXME: load from constant table?
    // Load a constant replicated "count" times with width "width"
    int count = ((1));
    int width = ((4));
    assert(count*width == 4, "sanity");
    int val = opnd_array(1)->constant();
    if (width < 4) {
      int bit_width = width * 8;
      val &= (((int)1) << bit_width) - 1; // mask off sign bits
      for (int i = 0; i < count - 1; i++) {
        val |= (val << bit_width);
      }
    }
    C2_MacroAssembler _masm(&cbuf);

    if (val == -1) {
      __ mvn(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else if (val == 0) {
      __ mov(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else {
      __ movw(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, val & 0xffff);
      __ movt(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, (unsigned int)val >> 16);
    }
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17524 "ad_arm.cpp"
  }
}

uint Repl2I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void Repl2I_immU8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9738 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vmovI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->constant(),
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 17547 "ad_arm.cpp"
  }
}

uint Repl2I_immU8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl4I_immU8Node::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9753 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vmovI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->constant(),
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 17570 "ad_arm.cpp"
  }
}

uint Repl4I_immU8Node::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9770 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor()->successor(),
             opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */->successor());
  
#line 17593 "ad_arm.cpp"
  }
}

uint Repl2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 8, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 8);
}

void Repl2F_regINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9786 "src/hotspot/cpu/arm/arm.ad"

    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */, opnd_array(1)->as_Register(ra_,this,idx1)/* src */);
  
#line 17614 "ad_arm.cpp"
  }
}

uint Repl2F_regINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint Repl2F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void Repl2F_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9814 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vdupF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, quad);
  
#line 17641 "ad_arm.cpp"
  }
}

uint Repl2F_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9832 "src/hotspot/cpu/arm/arm.ad"

    __ fmrs(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */);
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor()->successor(),
             opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17666 "ad_arm.cpp"
  }
}

uint Repl4F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*3, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*3);
}

void Repl4F_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9849 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vdupF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, quad);
  
#line 17688 "ad_arm.cpp"
  }
}

uint Repl4F_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void Repl2F_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// tmp
  {

#line 1327 "src/hotspot/cpu/arm/arm.ad"

    // Replicate float con 2 times and pack into vector (8 bytes) in regD.
    float fval = opnd_array(1)->constantF();
    int val = *((int*)&fval);
    C2_MacroAssembler _masm(&cbuf);

    if (val == -1) {
      __ mvn(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else if (val == 0) {
      __ mov(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, 0);
    } else {
      __ movw(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, val & 0xffff);
      __ movt(opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, (unsigned int)val >> 16);
    }
    __ fmdrr(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */, opnd_array(2)->as_Register(ra_,this,idx2)/* tmp */);
  
#line 17722 "ad_arm.cpp"
  }
}

uint Repl2F_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 12, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 12);
}

void Repl2D_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9879 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */;
    __ fcpyd(dsta, src);
    FloatRegister dstb = dsta->successor()->successor();
    __ fcpyd(dstb, src);
  
#line 17747 "ad_arm.cpp"
  }
}

uint Repl2D_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vadd8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9899 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 17771 "ad_arm.cpp"
  }
}

uint vadd8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9912 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 17795 "ad_arm.cpp"
  }
}

uint vadd16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9926 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 17819 "ad_arm.cpp"
  }
}

uint vadd4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9939 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 17843 "ad_arm.cpp"
  }
}

uint vadd8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9953 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 17867 "ad_arm.cpp"
  }
}

uint vadd2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9966 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 17891 "ad_arm.cpp"
  }
}

uint vadd4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9980 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vaddI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_64, quad);
  
#line 17915 "ad_arm.cpp"
  }
}

uint vadd2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 9994 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vaddF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VFA_SIZE_F32, quad);
  
#line 17939 "ad_arm.cpp"
  }
}

uint vadd2F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd2F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10010 "src/hotspot/cpu/arm/arm.ad"

    __ add_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ add_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor(),
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */->successor(),
             opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */->successor());
  
#line 17964 "ad_arm.cpp"
  }
}

uint vadd2F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vadd4F_reg_simdNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10025 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vaddF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VFA_SIZE_F32, quad);
  
#line 17988 "ad_arm.cpp"
  }
}

uint vadd4F_reg_simdNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vadd4F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10044 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ add_float(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor();
    FloatRegister src1b = src1a->successor();
    FloatRegister src2b = src2a->successor();
    __ add_float(dstb, src1b, src2b);
    FloatRegister dstc = dstb->successor();
    FloatRegister src1c = src1b->successor();
    FloatRegister src2c = src2b->successor();
    __ add_float(dstc, src1c, src2c);
    FloatRegister dstd = dstc->successor();
    FloatRegister src1d = src1c->successor();
    FloatRegister src2d = src2c->successor();
    __ add_float(dstd, src1d, src2d);
  
#line 18025 "ad_arm.cpp"
  }
}

uint vadd4F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*4);
}

void vadd2D_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10075 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ add_double(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor()->successor();
    FloatRegister src1b = src1a->successor()->successor();
    FloatRegister src2b = src2a->successor()->successor();
    __ add_double(dstb, src1b, src2b);
  
#line 18054 "ad_arm.cpp"
  }
}

uint vadd2D_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsub8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10096 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18078 "ad_arm.cpp"
  }
}

uint vsub8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10109 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18102 "ad_arm.cpp"
  }
}

uint vsub16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10123 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 18126 "ad_arm.cpp"
  }
}

uint vsub4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub16S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10136 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_16, quad);
  
#line 18150 "ad_arm.cpp"
  }
}

uint vsub16S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10150 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 18174 "ad_arm.cpp"
  }
}

uint vsub2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10163 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_32, quad);
  
#line 18198 "ad_arm.cpp"
  }
}

uint vsub4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10177 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vsubI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_64, quad);
  
#line 18222 "ad_arm.cpp"
  }
}

uint vsub2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10191 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vsubF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VFA_SIZE_F32, quad);
  
#line 18246 "ad_arm.cpp"
  }
}

uint vsub2F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub2F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10208 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ sub_float(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor();
    FloatRegister src1b = src1a->successor();
    FloatRegister src2b = src2a->successor();
    __ sub_float(dstb, src1b, src2b);
  
#line 18275 "ad_arm.cpp"
  }
}

uint vsub2F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsub4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10228 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vsubF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VFA_SIZE_F32, quad);
  
#line 18299 "ad_arm.cpp"
  }
}

uint vsub4F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsub4F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10247 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ sub_float(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor();
    FloatRegister src1b = src1a->successor();
    FloatRegister src2b = src2a->successor();
    __ sub_float(dstb, src1b, src2b);
    FloatRegister dstc = dstb->successor();
    FloatRegister src1c = src1b->successor();
    FloatRegister src2c = src2b->successor();
    __ sub_float(dstc, src1c, src2c);
    FloatRegister dstd = dstc->successor();
    FloatRegister src1d = src1c->successor();
    FloatRegister src2d = src2c->successor();
    __ sub_float(dstd, src1d, src2d);
  
#line 18336 "ad_arm.cpp"
  }
}

uint vsub4F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*4);
}

void vsub2D_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10278 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ sub_double(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor()->successor();
    FloatRegister src1b = src1a->successor()->successor();
    FloatRegister src2b = src2a->successor()->successor();
    __ sub_double(dstb, src1b, src2b);
  
#line 18365 "ad_arm.cpp"
  }
}

uint vsub2D_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vmul4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10298 "src/hotspot/cpu/arm/arm.ad"

    __ vmulI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_16, 0);
  
#line 18388 "ad_arm.cpp"
  }
}

uint vmul4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vmul8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10310 "src/hotspot/cpu/arm/arm.ad"

    __ vmulI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_16, 1);
  
#line 18411 "ad_arm.cpp"
  }
}

uint vmul8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vmul2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10323 "src/hotspot/cpu/arm/arm.ad"

    __ vmulI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_32, 0);
  
#line 18434 "ad_arm.cpp"
  }
}

uint vmul2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vmul4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10335 "src/hotspot/cpu/arm/arm.ad"

    __ vmulI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VELEM_SIZE_32, 1);
  
#line 18457 "ad_arm.cpp"
  }
}

uint vmul4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vmul2F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10348 "src/hotspot/cpu/arm/arm.ad"

    __ vmulF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VFA_SIZE_F32, 0);
  
#line 18480 "ad_arm.cpp"
  }
}

uint vmul2F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vmul2F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10363 "src/hotspot/cpu/arm/arm.ad"

    __ mul_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ mul_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor(),
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */->successor(),
             opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */->successor());
  
#line 18505 "ad_arm.cpp"
  }
}

uint vmul2F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vmul4F_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10378 "src/hotspot/cpu/arm/arm.ad"

    __ vmulF(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             MacroAssembler::VFA_SIZE_F32, 1);
  
#line 18528 "ad_arm.cpp"
  }
}

uint vmul4F_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vmul4F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10396 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ mul_float(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor();
    FloatRegister src1b = src1a->successor();
    FloatRegister src2b = src2a->successor();
    __ mul_float(dstb, src1b, src2b);
    FloatRegister dstc = dstb->successor();
    FloatRegister src1c = src1b->successor();
    FloatRegister src2c = src2b->successor();
    __ mul_float(dstc, src1c, src2c);
    FloatRegister dstd = dstc->successor();
    FloatRegister src1d = src1c->successor();
    FloatRegister src2d = src2c->successor();
    __ mul_float(dstd, src1d, src2d);
  
#line 18565 "ad_arm.cpp"
  }
}

uint vmul4F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*4);
}

void vmul2D_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10426 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ mul_double(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor()->successor();
    FloatRegister src1b = src1a->successor()->successor();
    FloatRegister src2b = src2a->successor()->successor();
    __ mul_double(dstb, src1b, src2b);
  
#line 18594 "ad_arm.cpp"
  }
}

uint vmul2D_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vdiv2F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10450 "src/hotspot/cpu/arm/arm.ad"

    __ div_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */);
    __ div_float(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */->successor(),
             opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */->successor(),
             opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */->successor());
  
#line 18619 "ad_arm.cpp"
  }
}

uint vdiv2F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vdiv4F_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10471 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ div_float(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor();
    FloatRegister src1b = src1a->successor();
    FloatRegister src2b = src2a->successor();
    __ div_float(dstb, src1b, src2b);
    FloatRegister dstc = dstb->successor();
    FloatRegister src1c = src1b->successor();
    FloatRegister src2c = src2b->successor();
    __ div_float(dstc, src1c, src2c);
    FloatRegister dstd = dstc->successor();
    FloatRegister src1d = src1c->successor();
    FloatRegister src2d = src2c->successor();
    __ div_float(dstd, src1d, src2d);
  
#line 18656 "ad_arm.cpp"
  }
}

uint vdiv4F_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*4);
}

void vdiv2D_reg_vfpNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10501 "src/hotspot/cpu/arm/arm.ad"

    FloatRegister dsta = opnd_array(0)->as_FloatRegister(ra_,this)/* dst */;
    FloatRegister src1a = opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */;
    FloatRegister src2a = opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */;
    __ div_double(dsta, src1a, src2a);
    FloatRegister dstb = dsta->successor()->successor();
    FloatRegister src1b = src1a->successor()->successor();
    FloatRegister src2b = src2a->successor()->successor();
    __ div_double(dstb, src1b, src2b);
  
#line 18685 "ad_arm.cpp"
  }
}

uint vdiv2D_reg_vfpNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vneg8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10523 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vnegI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18708 "ad_arm.cpp"
  }
}

uint vneg8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vneg16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10537 "src/hotspot/cpu/arm/arm.ad"

    bool _float = false;
    bool quad = true;
    __ vnegI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18732 "ad_arm.cpp"
  }
}

uint vneg16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vslcntDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vslcntXNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrcntDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10578 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vnegI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18767 "ad_arm.cpp"
  }
}

uint vsrcntDNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsrcntXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// cnt
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10595 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vdupI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_Register(ra_,this,idx1)/* cnt */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vnegI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(0)->as_FloatRegister(ra_,this)/* dst */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18792 "ad_arm.cpp"
  }
}

uint vsrcntXNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsh8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10616 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18816 "ad_arm.cpp"
  }
}

uint vsh8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsh16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10632 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 18840 "ad_arm.cpp"
  }
}

uint vsh16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsh4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10649 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 18864 "ad_arm.cpp"
  }
}

uint vsh4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsh8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10665 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 18888 "ad_arm.cpp"
  }
}

uint vsh8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsh2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10682 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 18912 "ad_arm.cpp"
  }
}

uint vsh2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsh4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10698 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 18936 "ad_arm.cpp"
  }
}

uint vsh4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsh2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10715 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_64, quad);
  
#line 18960 "ad_arm.cpp"
  }
}

uint vsh2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsl8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

uint vsl16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

void vsl8B_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10754 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 8, opnd_array(2)->constant(),
             quad);
  
#line 18994 "ad_arm.cpp"
  }
}

uint vsl8B_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsl16B_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10770 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 8, opnd_array(2)->constant(),
             quad);
  
#line 19018 "ad_arm.cpp"
  }
}

uint vsl16B_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsl4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

uint vsl8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

void vsl4S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10807 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 16, opnd_array(2)->constant(),
             quad);
  
#line 19052 "ad_arm.cpp"
  }
}

uint vsl4S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsl8S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10823 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 16, opnd_array(2)->constant(),
             quad);
  
#line 19076 "ad_arm.cpp"
  }
}

uint vsl8S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsl2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

uint vsl4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

void vsl2I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10862 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 32, opnd_array(2)->constant(),
             quad);
  
#line 19110 "ad_arm.cpp"
  }
}

uint vsl2I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsl4I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10880 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 32, opnd_array(2)->constant(),
             quad);
  
#line 19134 "ad_arm.cpp"
  }
}

uint vsl4I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsl2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*1, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*1);
}

void vsl2L_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10907 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshli(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 64, opnd_array(2)->constant(),
             quad);
  
#line 19163 "ad_arm.cpp"
  }
}

uint vsl2L_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsrl4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl4S_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10952 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 19195 "ad_arm.cpp"
  }
}

uint vsrl4S_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

uint vsrl8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl8S_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 10982 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 19227 "ad_arm.cpp"
  }
}

uint vsrl8S_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsrl4S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11000 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshrUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 16, opnd_array(2)->constant(),
             quad);
  
#line 19251 "ad_arm.cpp"
  }
}

uint vsrl4S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl8S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11016 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 16, opnd_array(2)->constant(),
             quad);
  
#line 19275 "ad_arm.cpp"
  }
}

uint vsrl8S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsrl2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl2I_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11049 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 19307 "ad_arm.cpp"
  }
}

uint vsrl2I_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

uint vsrl4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl4I_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11083 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 19339 "ad_arm.cpp"
  }
}

uint vsrl4I_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsrl2I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11103 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshrUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 32, opnd_array(2)->constant(),
             quad);
  
#line 19363 "ad_arm.cpp"
  }
}

uint vsrl2I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl4I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11121 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 32, opnd_array(2)->constant(),
             quad);
  
#line 19387 "ad_arm.cpp"
  }
}

uint vsrl4I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsrl2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsrl2L_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11150 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_64, quad);
  
#line 19419 "ad_arm.cpp"
  }
}

uint vsrl2L_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsrl2L_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11168 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrUI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 64, opnd_array(2)->constant(),
             quad);
  
#line 19443 "ad_arm.cpp"
  }
}

uint vsrl2L_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha8B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11187 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 19467 "ad_arm.cpp"
  }
}

uint vsha8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha16B_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11203 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 19491 "ad_arm.cpp"
  }
}

uint vsha16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha4S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11220 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 19515 "ad_arm.cpp"
  }
}

uint vsha4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha8S_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11236 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 19539 "ad_arm.cpp"
  }
}

uint vsha8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha2I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11253 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 19563 "ad_arm.cpp"
  }
}

uint vsha2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha4I_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11269 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 19587 "ad_arm.cpp"
  }
}

uint vsha4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsha2L_regNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11286 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_64, quad);
  
#line 19611 "ad_arm.cpp"
  }
}

uint vsha2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsra8B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra8B_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11315 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 19643 "ad_arm.cpp"
  }
}

uint vsra8B_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

uint vsra16B_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra16B_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11345 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_8, quad);
  
#line 19675 "ad_arm.cpp"
  }
}

uint vsra16B_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsra8B_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11363 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 8, opnd_array(2)->constant(),
             quad);
  
#line 19699 "ad_arm.cpp"
  }
}

uint vsra8B_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra16B_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11379 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 8, opnd_array(2)->constant(),
             quad);
  
#line 19723 "ad_arm.cpp"
  }
}

uint vsra16B_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsra4S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra4S_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11408 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 19755 "ad_arm.cpp"
  }
}

uint vsra4S_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

uint vsra8S_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra8S_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11438 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_16, quad);
  
#line 19787 "ad_arm.cpp"
  }
}

uint vsra8S_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsra4S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11456 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 16, opnd_array(2)->constant(),
             quad);
  
#line 19811 "ad_arm.cpp"
  }
}

uint vsra4S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra8S_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11472 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 16, opnd_array(2)->constant(),
             quad);
  
#line 19835 "ad_arm.cpp"
  }
}

uint vsra8S_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsra2I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra2I_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11501 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 19867 "ad_arm.cpp"
  }
}

uint vsra2I_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

uint vsra4I_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra4I_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11531 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_32, quad);
  
#line 19899 "ad_arm.cpp"
  }
}

uint vsra4I_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsra2I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11549 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 32, opnd_array(2)->constant(),
             quad);
  
#line 19923 "ad_arm.cpp"
  }
}

uint vsra2I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra4I_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11565 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 32, opnd_array(2)->constant(),
             quad);
  
#line 19947 "ad_arm.cpp"
  }
}

uint vsra4I_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

uint vsra2L_regNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vsra2L_reg_varNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  unsigned idx3 = idx2 + opnd_array(2)->num_edges(); 	// tmp
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11594 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vnegI(opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* shift */,
             MacroAssembler::VELEM_SIZE_8, quad);
    __ vshlSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(3)->as_FloatRegister(ra_,this,idx3)/* tmp */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */,
              MacroAssembler::VELEM_SIZE_64, quad);
  
#line 19979 "ad_arm.cpp"
  }
}

uint vsra2L_reg_varNode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4*2, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4*2);
}

void vsra2L_immINode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// shift
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11612 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vshrSI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src */, 64, opnd_array(2)->constant(),
             quad);
  
#line 20003 "ad_arm.cpp"
  }
}

uint vsra2L_immINode::size(PhaseRegAlloc *ra_) const {
  assert(VerifyOops || MachNode::size(ra_) <= 4, "bad fixed size");
  return (VerifyOops ? MachNode::size(ra_) : 4);
}

void vandDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11626 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vandI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             quad);
  
#line 20027 "ad_arm.cpp"
  }
}

void vandXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11638 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vandI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             quad);
  
#line 20046 "ad_arm.cpp"
  }
}

void vorDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11652 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vorI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
            quad);
  
#line 20065 "ad_arm.cpp"
  }
}

void vorXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11664 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vorI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
            quad);
  
#line 20084 "ad_arm.cpp"
  }
}

void vxorDNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11678 "src/hotspot/cpu/arm/arm.ad"

    bool quad = false;
    __ vxorI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             quad);
  
#line 20103 "ad_arm.cpp"
  }
}

void vxorXNode::emit(CodeBuffer& cbuf, PhaseRegAlloc* ra_) const {
  cbuf.set_insts_mark();
  // Start at oper_input_base() and count operands
  unsigned idx0 = 1;
  unsigned idx1 = 1; 	// src1
  unsigned idx2 = idx1 + opnd_array(1)->num_edges(); 	// src2
  {
    C2_MacroAssembler _masm(&cbuf);

#line 11690 "src/hotspot/cpu/arm/arm.ad"

    bool quad = true;
    __ vxorI(opnd_array(0)->as_FloatRegister(ra_,this)/* dst */, opnd_array(1)->as_FloatRegister(ra_,this,idx1)/* src1 */, opnd_array(2)->as_FloatRegister(ra_,this,idx2)/* src2 */,
             quad);
  
#line 20122 "ad_arm.cpp"
  }
}

const MachOper* loadBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUB2L_limmINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUSNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUS2L_limmINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadINode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2BNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2UBNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2SNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2USNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_255Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immI_65535Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_limmU31Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadI2L_immU31Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadUI2LNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadLNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_2instrNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_volatile_fpNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadL_unalignedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadRangeNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadKlassNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadDNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadD_unalignedNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadFNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAlloc_mpNode::memory_operand() const { return _opnds[1]; }
const MachOper* prefetchAlloc_spNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeBNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCMNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeCNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeINode::memory_operand() const { return _opnds[1]; }
const MachOper* storeLNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_2instrNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatileNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeL_volatile_fpNode::memory_operand() const { return _opnds[1]; }
const MachOper* storePNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeDNode::memory_operand() const { return _opnds[1]; }
const MachOper* storeFNode::memory_operand() const { return _opnds[1]; }
const MachOper* addshlP_reg_reg_immNode::memory_operand() const { return _opnds[2]; }
const MachOper* compareAndSwapL_boolNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapI_boolNode::memory_operand() const { return _opnds[1]; }
const MachOper* compareAndSwapP_boolNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddI_aimmI_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddI_reg_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddI_aimmINode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddI_regNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddL_reg_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddL_immRot_no_resNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddL_regNode::memory_operand() const { return _opnds[1]; }
const MachOper* xaddL_immRotNode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgINode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgLNode::memory_operand() const { return _opnds[1]; }
const MachOper* xchgPNode::memory_operand() const { return _opnds[1]; }
const MachOper* loadV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* loadV16Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV8Node::memory_operand() const { return _opnds[1]; }
const MachOper* storeV16Node::memory_operand() const { return _opnds[1]; }


const bool Matcher::has_match_rule(int opcode) {
  assert(_last_machine_leaf < opcode && opcode < _last_opcode, "opcode in range");
  return _hasMatchRule[opcode];
}

const bool Matcher::_hasMatchRule[_last_opcode] = {
    false,  // Node
    false,  // Set
    false,  // RegN
    false,  // RegI
    false,  // RegP
    false,  // RegF
    false,  // RegD
    false,  // RegL
    false,  // VecA
    false,  // VecS
    false,  // VecD
    false,  // VecX
    false,  // VecY
    false,  // VecZ
    false,  // RegVectMask
    false,  // RegFlags
    false,  // _last_machine_leaf
    true ,  // AbsD
    true ,  // AbsF
    false,  // AbsI
    false,  // AbsL
    true ,  // AddD
    true ,  // AddF
    true ,  // AddI
    true ,  // AddL
    true ,  // AddP
    false,  // Allocate
    false,  // AllocateArray
    true ,  // AndI
    true ,  // AndL
    false,  // ArrayCopy
    false,  // AryEq
    false,  // AtanD
    true ,  // Binary
    false,  // Blackhole
    true ,  // Bool
    false,  // BoxLock
    true ,  // ReverseBytesI
    true ,  // ReverseBytesL
    true ,  // ReverseBytesUS
    true ,  // ReverseBytesS
    false,  // ReverseBytesV
    false,  // CProj
    false,  // CacheWB
    false,  // CacheWBPreSync
    false,  // CacheWBPostSync
    true ,  // CallDynamicJava
    false,  // CallJava
    true ,  // CallLeaf
    true ,  // CallLeafNoFP
    false,  // CallLeafVector
    true ,  // CallRuntime
    true ,  // CallStaticJava
    true ,  // CastDD
    true ,  // CastFF
    true ,  // CastII
    true ,  // CastLL
    true ,  // CastVV
    true ,  // CastX2P
    true ,  // CastP2X
    true ,  // CastPP
    false,  // Catch
    false,  // CatchProj
    true ,  // CheckCastPP
    true ,  // ClearArray
    false,  // CompressBits
    false,  // ExpandBits
    false,  // CompressBitsV
    false,  // ExpandBitsV
    false,  // ConstraintCast
    true ,  // CMoveD
    true ,  // CMoveF
    true ,  // CMoveI
    true ,  // CMoveL
    true ,  // CMoveP
    false,  // CMoveN
    false,  // CmpN
    true ,  // CmpD
    true ,  // CmpD3
    true ,  // CmpF
    true ,  // CmpF3
    true ,  // CmpI
    true ,  // CmpL
    true ,  // CmpL3
    true ,  // CmpLTMask
    true ,  // CmpP
    true ,  // CmpU
    false,  // CmpU3
    true ,  // CmpUL
    false,  // CmpUL3
    false,  // CompareAndSwapB
    false,  // CompareAndSwapS
    true ,  // CompareAndSwapI
    true ,  // CompareAndSwapL
    true ,  // CompareAndSwapP
    false,  // CompareAndSwapN
    false,  // WeakCompareAndSwapB
    false,  // WeakCompareAndSwapS
    false,  // WeakCompareAndSwapI
    false,  // WeakCompareAndSwapL
    false,  // WeakCompareAndSwapP
    false,  // WeakCompareAndSwapN
    false,  // CompareAndExchangeB
    false,  // CompareAndExchangeS
    false,  // CompareAndExchangeI
    false,  // CompareAndExchangeL
    false,  // CompareAndExchangeP
    false,  // CompareAndExchangeN
    false,  // GetAndAddB
    false,  // GetAndAddS
    true ,  // GetAndAddI
    true ,  // GetAndAddL
    false,  // GetAndSetB
    false,  // GetAndSetS
    true ,  // GetAndSetI
    true ,  // GetAndSetL
    true ,  // GetAndSetP
    false,  // GetAndSetN
    false,  // Con
    true ,  // ConN
    true ,  // ConNKlass
    true ,  // ConD
    true ,  // ConF
    true ,  // ConI
    true ,  // ConL
    true ,  // ConP
    false,  // Conv2B
    true ,  // ConvD2F
    true ,  // ConvD2I
    true ,  // ConvD2L
    true ,  // ConvF2D
    true ,  // ConvF2I
    true ,  // ConvF2L
    true ,  // ConvI2D
    true ,  // ConvI2F
    true ,  // ConvI2L
    true ,  // ConvL2D
    false,  // ConvL2F
    true ,  // ConvL2I
    false,  // ConvF2HF
    false,  // ConvHF2F
    false,  // CountedLoop
    true ,  // CountedLoopEnd
    false,  // OuterStripMinedLoop
    false,  // OuterStripMinedLoopEnd
    false,  // LongCountedLoop
    false,  // LongCountedLoopEnd
    true ,  // CountLeadingZerosI
    true ,  // CountLeadingZerosL
    false,  // CountLeadingZerosV
    true ,  // CountTrailingZerosI
    true ,  // CountTrailingZerosL
    false,  // CountTrailingZerosV
    true ,  // CreateEx
    false,  // DecodeN
    false,  // DecodeNKlass
    true ,  // DivD
    true ,  // DivF
    true ,  // DivI
    true ,  // DivL
    false,  // UDivI
    false,  // UDivL
    false,  // DivMod
    false,  // DivModI
    false,  // DivModL
    false,  // UDivModI
    false,  // UDivModL
    false,  // EncodeISOArray
    false,  // EncodeP
    false,  // EncodePKlass
    true ,  // FastLock
    true ,  // FastUnlock
    false,  // FmaD
    false,  // FmaF
    true ,  // Goto
    true ,  // Halt
    false,  // CountPositives
    true ,  // If
    false,  // RangeCheck
    false,  // IfFalse
    false,  // IfTrue
    false,  // Initialize
    false,  // JProj
    true ,  // Jump
    false,  // JumpProj
    true ,  // LShiftI
    true ,  // LShiftL
    true ,  // LoadB
    true ,  // LoadUB
    true ,  // LoadUS
    true ,  // LoadD
    true ,  // LoadD_unaligned
    true ,  // LoadF
    true ,  // LoadI
    true ,  // LoadKlass
    false,  // LoadNKlass
    true ,  // LoadL
    true ,  // LoadL_unaligned
    true ,  // LoadP
    false,  // LoadN
    true ,  // LoadRange
    true ,  // LoadS
    false,  // Lock
    false,  // Loop
    false,  // LoopLimit
    false,  // Mach
    false,  // MachNullCheck
    false,  // MachProj
    false,  // MulAddS2I
    true ,  // MaxI
    false,  // MaxL
    false,  // MaxD
    false,  // MaxF
    true ,  // MemBarAcquire
    true ,  // LoadFence
    true ,  // MemBarAcquireLock
    false,  // MemBarCPUOrder
    true ,  // MemBarRelease
    true ,  // StoreFence
    true ,  // StoreStoreFence
    true ,  // MemBarReleaseLock
    true ,  // MemBarVolatile
    true ,  // MemBarStoreStore
    false,  // MergeMem
    true ,  // MinI
    false,  // MinL
    false,  // MinF
    false,  // MinD
    false,  // ModD
    false,  // ModF
    true ,  // ModI
    true ,  // ModL
    false,  // UModI
    false,  // UModL
    true ,  // MoveI2F
    true ,  // MoveF2I
    true ,  // MoveL2D
    true ,  // MoveD2L
    false,  // IsInfiniteF
    false,  // IsFiniteF
    false,  // IsInfiniteD
    false,  // IsFiniteD
    true ,  // MulD
    true ,  // MulF
    false,  // MulHiL
    false,  // UMulHiL
    true ,  // MulI
    true ,  // MulL
    false,  // Multi
    false,  // NegI
    false,  // NegL
    true ,  // NegD
    true ,  // NegF
    false,  // NeverBranch
    false,  // OnSpinWait
    false,  // Opaque1
    false,  // OpaqueLoopInit
    false,  // OpaqueLoopStride
    false,  // OpaqueZeroTripGuard
    false,  // Opaque3
    false,  // Opaque4
    false,  // ProfileBoolean
    true ,  // OrI
    true ,  // OrL
    false,  // OverflowAddI
    false,  // OverflowSubI
    false,  // OverflowMulI
    false,  // OverflowAddL
    false,  // OverflowSubL
    false,  // OverflowMulL
    false,  // PCTable
    false,  // Parm
    false,  // ParsePredicate
    true ,  // PartialSubtypeCheck
    false,  // SubTypeCheck
    false,  // Phi
    true ,  // PopCountI
    true ,  // PopCountL
    false,  // PopCountVI
    false,  // PopCountVL
    false,  // PopulateIndex
    true ,  // PrefetchAllocation
    false,  // Proj
    true ,  // RShiftI
    true ,  // RShiftL
    false,  // Region
    true ,  // Rethrow
    true ,  // Return
    false,  // ReverseI
    false,  // ReverseL
    false,  // ReverseV
    false,  // Root
    false,  // RoundDouble
    false,  // RoundDoubleMode
    false,  // RoundDoubleModeV
    false,  // RoundFloat
    false,  // RotateLeft
    false,  // RotateLeftV
    false,  // RotateRight
    false,  // RotateRightV
    true ,  // SafePoint
    false,  // SafePointScalarObject
    false,  // ShenandoahCompareAndExchangeP
    false,  // ShenandoahCompareAndExchangeN
    false,  // ShenandoahCompareAndSwapN
    false,  // ShenandoahCompareAndSwapP
    false,  // ShenandoahWeakCompareAndSwapN
    false,  // ShenandoahWeakCompareAndSwapP
    false,  // ShenandoahIUBarrier
    false,  // ShenandoahLoadReferenceBarrier
    false,  // SCMemProj
    false,  // CopySignD
    false,  // CopySignF
    false,  // SignumD
    false,  // SignumF
    false,  // SignumVF
    false,  // SignumVD
    true ,  // SqrtD
    false,  // SqrtF
    false,  // RoundF
    false,  // RoundD
    false,  // Start
    false,  // StartOSR
    true ,  // StoreB
    true ,  // StoreC
    true ,  // StoreCM
    true ,  // StoreD
    true ,  // StoreF
    true ,  // StoreI
    true ,  // StoreL
    true ,  // StoreP
    false,  // StoreN
    false,  // StoreNKlass
    false,  // StrComp
    false,  // StrCompressedCopy
    false,  // StrEquals
    false,  // StrIndexOf
    false,  // StrIndexOfChar
    false,  // StrInflatedCopy
    true ,  // SubD
    true ,  // SubF
    true ,  // SubI
    true ,  // SubL
    true ,  // TailCall
    true ,  // TailJump
    false,  // MacroLogicV
    true ,  // ThreadLocal
    false,  // Unlock
    false,  // URShiftB
    false,  // URShiftS
    true ,  // URShiftI
    true ,  // URShiftL
    true ,  // XorI
    true ,  // XorL
    false,  // Vector
    true ,  // AddVB
    true ,  // AddVS
    true ,  // AddVI
    false,  // AddReductionVI
    true ,  // AddVL
    false,  // AddReductionVL
    true ,  // AddVF
    false,  // AddReductionVF
    true ,  // AddVD
    false,  // AddReductionVD
    true ,  // SubVB
    true ,  // SubVS
    true ,  // SubVI
    true ,  // SubVL
    true ,  // SubVF
    true ,  // SubVD
    false,  // MulVB
    true ,  // MulVS
    true ,  // MulVI
    false,  // MulReductionVI
    false,  // MulVL
    false,  // MulReductionVL
    true ,  // MulVF
    false,  // MulReductionVF
    true ,  // MulVD
    false,  // MulReductionVD
    false,  // MulAddVS2VI
    false,  // FmaVD
    false,  // FmaVF
    true ,  // DivVF
    true ,  // DivVD
    false,  // AbsVB
    false,  // AbsVS
    false,  // AbsVI
    false,  // AbsVL
    false,  // AbsVF
    false,  // AbsVD
    false,  // NegVI
    false,  // NegVL
    false,  // NegVF
    false,  // NegVD
    false,  // SqrtVD
    false,  // SqrtVF
    true ,  // LShiftCntV
    true ,  // RShiftCntV
    true ,  // LShiftVB
    true ,  // LShiftVS
    true ,  // LShiftVI
    true ,  // LShiftVL
    true ,  // RShiftVB
    true ,  // RShiftVS
    true ,  // RShiftVI
    true ,  // RShiftVL
    false,  // URShiftVB
    true ,  // URShiftVS
    true ,  // URShiftVI
    true ,  // URShiftVL
    true ,  // AndV
    false,  // AndReductionV
    true ,  // OrV
    false,  // OrReductionV
    true ,  // XorV
    false,  // XorReductionV
    false,  // MinV
    false,  // MaxV
    false,  // MinReductionV
    false,  // MaxReductionV
    false,  // CompressV
    false,  // CompressM
    false,  // ExpandV
    true ,  // LoadVector
    false,  // LoadVectorGather
    false,  // LoadVectorGatherMasked
    true ,  // StoreVector
    false,  // StoreVectorScatter
    false,  // StoreVectorScatterMasked
    false,  // LoadVectorMasked
    false,  // StoreVectorMasked
    false,  // VectorCmpMasked
    false,  // VectorMaskGen
    false,  // VectorMaskOp
    false,  // VectorMaskTrueCount
    false,  // VectorMaskFirstTrue
    false,  // VectorMaskLastTrue
    false,  // VectorMaskToLong
    false,  // VectorLongToMask
    false,  // Pack
    false,  // PackB
    false,  // PackS
    false,  // PackI
    false,  // PackL
    false,  // PackF
    false,  // PackD
    false,  // Pack2L
    false,  // Pack2D
    true ,  // ReplicateB
    true ,  // ReplicateS
    true ,  // ReplicateI
    true ,  // ReplicateL
    true ,  // ReplicateF
    true ,  // ReplicateD
    false,  // RoundVF
    false,  // RoundVD
    false,  // Extract
    false,  // ExtractB
    false,  // ExtractUB
    false,  // ExtractC
    false,  // ExtractS
    false,  // ExtractI
    false,  // ExtractL
    false,  // ExtractF
    false,  // ExtractD
    false,  // Digit
    false,  // LowerCase
    false,  // UpperCase
    false,  // Whitespace
    false,  // VectorBox
    false,  // VectorBoxAllocate
    false,  // VectorUnbox
    false,  // VectorMaskWrapper
    false,  // VectorMaskCmp
    false,  // VectorMaskCast
    false,  // VectorTest
    false,  // VectorBlend
    false,  // VectorRearrange
    false,  // VectorLoadMask
    false,  // VectorLoadShuffle
    false,  // VectorLoadConst
    false,  // VectorStoreMask
    false,  // VectorReinterpret
    false,  // VectorCast
    false,  // VectorCastB2X
    false,  // VectorCastS2X
    false,  // VectorCastI2X
    false,  // VectorCastL2X
    false,  // VectorCastF2X
    false,  // VectorCastD2X
    false,  // VectorCastF2HF
    false,  // VectorCastHF2F
    false,  // VectorUCastB2X
    false,  // VectorUCastS2X
    false,  // VectorUCastI2X
    false,  // VectorizedHashCode
    false,  // VectorInsert
    false,  // MaskAll
    false,  // AndVMask
    false,  // OrVMask
    false   // XorVMask
};


int Compile::sync_stack_slots() const { return 1 * VMRegImpl::slots_per_word; }

uint Matcher::stack_alignment_in_bytes() { return StackAlignmentInBytes; }

OptoReg::Name Matcher::return_addr() const { return OptoReg::stack2reg(- 1*VMRegImpl::slots_per_word +
              align_up((Compile::current()->in_preserve_stack_slots() +
                        Compile::current()->fixed_slots()),
                       stack_alignment_in_slots())); }

uint Compile::varargs_C_out_slots_killed() const { return 0; }

OptoRegPair Matcher::return_value(uint ideal_reg) {

#line 1652 "src/hotspot/cpu/arm/arm.ad"

    return c2::return_value(ideal_reg);
  
#line 20724 "ad_arm.cpp"

}

OptoRegPair Matcher::c_return_value(uint ideal_reg) {

#line 1652 "src/hotspot/cpu/arm/arm.ad"

    return c2::return_value(ideal_reg);
  
#line 20734 "ad_arm.cpp"

}

OptoReg::Name Matcher::inline_cache_reg() { return OptoReg::Name(R_Ricklass_num); }

int Matcher::inline_cache_reg_encode() { return _regEncode[inline_cache_reg()]; }

OptoReg::Name Matcher::interpreter_frame_pointer_reg() { return OptoReg::Bad; }

OptoReg::Name Matcher::c_frame_pointer() const { return OptoReg::Name(R_R13_num); }

// Number of callee-save + always-save registers
int  Matcher::number_of_saved_registers() {
  return 0;
};

bool Compile::needs_deep_clone_jvms() { return false; }

// Check consistency of C++ compilation with ADLC options:
// Check adlc -DLINUX=1
#ifndef LINUX
#  error "LINUX must be defined"
#endif // LINUX
// Check adlc -D_GNU_SOURCE=1
#ifndef _GNU_SOURCE
#  error "_GNU_SOURCE must be defined"
#endif // _GNU_SOURCE
// Check adlc -DARM32=1
#ifndef ARM32
#  error "ARM32 must be defined"
#endif // ARM32
// Check adlc -U_LP64
#ifdef _LP64
#  error "_LP64 must not be defined"
#endif // _LP64
// Check adlc -DARM=1
#ifndef ARM
#  error "ARM must be defined"
#endif // ARM
// Check adlc -DNDEBUG=1
#ifndef NDEBUG
#  error "NDEBUG must be defined"
#endif // NDEBUG
// Check adlc -DPRODUCT=1
#ifndef PRODUCT
#  error "PRODUCT must be defined"
#endif // PRODUCT
